@@ -97,7 +97,8 @@ function inst_wget() {
 function inst_dtk() {
     setup MSYS DTK
     _MSYS_UDIR=`unix_path $MSYS_DIR`
-    if quiet ${_MSYS_UDIR}/bin/perl --help
+    if quiet ${_MSYS_UDIR}/bin/perl --help &&
+        [ "`m4 --version | sed '1!d;s,.* [Mm]4 ,,'`" = "1.4.7" ]
     then
         echo "msys dtk already installed.  skipping."
     else
@@ -112,7 +113,10 @@ function inst_dtk() {
             while [ -e $_dst_file ]; do _dst_file=$_dst_file.bak; done
             mv $file $_dst_file
         done
-        quiet ${_MSYS_UDIR}/bin/perl --help || die "msys dtk not installed correctly"
+        wget_unpacked $M4_URL $DOWNLOAD_DIR $TMP_DIR
+        mv $TMP_UDIR/usr/bin/m4.exe /bin
+        quiet ${_MSYS_UDIR}/bin/perl --help &&
+        [ "`m4 --version | sed '1!d;s,.* [Mm]4 ,,'`" = "1.4.7" ] || die "msys dtk not installed correctly"
     fi
 }
 
@@ -211,6 +215,10 @@ function inst_active_perl() {
         echo "ActivePerl already installed.  skipping."
     else
         wget_unpacked $ACTIVE_PERL_URL $DOWNLOAD_DIR $ACTIVE_PERL_DIR
+        qpushd $_ACTIVE_PERL_UDIR
+            assert_one_dir ActivePerl-*
+            mv ActivePerl-* ActivePerl
+        qpopd
         quiet $INTLTOOL_PERL --help || die "ActivePerl not installed correctly"
     fi
 }
@@ -346,8 +354,11 @@ function inst_svn() {
     then
         echo "subversion already installed.  skipping."
     else
-        smart_wget $SVN_URL $DOWNLOAD_DIR
-        $LAST_FILE //SP- //SILENT //DIR="$SVN_DIR"
+        wget_unpacked $SVN_URL $DOWNLOAD_DIR $TMP_DIR
+        assert_one_dir $TMP_UDIR/svn-win32-*
+        mkdir -p $_SVN_UDIR
+        mv $TMP_UDIR/svn-win32-*/* $_SVN_UDIR
+        quiet svn --version || die "svn not installed correctly"
     fi
 }
 
@@ -463,8 +474,7 @@ function inst_gnome() {
     fi
     add_to_env "-I $_GNOME_UDIR/share/aclocal" ACLOCAL_FLAGS
     if quiet gconftool-2 --version &&
-        ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgnomeprint-2.2 libgnomeprintui-2.2 libgtkhtml-3.8 &&  # gnomeprint
-#        ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgnomeprint-2.2 libgtkhtml-3.14 &&  # not gnomeprint
+        quiet ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgtkhtml-3.14 &&
         quiet intltoolize --version
     then
         echo "gnome packages installed.  skipping."
@@ -480,8 +490,11 @@ function inst_gnome() {
         wget_unpacked $GLIB_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBJPEG_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBPNG_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $LIBPNG_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBTIFF_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $LIBTIFF_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $ZLIB_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $ZLIB_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $PKG_CONFIG_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $CAIRO_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $CAIRO_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
@@ -521,26 +534,20 @@ function inst_gnome() {
         wget_unpacked $LIBGNOMEUI_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBGLADE_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBGLADE_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $LIBGNOMEPRINT_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $LIBGNOMEPRINT_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $LIBGNOMEPRINTUI_URL $DOWNLOAD_DIR $GNOME_DIR  # gnomeprint
-        wget_unpacked $LIBGNOMEPRINTUI_DEV_URL $DOWNLOAD_DIR $GNOME_DIR  # gnomeprint
         wget_unpacked $GTKHTML_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $GTKHTML_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $GTK_DOC_URL $DOWNLOAD_DIR $TMP_DIR
         qpushd $_GNOME_UDIR
-            [ -f bin/zlib1.dll ] || mv zlib1.dll bin
-            if [ ! -f lib/libz.dll.a ]; then
-                qpushd bin
-                    ${DLLTOOL} -D zlib1.dll -d ../lib/zlib.def -l libz.dll.a
-                    mv libz.dll.a ../lib
-                qpopd
-            fi
+            assert_one_dir $TMP_UDIR/gtk-doc-*
+            mv $TMP_UDIR/gtk-doc-*/gtk-doc.m4 $_GNOME_UDIR/share/aclocal
             if [ ! -f libexec/gconfd-2.console.exe ]; then
                 cp libexec/gconfd-2.exe libexec/gconfd-2.console.exe
             fi
             exetype libexec/gconfd-2.exe windows
-#            sed 's#gtk+-unix-print-2.0 >= [0-9\.]* *##' lib/pkgconfig/libgtkhtml-3.14.pc > tmp  # not gnomeprint
-#            mv tmp lib/pkgconfig/libgtkhtml-3.14.pc  # not gnomeprint
+            for file in bin/intltool-*; do
+                sed '1s,!.*perl,!'"$INTLTOOL_PERL"',;s,/opt/gnu/bin/iconv,iconv,' $file > tmp
+                mv tmp $file
+            done
             # work around a bug in msys bash, adding 0x01 smilies
             cat > bin/pkg-config-msys.sh <<EOF
 #!/bin/sh
@@ -553,10 +560,11 @@ fi
 \${PKG_CONFIG} "\$@" | tr -d \\\\r && \$res
 EOF
             chmod +x bin/pkg-config{.exe,-msys.sh}
+            sed '/Requires/s,\(.*\) enchant\(.*\) iso-codes\(.*\),\1\2\3,' lib/pkgconfig/libgtkhtml-3.14.pc > tmp
+            mv tmp lib/pkgconfig/libgtkhtml-3.14.pc
         qpopd
         quiet gconftool-2 --version &&
-        ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgnomeprint-2.2 libgnomeprintui-2.2 libgtkhtml-3.8 &&  # gnomeprint
-#        ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgnomeprint-2.2 libgtkhtml-3.14 &&  # not gnomeprint
+        quiet ${PKG_CONFIG} --exists gconf-2.0 libgnome-2.0 libgnomeui-2.0 libgtkhtml-3.14 &&
         quiet intltoolize --version || die "gnome not installed correctly"
     fi
     if [ "$CROSS_COMPILE" = "yes" ]; then
@@ -564,11 +572,6 @@ EOF
             perl -pi.bak -e"s!^prefix=.*\$!prefix=$_GNOME_UDIR!" *.pc
             #perl -pi.bak -e's!^Libs: !Libs: -L\${prefix}/bin !' *.pc
         qpopd
-        # Latest gnome-dev packages don't ship with *.la files
-        # anymore. What do we do...?
-        #qpushd $_GNOME_UDIR/bin
-        #    for A in *-0.dll; do ln -sf $A `echo $A|sed 's/\(.*\)-0.dll/\1.dll/'`; done
-        #qpopd
     fi
 }
 
@@ -639,7 +642,7 @@ function inst_goffice() {
     _GOFFICE_UDIR=`unix_path $GOFFICE_DIR`
     add_to_env $_GOFFICE_UDIR/bin PATH
     add_to_env $_GOFFICE_UDIR/lib/pkgconfig PKG_CONFIG_PATH
-    if quiet ${PKG_CONFIG} --exists libgoffice-0.4
+    if quiet ${PKG_CONFIG} --exists libgoffice-0.8
     then
         echo "goffice already installed.  skipping."
     else
@@ -655,14 +658,14 @@ function inst_goffice() {
             automake
             autoconf
             ./configure ${HOST_XCOMPILE} --prefix=$_GOFFICE_UDIR \
-                CPPFLAGS="${GNOME_CPPFLAGS} ${PCRE_CPPFLAGS}" \
-                LDFLAGS="${GNOME_LDFLAGS} ${PCRE_LDFLAGS}"
+                CPPFLAGS="${GNOME_CPPFLAGS} ${PCRE_CPPFLAGS} ${HH_CPPFLAGS}" \
+                LDFLAGS="${GNOME_LDFLAGS} ${PCRE_LDFLAGS} ${HH_LDFLAGS}"
             [ -d ../libgsf-* ] || die "We need the unpacked package $TMP_UDIR/libgsf-*; please unpack it in $TMP_UDIR"
             [ -f dumpdef.pl ] || cp -p ../libgsf-*/dumpdef.pl .
             make
             make install
         qpopd
-        ${PKG_CONFIG} --exists libgoffice-0.4 || die "goffice not installed correctly"
+        ${PKG_CONFIG} --exists libgoffice-0.8 || die "goffice not installed correctly"
     fi
 }
 
@@ -753,6 +756,7 @@ function inst_opensp() {
         qpushd $TMP_UDIR/OpenSP-*
             [ -n "$OPENSP_PATCH" -a -f "$OPENSP_PATCH" ] && \
                 patch -p0 < $OPENSP_PATCH
+            libtoolize --force
             aclocal ${ACLOCAL_FLAGS} -I m4
             automake
             autoconf
@@ -970,8 +974,6 @@ function inst_gnucash() {
         if [ "$BUILD_FROM_TARBALL" != "yes" ]; then
             ./autogen.sh
         fi
-        # Windows DLLs don't need relinking
-        grep -v "need_relink=yes" ltmain.sh > ltmain.sh.new ; mv ltmain.sh.new ltmain.sh
     qpopd
 
     qpushd $BUILD_DIR
@@ -987,9 +989,6 @@ function inst_gnucash() {
             LDFLAGS="${AUTOTOOLS_LDFLAGS} ${REGEX_LDFLAGS} ${GNOME_LDFLAGS} ${GUILE_LDFLAGS} ${KTOBLZCHECK_LDFLAGS} ${HH_LDFLAGS}" \
             PKG_CONFIG_PATH="${PKG_CONFIG_PATH}"
 
-        # Windows DLLs don't need relinking
-        grep -v "need_relink=yes" libtool   > libtool.new   ; mv libtool.new   libtool
-
         make
 
         # Try to fix the paths in the "gnucash" script
@@ -1015,10 +1014,6 @@ function inst_gnucash() {
         for A in *.la; do
             sed '/dependency_libs/d' $A > tmp ; mv tmp $A
         done
-
-        # gettext 0.17 installs translations to \share\locale, but not all
-        # gnome packages have been recompiled against it
-        cp -a locale ../share && rm -rf locale
     qpopd
 
     qpushd $_INSTALL_UDIR/etc/gconf/schemas
@@ -1032,13 +1027,14 @@ function inst_gnucash() {
 
     # Create a startup script that works without the msys shell
     qpushd $_INSTALL_UDIR/bin
-        echo "setlocal" > gnucash.bat
-        echo "set PATH=${INSTALL_DIR}\\bin;${INSTALL_DIR}\\lib;${INSTALL_DIR}\\lib\\gnucash;${GOFFICE_DIR}\\bin;${LIBGSF_DIR}\\bin;${PCRE_DIR}\\bin;${GNOME_DIR}\\bin;${LIBXML2_DIR}\\bin;${GUILE_DIR}\\bin;${REGEX_DIR}\\bin;${AUTOTOOLS_DIR}\\bin;${AQBANKING_PATH};${LIBOFX_DIR}\\bin;${OPENSP_DIR}\\bin;%PATH%" >> gnucash.bat
-        echo "set GUILE_WARN_DEPRECATED=no" >> gnucash.bat
-        echo "set GNC_MODULE_PATH=${INSTALL_DIR}\\lib\\gnucash" >> gnucash.bat
-        echo "set GUILE_LOAD_PATH=${INSTALL_DIR}\\share\\gnucash\\guile-modules;${INSTALL_DIR}\\share\\gnucash\\scm;%GUILE_LOAD_PATH%" >> gnucash.bat
-        echo "set LTDL_LIBRARY_PATH=${INSTALL_DIR}\\lib" >> gnucash.bat
-        echo "start gnucash-bin %*" >> gnucash.bat
+        echo "setlocal" > gnucash.cmd
+        echo "set PATH=${INSTALL_DIR}\\bin;${INSTALL_DIR}\\lib;${INSTALL_DIR}\\lib\\gnucash;${GOFFICE_DIR}\\bin;${LIBGSF_DIR}\\bin;${PCRE_DIR}\\bin;${GNOME_DIR}\\bin;${GUILE_DIR}\\bin;${REGEX_DIR}\\bin;${AUTOTOOLS_DIR}\\bin;${AQBANKING_PATH};${LIBOFX_DIR}\\bin;${OPENSP_DIR}\\bin;%PATH%" >> gnucash.cmd
+        echo "set GUILE_WARN_DEPRECATED=no" >> gnucash.cmd
+        echo "set GNC_MODULE_PATH=${INSTALL_DIR}\\lib\\gnucash" >> gnucash.cmd
+        echo "set GUILE_LOAD_PATH=${INSTALL_DIR}\\share\\gnucash\\guile-modules;${INSTALL_DIR}\\share\\gnucash\\scm;%GUILE_LOAD_PATH%" >> gnucash.cmd
+        echo "set LTDL_LIBRARY_PATH=${INSTALL_DIR}\\lib" >> gnucash.cmd
+        echo "set SCHEME_LIBRARY_PATH=" >> gnucash.cmd
+        echo "start gnucash-bin %*" >> gnucash.cmd
     qpopd
 }
 
@@ -1092,11 +1088,13 @@ function inst_docs() {
         fi
         setup docs
         _DOCS_INST_UDIR=`unix_path $INSTALL_DIR`/share/gnucash/help
-        mkdir -p $_DOCS_INST_UDIR/{C,de_DE}
+        mkdir -p $_DOCS_INST_UDIR/{C,de_DE,it_IT}
         make_chm guide C
         make_chm guide de_DE
+        make_chm guide it_IT
         make_chm help C
         make_chm help de_DE
+        make_chm help it_IT
     qpopd
 }
 
