@@ -21,7 +21,6 @@
 
 #include <stdio.h>
 
-#include "Group.h"
 #include "gnc-component-manager.h"
 #include "qof.h"
 #include "gnc-ui-util.h"
@@ -51,9 +50,6 @@ typedef struct
   GNCComponentCloseHandler close_handler;
   gpointer user_data;
 
-  SCM refresh_handler_scm;
-  SCM close_handler_scm;
-
   ComponentEventInfo watch_info;
 
   char *component_class;
@@ -257,7 +253,7 @@ add_event_type (ComponentEventInfo *cei, GNCIdTypeConst entity_type,
 }
 
 static void
-gnc_cm_event_handler (QofEntity *entity,
+gnc_cm_event_handler (QofInstance *entity,
                       QofEventId event_type,
                       gpointer user_data,
 		      gpointer event_data)
@@ -404,9 +400,6 @@ gnc_register_gui_component_internal (const char * component_class)
   /* found one, add the handler */
   ci = g_new0 (ComponentInfo, 1);
 
-  ci->refresh_handler_scm = SCM_BOOL_F;
-  ci->close_handler_scm = SCM_BOOL_F;
-
   ci->watch_info.event_masks = g_hash_table_new (g_str_hash, g_str_equal);
   ci->watch_info.entity_events = guid_hash_table_new ();
 
@@ -453,32 +446,6 @@ gnc_register_gui_component (const char *component_class,
   return ci->component_id;
 }
 
-gint
-gnc_register_gui_component_scm (const char * component_class,
-                                SCM refresh_handler,
-                                SCM close_handler)
-{
-  ComponentInfo *ci;
-
-  /* sanity check */
-  if (!component_class)
-  {
-    PERR ("no class specified");
-    return NO_COMPONENT;
-  }
-
-  ci = gnc_register_gui_component_internal (component_class);
-  g_return_val_if_fail (ci, NO_COMPONENT);
-
-  ci->refresh_handler_scm = refresh_handler;
-  scm_gc_protect_object (refresh_handler);
-
-  ci->close_handler_scm = close_handler;
-  scm_gc_protect_object (close_handler);
-
-  return ci->component_id;
-}
-
 void
 gnc_gui_component_watch_entity (gint component_id,
                                 const GUID *entity,
@@ -579,14 +546,6 @@ gnc_unregister_gui_component (gint component_id)
   g_free (ci->component_class);
   ci->component_class = NULL;
 
-  if (ci->refresh_handler_scm != SCM_BOOL_F)
-    scm_gc_unprotect_object (ci->refresh_handler_scm);
-  ci->refresh_handler_scm = SCM_BOOL_F;
-
-  if (ci->close_handler_scm != SCM_BOOL_F)
-    scm_gc_unprotect_object (ci->close_handler_scm);
-  ci->close_handler_scm = SCM_BOOL_F;
-
   g_free (ci);
 
 #if CM_DEBUG
@@ -679,7 +638,7 @@ static gboolean
 changes_match (ComponentEventInfo *cei, ComponentEventInfo *changes)
 {
   ComponentEventInfo *big_cei;
-  GHashTable *small;
+  GHashTable *smalltable;
 
   if (cei == NULL)
     return FALSE;
@@ -693,18 +652,18 @@ changes_match (ComponentEventInfo *cei, ComponentEventInfo *changes)
   if (g_hash_table_size (cei->entity_events) <=
       g_hash_table_size (changes->entity_events))
   {
-    small = cei->entity_events;
+    smalltable = cei->entity_events;
     big_cei = changes;
   }
   else
   {
-    small = changes->entity_events;
+    smalltable = changes->entity_events;
     big_cei = cei;
   }
 
   big_cei->match = FALSE;
 
-  g_hash_table_foreach (small, match_helper, big_cei);
+  g_hash_table_foreach (smalltable, match_helper, big_cei);
 
   return big_cei->match;
 }
@@ -745,8 +704,7 @@ gnc_gui_refresh_internal (gboolean force)
     if (!ci)
       continue;
 
-    if (!ci->refresh_handler &&
-        !SCM_PROCEDUREP (ci->refresh_handler_scm)) {
+    if (!ci->refresh_handler) {
 #if CM_DEBUG
       fprintf (stderr, "no handlers for %s:%d\n", ci->component_class, ci->component_id);
 #endif
@@ -760,11 +718,6 @@ gnc_gui_refresh_internal (gboolean force)
 	fprintf (stderr, "calling %s:%d C handler\n", ci->component_class, ci->component_id);
 #endif
         ci->refresh_handler (NULL, ci->user_data);
-      } else {
-#if CM_DEBUG
-	fprintf (stderr, "calling %s:%d SCM handler\n", ci->component_class, ci->component_id);
-#endif
-        scm_call_0 (ci->refresh_handler_scm);
       }
     }
     else if (changes_match (&ci->watch_info, &changes_backup))
@@ -774,11 +727,6 @@ gnc_gui_refresh_internal (gboolean force)
 	fprintf (stderr, "calling %s:%d C handler\n", ci->component_class, ci->component_id);
 #endif
         ci->refresh_handler (changes_backup.entity_events, ci->user_data);
-      } else {
-#if CM_DEBUG
-	fprintf (stderr, "calling %s:%d SCM handler\n", ci->component_class, ci->component_id);
-#endif
-        scm_call_0 (ci->refresh_handler_scm);
       }
     }
     else
@@ -827,14 +775,11 @@ gnc_close_gui_component (gint component_id)
     return;
   }
 
-  if (!ci->close_handler &&
-      !SCM_PROCEDUREP (ci->close_handler_scm))
+  if (!ci->close_handler)
     return;
 
   if (ci->close_handler)
     ci->close_handler (ci->user_data);
-  else
-    scm_call_0 (ci->close_handler_scm);
 }
 
 void
