@@ -213,11 +213,14 @@ _get_vars_helper(Transaction *txn, void *var_hash_data)
         {
             GncSxVariable *var;
             GString *var_name;
+            const gchar *split_mnemonic, *first_mnemonic;
 
             var_name = g_string_sized_new(16);
+            split_mnemonic = gnc_commodity_get_mnemonic(split_cmdty);
+            first_mnemonic = gnc_commodity_get_mnemonic(first_cmdty);
             g_string_printf(var_name, "%s -> %s",
-                            gnc_commodity_get_mnemonic(split_cmdty),
-                            gnc_commodity_get_mnemonic(first_cmdty));
+                            split_mnemonic ? split_mnemonic : "(null)",
+                            first_mnemonic ? first_mnemonic : "(null)");
             var = gnc_sx_variable_new(g_strdup(var_name->str));
             g_hash_table_insert(var_hash, g_strdup(var->name), var);
             g_string_free(var_name, TRUE);
@@ -258,11 +261,10 @@ Account*
 gnc_sx_get_template_transaction_account(SchedXaction *sx)
 {
     Account *template_root, *sx_template_acct;
-    const char *sx_guid_str;
+    char sx_guid_str[GUID_ENCODING_LENGTH+1];
 
     template_root = gnc_book_get_template_root(gnc_get_current_book());
-    sx_guid_str = guid_to_string(xaccSchedXactionGetGUID(sx));
-    /* Get account named after guid string. */
+    guid_to_string_buff(xaccSchedXactionGetGUID(sx), sx_guid_str);
     sx_template_acct = gnc_account_lookup_by_name(template_root, sx_guid_str);
     return sx_template_acct;
 }
@@ -843,7 +845,7 @@ gnc_sx_instance_model_update_sx_instances(GncSxInstanceModel *model, SchedXactio
 
                     g_assert(parent_var != NULL);
                     var_copy = gnc_sx_variable_new_copy(parent_var);
-                    g_hash_table_insert(inst->variable_bindings, to_add_key, var_copy);
+                    g_hash_table_insert(inst->variable_bindings, g_strdup(to_add_key), var_copy);
                 }
             }
         }
@@ -919,13 +921,12 @@ _get_template_split_account(GncSxInstance *instance, Split *template_split, Acco
     *split_acct = xaccAccountLookup(acct_guid, gnc_get_current_book());
     if (*split_acct == NULL)
     {
-        const char *guid_str;
+        char guid_str[GUID_ENCODING_LENGTH+1];
         GString *err;
-        guid_str = guid_to_string((const GUID*)acct_guid);
+        guid_to_string_buff((const GUID*)acct_guid, guid_str);
         err = g_string_new("");
         g_string_printf(err, "Unknown account for guid [%s], cancelling SX [%s] creation.",
                         guid_str, xaccSchedXactionGetName(instance->parent->sx));
-        g_free((char*)guid_str);
         g_critical("%s", err->str);
         if (creation_errors != NULL)
             *creation_errors = g_list_append(*creation_errors, err);
@@ -1012,6 +1013,12 @@ create_each_transaction_helper(Transaction *template_txn, void *user_data)
     /* clear any copied KVP data */
     qof_instance_set_slots(QOF_INSTANCE(new_txn), kvp_frame_new());
 
+    /* Bug#500427: copy the notes, if any */
+    if (xaccTransGetNotes(template_txn) != NULL)
+    {
+        xaccTransSetNotes(new_txn, g_strdup(xaccTransGetNotes(template_txn)));
+    }
+
     xaccTransSetDate(new_txn,
                      g_date_get_day(&creation_data->instance->date),
                      g_date_get_month(&creation_data->instance->date),
