@@ -1161,18 +1161,6 @@ gnc_split_amount_print_info (Split *split, gboolean use_symbol)
   return gnc_account_print_info (xaccSplitGetAccount (split), use_symbol);
 }
 
-GNCPrintAmountInfo
-gnc_split_value_print_info (Split *split, gboolean use_symbol)
-{
-  Transaction *trans;
-
-  if (!split) return gnc_default_print_info (use_symbol);
-
-  trans = xaccSplitGetParent (split);
-
-  return gnc_commodity_print_info (xaccTransGetCurrency (trans), use_symbol);
-}
-
 static GNCPrintAmountInfo
 gnc_default_print_info_helper (int decplaces)
 {
@@ -1260,6 +1248,7 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
   char temp_buf[128];
   gnc_numeric whole, rounding;
   int min_dp, max_dp;
+  gboolean value_is_negative, value_is_decimal;
 
   g_return_val_if_fail (info != NULL, 0);
 
@@ -1270,9 +1259,13 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
     return 0;
   }
 
-  /* print the absolute value */
+  /* Print the absolute value, but remember negativity */
+  value_is_negative = gnc_numeric_negative_p (val);
   val = gnc_numeric_abs (val);
 
+  /* Try to print as decimal. */
+  value_is_decimal = gnc_numeric_to_decimal(&val, NULL);
+
   /* Force at least auto_decimal_places zeros */
   if (auto_decimal_enabled) {
     min_dp = MAX(auto_decimal_places, info->min_decimal_places);
@@ -1288,7 +1281,7 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
     max_dp = 99;
 
   /* rounding? -- can only ROUND if force_fit is also true */
-  if (info->round && info->force_fit) {
+  if (value_is_decimal && info->round && info->force_fit) {
     rounding.num = 5; /* Limit the denom to 10^13 ~= 2^44, leaving max at ~524288 */
     rounding.denom = pow(10, max_dp + 1);
     val = gnc_numeric_add(val, rounding, GNC_DENOM_AUTO, GNC_DENOM_LCD);
@@ -1382,22 +1375,26 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
 
   /* at this point, buf contains the whole part of the number */
 
-  /* If it's not decimal, print the fraction as an expression */
-  if (!is_decimal_fraction (val.denom, NULL))
+  /* If it's not decimal, print the fraction as an expression. */
+  if (!value_is_decimal)
   {
-    if (!gnc_numeric_zero_p (val))
-    {
-      val = gnc_numeric_reduce (val);
+    val = gnc_numeric_reduce (val);
 
-      if (val.denom > 0)
-          sprintf (temp_buf, " + %" G_GINT64_FORMAT " / %" G_GINT64_FORMAT,
-                   val.num, val.denom);
-      else
-          sprintf (temp_buf, " + %" G_GINT64_FORMAT " * %" G_GINT64_FORMAT,
-                   val.num, -val.denom);
+    if (val.denom > 0)
+        sprintf (temp_buf, "%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT,
+                 val.num, val.denom);
+    else
+        sprintf (temp_buf, "%" G_GINT64_FORMAT " * %" G_GINT64_FORMAT,
+                 val.num, -val.denom);
 
-      strcat (buf, temp_buf);
-    }
+    if (whole.num == 0)
+      *buf = '\0';
+    else if (value_is_negative)
+      strcat(buf, " - ");
+    else
+      strcat(buf, " + ");
+
+    strcat (buf, temp_buf);
   }
   else
   {
@@ -1474,6 +1471,7 @@ xaccSPrintAmount (char * bufp, gnc_numeric val, GNCPrintAmountInfo info)
 
    gboolean print_sign = TRUE;
    gboolean is_shares = FALSE;
+   gboolean print_absolute = FALSE;
 
    if (!bufp)
      return 0;
@@ -1561,10 +1559,15 @@ xaccSPrintAmount (char * bufp, gnc_numeric val, GNCPrintAmountInfo info)
 
    /* Now see if we print parentheses */
    if (print_sign && (sign_posn == 0))
+   {
      bufp = g_stpcpy(bufp, "(");
+     print_absolute = TRUE;
+   }
 
    /* Now print the value */
-   bufp += PrintAmountInternal(bufp, val, &info);
+   bufp += PrintAmountInternal(bufp,
+                               print_absolute? gnc_numeric_abs(val) : val,
+                               &info);
 
    /* Now see if we print parentheses */
    if (print_sign && (sign_posn == 0))
