@@ -17,6 +17,6 @@
 
 (define (gnc:hook-run-danglers hook . args)
   (if (null? args)
-      (set! args #f)
+      (set! args '())
       (set! args (car args)))
-  (gnc:hook-run-danglers-real hook args))
+  (gnc-hook-run hook args))
