@@ -18,7 +18,6 @@
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 
 (require 'hash-table)
-(use-modules (g-wrapped gw-core-utils))
 
 ;; (define gnc:*double-entry-restriction*
 ;;   (gnc:make-config-var
@@ -63,36 +62,36 @@
 ;;;;;; Create config vars
 
 (define gnc:*debit-strings*
-  (list (cons 'NO_TYPE   (N_ "Funds In"))
-        (cons 'BANK      (N_ "Deposit"))
-        (cons 'CASH      (N_ "Receive"))
-        (cons 'CREDIT    (N_ "Payment"))
-        (cons 'ASSET     (N_ "Increase"))
-        (cons 'LIABILITY (N_ "Decrease"))
-        (cons 'STOCK     (N_ "Buy"))
-        (cons 'MUTUAL    (N_ "Buy"))
-        (cons 'CURRENCY  (N_ "Buy"))
-        (cons 'INCOME    (N_ "Charge"))
-        (cons 'EXPENSE   (N_ "Expense"))
-	(cons 'PAYABLE   (N_ "Payment"))
-	(cons 'RECEIVABLE (N_ "Invoice"))
-        (cons 'EQUITY    (N_ "Decrease"))))
+  (list (cons ACCT-TYPE-NONE       (N_ "Funds In"))
+        (cons ACCT-TYPE-BANK       (N_ "Deposit"))
+        (cons ACCT-TYPE-CASH       (N_ "Receive"))
+        (cons ACCT-TYPE-CREDIT     (N_ "Payment"))
+        (cons ACCT-TYPE-ASSET      (N_ "Increase"))
+        (cons ACCT-TYPE-LIABILITY  (N_ "Decrease"))
+        (cons ACCT-TYPE-STOCK      (N_ "Buy"))
+        (cons ACCT-TYPE-MUTUAL     (N_ "Buy"))
+        (cons ACCT-TYPE-CURRENCY   (N_ "Buy"))
+        (cons ACCT-TYPE-INCOME     (N_ "Charge"))
+        (cons ACCT-TYPE-EXPENSE    (N_ "Expense"))
+        (cons ACCT-TYPE-PAYABLE    (N_ "Payment"))
+        (cons ACCT-TYPE-RECEIVABLE (N_ "Invoice"))
+        (cons ACCT-TYPE-EQUITY     (N_ "Decrease"))))
 
 (define gnc:*credit-strings*
-  (list (cons 'NO_TYPE   (N_ "Funds Out"))
-        (cons 'BANK      (N_ "Withdrawal"))
-        (cons 'CASH      (N_ "Spend"))
-        (cons 'CREDIT    (N_ "Charge"))
-        (cons 'ASSET     (N_ "Decrease"))
-        (cons 'LIABILITY (N_ "Increase"))
-        (cons 'STOCK     (N_ "Sell"))
-        (cons 'MUTUAL    (N_ "Sell"))
-        (cons 'CURRENCY  (N_ "Sell"))
-        (cons 'INCOME    (N_ "Income"))
-        (cons 'EXPENSE   (N_ "Rebate"))
-	(cons 'PAYABLE   (N_ "Bill"))
-	(cons 'RECEIVABLE (N_ "Payment"))
-        (cons 'EQUITY    (N_ "Increase"))))
+  (list (cons ACCT-TYPE-NONE       (N_ "Funds Out"))
+        (cons ACCT-TYPE-BANK       (N_ "Withdrawal"))
+        (cons ACCT-TYPE-CASH       (N_ "Spend"))
+        (cons ACCT-TYPE-CREDIT     (N_ "Charge"))
+        (cons ACCT-TYPE-ASSET      (N_ "Decrease"))
+        (cons ACCT-TYPE-LIABILITY  (N_ "Increase"))
+        (cons ACCT-TYPE-STOCK      (N_ "Sell"))
+        (cons ACCT-TYPE-MUTUAL     (N_ "Sell"))
+        (cons ACCT-TYPE-CURRENCY   (N_ "Sell"))
+        (cons ACCT-TYPE-INCOME     (N_ "Income"))
+        (cons ACCT-TYPE-EXPENSE    (N_ "Rebate"))
+        (cons ACCT-TYPE-PAYABLE    (N_ "Bill"))
+        (cons ACCT-TYPE-RECEIVABLE (N_ "Payment"))
+        (cons ACCT-TYPE-EQUITY     (N_ "Increase"))))
 
 (define (gnc:get-debit-string type)
   (_ (assoc-ref gnc:*debit-strings* type)))
