@@ -144,11 +144,17 @@ gnc_file_be_get_file_lock (FileBackend *be)
     if (rc)
     {
         /* If hard links aren't supported, just allow the lock. */
-        if (errno == EPERM
+        if (errno == EPERM || errno == ENOSYS
 # ifdef EOPNOTSUPP
-	    || errno == EOPNOTSUPP
+            || errno == EOPNOTSUPP
 # endif
-	    )
+# ifdef ENOTSUP
+            || errno == ENOTSUP
+# endif
+# ifdef ENOSYS
+            || errno == ENOSYS
+# endif
+            )
         {
             be->linkfile = NULL;
             return TRUE;
@@ -394,6 +400,7 @@ copy_file(const char *orig, const char *bkup)
 static gboolean
 gnc_int_link_or_make_backup(FileBackend *be, const char *orig, const char *bkup)
 {
+    gboolean copy_success = FALSE;
     int err_ret = 
 #ifdef HAVE_LINK
       link (orig, bkup)
@@ -404,17 +411,23 @@ gnc_int_link_or_make_backup(FileBackend *be, const char *orig, const char *bkup)
     if(err_ret != 0)
     {
 #ifdef HAVE_LINK
-        if(errno == EPERM
+        if(errno == EPERM || errno == ENOSYS
 # ifdef EOPNOTSUPP
-	   || errno == EOPNOTSUPP
+           || errno == EOPNOTSUPP
 # endif
-	   )
+# ifdef ENOTSUP
+           || errno == ENOTSUP
+# endif
+# ifdef ENOSYS
+           || errno == ENOSYS
+# endif
+            )
 #endif
         {
-            err_ret = copy_file(orig, bkup);
+            copy_success = copy_file(orig, bkup);
         }
 
-        if(!err_ret)
+        if(!copy_success)
         {
             qof_backend_set_error((QofBackend*)be, ERR_FILEIO_BACKUP_ERROR);
             PWARN ("unable to make file backup from %s to %s: %s", 
@@ -634,6 +647,7 @@ gnc_file_be_write_to_file(FileBackend *fbe,
             case ENOENT:     /* tmp_name doesn't exist?  Assume "RO" error */
             case EACCES:
             case EPERM:
+            case ENOSYS:
             case EROFS:
               be_err = ERR_BACKEND_READONLY;
               break;
