@@ -44,39 +44,7 @@
 
 #include "sixtp-dom-parsers.h"
 #include "SchedXaction.h"
-#include "FreqSpecP.h"
-
-/**
- * The XML output should look something like:
- * <freqspec>
- *   <fs:monthly>
- *     <fs:interval>2</fs:interval>
- *     <fs:offset>1</fs:offset>
- *     <fs:day>21</fs:day>
- *   </fs:monthly>
- *   <fs:id>...</fs:id>
- * </freqspec>
- *
- * <freqspec>
- *   
- *   <fs:composite>
- *     <freqspec>
- *       <fs:weekly>
- *         <fs:interval>2</fs:interval>
- *         <fs:offset>3</fs:offset>
- *       </fs:weekly>
- *     </freqspec>
- *     <freqspec>
- *       <fs:weekly>
- *         <fs:interval>2</fs:interval>
- *         <fs:offset>12</fs:offset>
- *       </fs:weekly>
- *     </freqspec>
- *   </fs:composite>
- *   <fs:id>...</fs:id>
- * </freqspec>
- *
- **/
+#include "FreqSpec.h"
 
 const gchar *freqspec_version_string = "1.0.0";
 
@@ -122,9 +90,11 @@ struct uiFreqTypeTuple uiFreqTypeStrs[] = {
  **/
 typedef struct
 {
-        FreqSpec        *fs;              /* FreqSpec we're parsing into. */
         QofBook         *book;            /* Book we're loading into. */
 
+        Recurrence *recurrence;
+        GList *recurrence_list;
+
         /* fields used in the union of unions... :) */
         GDate                 once_day;     /* once */
         gint64                interval;     /* all [except once] */
@@ -132,14 +102,17 @@ typedef struct
         gint64                day;          /* monthly or month-relative */
         gint64                occurrence;   /* month-relative */
         GList                *list;         /* composite */
+        UIFreqType            uift;
 } fsParseData;
 
 static void
 fspd_init( fsParseData *fspd )
 {
-        fspd->fs      = NULL;
         fspd->list    = NULL;
         fspd->book    = NULL;
+        fspd->recurrence = g_new0(Recurrence, 1);
+        fspd->recurrence_list = NULL;
+        fspd->uift = UIFREQ_NONE;
         fspd->interval
                 = fspd->offset
                 = fspd->day
@@ -148,131 +121,6 @@ fspd_init( fsParseData *fspd )
         g_date_clear( &fspd->once_day, 1 );
 }
 
-xmlNodePtr
-gnc_freqSpec_dom_tree_create( FreqSpec *fs )
-{
-        xmlNodePtr                ret;
-        xmlNodePtr                xmlSub;
-
-        ret = xmlNewNode( NULL, BAD_CAST "gnc:freqspec" );
-        xmlSetProp( ret, BAD_CAST "version", BAD_CAST freqspec_version_string );
-
-        xmlAddChild( ret, guid_to_dom_tree( "fs:id", &fs->entity.guid ) );
-
-        xmlSub = text_to_dom_tree( "fs:ui_type",
-                                   uiFreqTypeStrs[ xaccFreqSpecGetUIType(fs) ].str );
-        xmlAddChild( ret, xmlSub );
-
-        switch( fs->type ) {
-
-        case INVALID: {
-                xmlSub = xmlNewNode( NULL, BAD_CAST "fs:none" );
-        } break;
-
-        case ONCE: {
-                xmlSub = xmlNewNode( NULL, BAD_CAST "fs:once" );
-                xmlAddChild( xmlSub, 
-                             gdate_to_dom_tree( "fs:date", 
-                                                &fs->s.once.date ) );
-                xmlAddChild( ret, xmlSub );
-        } break;
-
-        case DAILY: {
-                        xmlSub = xmlNewNode( NULL, BAD_CAST "fs:daily" );
-                        xmlAddChild( xmlSub, 
-                                     guint_to_dom_tree(
-                                             "fs:interval", 
-                                             fs->s.daily.interval_days )
-                                );
-                        xmlAddChild( xmlSub, 
-                                     guint_to_dom_tree( 
-                                             "fs:offset", 
-                                             fs->s.daily.offset_from_epoch )
-                                );
-                        xmlAddChild( ret, xmlSub );
-        } break;
-        
-        case WEEKLY: {
-                xmlSub = xmlNewNode( NULL, BAD_CAST "fs:weekly" );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:interval", 
-                                     fs->s.weekly.interval_weeks )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:offset", 
-                                     fs->s.weekly.offset_from_epoch )
-                        );
-                xmlAddChild( ret, xmlSub );
-        } break;
-        
-        case MONTHLY: {
-                xmlSub = xmlNewNode( NULL, BAD_CAST "fs:monthly" );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:interval", 
-                                     fs->s.monthly.interval_months )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:offset", 
-                                     fs->s.monthly.offset_from_epoch )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:day", 
-                                     fs->s.monthly.day_of_month )
-                        );
-                        xmlAddChild( ret, xmlSub );
-        } break;
-        
-        case MONTH_RELATIVE: {
-                xmlSub = xmlNewNode( NULL, BAD_CAST "fs:month_relative" );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:interval", 
-                                     fs->s.month_relative.interval_months )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:offset", 
-                                     fs->s.month_relative.offset_from_epoch )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:weekday", 
-                                     fs->s.month_relative.weekday )
-                        );
-                xmlAddChild( xmlSub, 
-                             guint_to_dom_tree( 
-                                     "fs:occurrence", 
-                                     fs->s.month_relative.occurrence )
-                        );
-                xmlAddChild( ret, xmlSub );
-        } break;
-        
-        case COMPOSITE: {
-                GList *subelts;
-                xmlNodePtr xmlComposites;
-                xmlComposites = xmlNewNode( NULL, BAD_CAST "fs:composite" );
-                subelts = fs->s.composites.subSpecs;
-                while( subelts ) {
-                        xmlAddChild( xmlComposites,
-                                     gnc_freqSpec_dom_tree_create(
-                                             subelts->data ) );
-                        subelts = subelts->next;
-                }
-                xmlAddChild( ret, xmlComposites );
-        } break;
-        
-        default:
-                g_return_val_if_fail( FALSE, NULL );
-        }
-        
-        return ret;
-}
-
 static struct dom_tree_handler fs_dom_handlers[];
 
 static
@@ -296,7 +144,7 @@ fs_uift_handler( xmlNodePtr node, gpointer data)
         g_return_val_if_fail( nodeTxt, FALSE );
         for ( i=0; (tmp = uiFreqTypeStrs[i].str) != NULL; i++ ) {
                 if ( safe_strcmp( nodeTxt, tmp ) == 0 ) {
-                        xaccFreqSpecSetUIType( fspd->fs, uiFreqTypeStrs[i].uift );
+                        fspd->uift = uiFreqTypeStrs[i].uift;
                         g_free( nodeTxt );
                         return TRUE;
                 }
@@ -398,11 +246,27 @@ gboolean
 fs_subelement_handler( xmlNodePtr node, gpointer data )
 {
         fsParseData *fspd = data;
-        FreqSpec        *fs;
-        fs = dom_tree_to_freqSpec( node, fspd->book );
-        if ( fs == NULL )
+        GList *recurrences;
+
+        recurrences = dom_tree_freqSpec_to_recurrences(node, fspd->book);
+        if (recurrences == NULL)
                 return FALSE;
-        fspd->list = g_list_append( fspd->list, fs );
+
+        {
+            GList *r_iter;
+            for (r_iter = recurrences; r_iter != NULL; r_iter = r_iter->next)
+            {
+                Recurrence *r = (Recurrence*)r_iter->data;
+                GDate recurrence_date;
+                if (fspd->uift == UIFREQ_SEMI_MONTHLY)
+                {
+                    // complementry hack around 'once' freqspects not being valid. :/
+                    recurrence_date = recurrenceGetDate(r);
+                    recurrenceSet(r, recurrenceGetMultiplier(r), PERIOD_MONTH, &recurrence_date);
+                }
+                fspd->recurrence_list = g_list_append(fspd->recurrence_list, r);
+            }
+        }
         return TRUE;
 }
 
@@ -417,8 +281,7 @@ struct dom_tree_handler fs_union_dom_handlers[] = {
         { NULL, NULL, 0, 0 },
 };
 
-static
-gboolean
+static gboolean
 fs_none_handler( xmlNodePtr node, gpointer data )
 {
         fsParseData *fspd = data;
@@ -426,10 +289,7 @@ fs_none_handler( xmlNodePtr node, gpointer data )
         successful = dom_tree_generic_parse( node,
                                              fs_union_dom_handlers,
                                              fspd );
-        if ( !successful )
-                return FALSE;
-        fspd->fs->type	      = INVALID;
-        return TRUE;
+        return successful;
 }
 
 static
@@ -444,25 +304,25 @@ fs_once_handler( xmlNodePtr node, gpointer data )
                                              fspd );
         if ( !successful )
                 return FALSE;
-        fspd->fs->type         = ONCE;
-        fspd->fs->s.once.date  = fspd->once_day;
+        recurrenceSet(fspd->recurrence, 0, PERIOD_ONCE, &fspd->once_day);
+        
         return TRUE;
 }
 
-static
-gboolean
-fs_daily_handler( xmlNodePtr node, gpointer data)
+static gboolean
+fs_daily_handler(xmlNodePtr node, gpointer data)
 {
         fsParseData *fspd = data;
+        GDate offset_date;
         gboolean        successful;
-        successful = dom_tree_generic_parse( node,
-                                             fs_union_dom_handlers,
-                                             fspd );
-        if ( !successful )
-                return FALSE;
-        fspd->fs->type                      = DAILY;
-        fspd->fs->s.daily.interval_days     = fspd->interval;
-        fspd->fs->s.daily.offset_from_epoch = fspd->offset;
+        successful = dom_tree_generic_parse(node, fs_union_dom_handlers, fspd );
+        if (!successful)
+             return FALSE;
+
+        g_date_clear(&offset_date, 1);
+        g_date_set_julian(&offset_date, fspd->offset == 0 ? 7 : fspd->offset);
+        recurrenceSet(fspd->recurrence, fspd->interval, PERIOD_DAY, &offset_date);
+
         return TRUE;
 }
 
@@ -471,15 +331,18 @@ gboolean
 fs_weekly_handler( xmlNodePtr node, gpointer data )
 {
         fsParseData *fspd = data;
+        GDate offset_date;
         gboolean        successful;
         successful = dom_tree_generic_parse( node,
                                              fs_union_dom_handlers,
                                              fspd );
         if ( !successful )
                 return FALSE;
-        fspd->fs->type                       = WEEKLY;
-        fspd->fs->s.weekly.interval_weeks    = fspd->interval;
-        fspd->fs->s.weekly.offset_from_epoch = fspd->offset;
+
+        g_date_clear(&offset_date, 1);
+        g_date_set_julian(&offset_date, fspd->offset == 0 ? 7 : fspd->offset);
+        recurrenceSet(fspd->recurrence, fspd->interval, PERIOD_WEEK, &offset_date);
+
         return TRUE;
 }
 
@@ -488,16 +351,29 @@ gboolean
 fs_monthly_handler( xmlNodePtr node, gpointer data)
 {
         fsParseData *fspd = data;
+        GDate offset_date;
         gboolean        successful;
         successful = dom_tree_generic_parse( node,
                                              fs_union_dom_handlers,
                                              fspd );
         if ( !successful )
                 return FALSE;
-        fspd->fs->type                        = MONTHLY;
-        fspd->fs->s.monthly.interval_months   = fspd->interval;
-        fspd->fs->s.monthly.offset_from_epoch = fspd->offset;
-        fspd->fs->s.monthly.day_of_month      = fspd->day;
+
+
+        g_date_clear(&offset_date, 1);
+        g_date_set_julian(&offset_date, 1);
+        g_date_add_months(&offset_date, fspd->offset);
+        g_date_set_day(&offset_date, fspd->day);
+        if (fspd->uift == UIFREQ_ONCE)
+        {
+            // hack...
+            recurrenceSet(fspd->recurrence, fspd->interval, PERIOD_ONCE, &offset_date);
+        }
+        else
+        {
+            recurrenceSet(fspd->recurrence, fspd->interval, PERIOD_MONTH, &offset_date);
+        }
+        
         return successful;
 }
 
@@ -505,19 +381,8 @@ static
 gboolean
 fs_month_relative_handler( xmlNodePtr node, gpointer data)
 {
-        fsParseData *fspd = data;
-        gboolean        successful;
-        successful = dom_tree_generic_parse( node,
-                                             fs_union_dom_handlers,
-                                             fspd );
-        if ( !successful )
-                return FALSE;
-        fspd->fs->type                               = MONTH_RELATIVE;
-        fspd->fs->s.month_relative.interval_months   = fspd->interval;
-        fspd->fs->s.month_relative.offset_from_epoch = fspd->offset;
-        fspd->fs->s.month_relative.weekday           = fspd->day;
-        fspd->fs->s.month_relative.occurrence        = fspd->occurrence;
-        return TRUE;
+        g_critical("this was never supported, how is it in the datafile?");
+        return FALSE;
 }
 
 static
@@ -527,7 +392,6 @@ fs_guid_handler( xmlNodePtr node, gpointer data)
         fsParseData *fspd = data;
         GUID        *guid;
         guid = dom_tree_to_guid( node );
-        fspd->fs->entity.guid = *guid;
         return TRUE;
 }
 
@@ -540,11 +404,7 @@ fs_composite_handler( xmlNodePtr node, gpointer data)
         successful = dom_tree_generic_parse( node,
                                              fs_union_dom_handlers,
                                              fspd );
-        if ( !successful )
-                return FALSE;
-        fspd->fs->type                  = COMPOSITE;
-        fspd->fs->s.composites.subSpecs = fspd->list;
-        return TRUE;
+        return successful;
 }
 
 static struct dom_tree_handler fs_dom_handlers[] = {
@@ -586,11 +446,9 @@ gnc_freqSpec_end_handler(gpointer data_for_children,
 
         g_return_val_if_fail( tree, FALSE );
 
-        fspd.fs = xaccFreqSpecMalloc(globaldata->book);
         successful = dom_tree_generic_parse( tree, fs_dom_handlers, &fspd );
         if (!successful) {
                 xmlElemDump( stdout, NULL, tree );
-                xaccFreqSpecFree( fspd.fs );
         }
 
         xmlFreeNode(tree);
@@ -604,21 +462,28 @@ gnc_freqSpec_sixtp_parser_create(void)
     return sixtp_dom_parser_new( gnc_freqSpec_end_handler, NULL, NULL );
 }
 
-FreqSpec*
-dom_tree_to_freqSpec(xmlNodePtr node, QofBook *book)
+static void
+common_parse(fsParseData *fspd, xmlNodePtr node, QofBook *book)
 {
     gboolean        successful;
-    fsParseData        fspd;
 
-    fspd_init( &fspd );
-    fspd.book = book;
-
-    fspd.fs = xaccFreqSpecMalloc(book);
-    successful = dom_tree_generic_parse( node, fs_dom_handlers, &fspd );
-    if ( !successful ) {
+    fspd->book = book;
+    successful = dom_tree_generic_parse( node, fs_dom_handlers, fspd );
+    if (!successful)
+    {
         xmlElemDump(stdout, NULL, node);
-        xaccFreqSpecFree( fspd.fs );
-        fspd.fs = NULL;
     }
-    return fspd.fs;
+}
+
+GList*
+dom_tree_freqSpec_to_recurrences(xmlNodePtr node, QofBook *book)
+{
+    fsParseData        fspd;
+    fspd_init( &fspd );
+    common_parse(&fspd, node, book);
+    if (fspd.recurrence_list == NULL)
+    {
+        fspd.recurrence_list = g_list_append(fspd.recurrence_list, fspd.recurrence);
+    }
+    return fspd.recurrence_list;
 }
