@@ -47,6 +47,14 @@
 #include "gnc-xml.h"
 #include "io-utils.h"
 
+/* Do not treat -Wstrict-aliasing warnings as errors because of problems of the
+ * G_LOCK* macros as declared by glib.  See
+ * http://bugzilla.gnome.org/show_bug.cgi?id=316221 for additional information.
+ */
+#if (__GNUC__ >= 4 && __GNUC_MINOR__ >= 2)
+#    pragma GCC diagnostic warning "-Wstrict-aliasing"
+#endif
+
 static QofLogModule log_module = GNC_MOD_IO;
 
 /* map pointers, e.g. of type FILE*, to GThreads */
@@ -277,19 +285,8 @@ add_template_transaction_local( sixtp_gdv2 *data,
     /* . transactions in those accounts. */
     for ( n = txd->accts; n; n = n->next ) {
         if ( gnc_account_get_parent( (Account*)n->data ) == NULL ) {
-            /* remove the gnc_book_init-created account of the same name */
-            acctRoot = gnc_book_get_template_root(book);
-            tmpAcct = gnc_account_lookup_by_name( acctRoot,
-                                    xaccAccountGetName( (Account*)n->data ) );
-            if ( tmpAcct != NULL ) {
-/* XXX hack alert FIXME .... Should this be 'Remove', or 'Destroy'?
- * If we just remove, then this seems to be a memory leak to me, since
- * it is never reparented.  Shouldn't it be a Destroy ???
- */
-                gnc_account_remove_child( acctRoot, tmpAcct );
-            }
-
-            gnc_account_append_child( acctRoot, (Account*)n->data );
+            /* replace the gnc_book_init-created root account */
+            gnc_book_set_template_root(book, (Account *)n->data);
         }
 
     }
