@@ -28,7 +28,6 @@
 
 #include "gnc-xml-helper.h"
 
-#include "FreqSpec.h"
 #include "gnc-commodity.h"
 #include "qof.h"
 #include "gnc-budget.h"
@@ -38,7 +37,7 @@ GUID* dom_tree_to_guid(xmlNodePtr node);
 gnc_commodity* dom_tree_to_commodity_ref(xmlNodePtr node, QofBook *book);
 gnc_commodity *dom_tree_to_commodity_ref_no_engine(xmlNodePtr node, QofBook *);
 
-FreqSpec* dom_tree_to_freqSpec( xmlNodePtr node, QofBook *book);
+GList* dom_tree_freqSpec_to_recurrences(xmlNodePtr node, QofBook *book);
 Recurrence* dom_tree_to_recurrence(xmlNodePtr node);
 
 Timespec dom_tree_to_timespec(xmlNodePtr node);
