@@ -1,8 +1,8 @@
 #include "config.h"
 
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <libguile.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 
@@ -178,7 +178,7 @@ test_generation(void)
         
         filename1 = g_strdup_printf("test_file_XXXXXX");
         
-        fd = mkstemp(filename1);
+        fd = g_mkstemp(filename1);
         
         write_dom_node_to_file(test_node, fd);
 
@@ -204,7 +204,7 @@ test_generation(void)
             /* sixtp_destroy(parser); */
         }
 
-        unlink(filename1);
+        g_unlink(filename1);
         g_free(filename1);
         gnc_commodity_destroy(ran_com);
         xmlFreeNode(test_node);
@@ -222,11 +222,10 @@ test_real_commodity(const char *tag, gpointer globaldata, gpointer data)
     return TRUE;
 }
 
-static void
-guile_main (void *closure, int argc, char **argv)
+int
+main(int argc, char **argv)
 {
-    gnc_module_system_init();
-    gnc_module_load("gnucash/engine", 0);
+    gnc_engine_init(argc, argv);
 
     book = qof_book_new ();
 
@@ -244,10 +243,3 @@ guile_main (void *closure, int argc, char **argv)
     print_test_results();
     exit(get_rv());
 }
-
-int
-main (int argc, char ** argv)
-{
-  scm_boot_guile (argc, argv, guile_main, NULL);
-  return 0;
-}
