@@ -37,7 +37,6 @@
 #include <gmodule.h>
 #include <libpq-fe.h>
 
-#include "Group.h"
 #include "qof.h"
 #include "Transaction.h"
 
@@ -134,7 +133,7 @@ QofBook * pgendGetBook(PGBackend *pbe);
 void pgendDisable (PGBackend *be);
 void pgendEnable (PGBackend *be);
 
-G_MODULE_EXPORT const gchar *
-g_module_check_init(GModule *module);
+G_MODULE_EXPORT void
+qof_backend_module_init(void);
 
 #endif /* POSTGRES_BACKEND_H */
