@@ -1,4 +1,4 @@
-/********************************************************************\
+/********************************************************************	\
  * events.c -- implements event handling for postgres backend       *
  * Copyright (c) 2001 Linas Vepstas <linas@linas.org>               *
  *                                                                  *
@@ -259,7 +259,7 @@ pgendProcessEvents (QofBackend *bend)
    {
       Event *ev = (Event *) node->data;
       QofIdType local_obj_type;
-      QofEntity *ent;
+      QofInstance *ent;
 
       ent = NULL;
       /* lets see if the local cache has this item in it */
@@ -290,17 +290,14 @@ pgendProcessEvents (QofBackend *bend)
 
                /* if the remote user created an account, mirror it here */
                acc = pgendCopyAccountToEngine (be, &(ev->guid));
-               xaccGroupMarkSaved (xaccAccountGetRoot(acc));
-               ent = (QofEntity*)acc;
+               ent = QOF_INSTANCE(acc);
                break;
             }
             case QOF_EVENT_DESTROY: {
                Account * acc = pgendAccountLookup (be, &(ev->guid));
-               AccountGroup *topgrp = xaccAccountGetRoot(acc);
                xaccAccountBeginEdit (acc);
                xaccAccountDestroy (acc);
-               xaccGroupMarkSaved (topgrp);
-               ent = (QofEntity*)acc;
+               ent = QOF_INSTANCE(acc);
                break;
             }
          }
@@ -322,7 +319,7 @@ pgendProcessEvents (QofBackend *bend)
                /* don't mirror transaction creations. If a register needs
                 * it, it will do a query. */
                trans = pgendTransLookup (be, &(ev->guid));
-               ent = (QofEntity*)trans;
+               ent = QOF_INSTANCE(trans);
                PINFO ("create transaction");
                break;
 			}
@@ -330,7 +327,7 @@ pgendProcessEvents (QofBackend *bend)
                Transaction *trans;
                trans = pgendTransLookup (be, &(ev->guid));
                pgendCopyTransactionToEngine (be, &(ev->guid));
-               ent = (QofEntity*)trans;
+               ent = QOF_INSTANCE(trans);
                break;
 			}
             case QOF_EVENT_DESTROY: {
@@ -339,7 +336,7 @@ pgendProcessEvents (QofBackend *bend)
                /* mark trans for freeing */
                xaccTransDestroy (trans);
                xaccTransCommitEdit (trans);
-               ent = (QofEntity*)trans;
+               ent = QOF_INSTANCE(trans);
                break;
             }
          }
