@@ -38,7 +38,7 @@ struct _gncAddress
   QofInstance inst;
 
   QofBook *	book;
-  QofEntity * parent;
+  QofInstance * parent;
   gboolean	dirty;
   char *	name;
   char *	addr1;
@@ -50,6 +50,13 @@ struct _gncAddress
   char *	email;
 };
 
+struct _gncAddressClass
+{
+  QofInstanceClass parent_class;
+};
+
+static QofLogModule log_module = GNC_MOD_BUSINESS;
+
 #define _GNC_MOD_NAME	GNC_ADDRESS_MODULE_NAME
 
 G_INLINE_FUNC void mark_address (GncAddress *address);
@@ -60,17 +67,35 @@ void mark_address (GncAddress *address)
   qof_event_gen (address->parent, QOF_EVENT_MODIFY, NULL);
 }
 
+/* GObject Initialization */
+QOF_GOBJECT_IMPL(gnc_address, GncAddress, QOF_TYPE_INSTANCE);
+
+static void
+gnc_address_init(GncAddress* addr)
+{
+}
+
+static void
+gnc_address_dispose_real (GObject *addrp)
+{
+}
+
+static void
+gnc_address_finalize_real(GObject* addrp)
+{
+}
+
 /* Create/Destroy functions */
 
 GncAddress * 
-gncAddressCreate (QofBook *book, QofEntity *prnt)
+gncAddressCreate (QofBook *book, QofInstance *prnt)
 {
   GncAddress *addr;
 
   if (!book) return NULL;
 
-  addr = g_new0 (GncAddress, 1);
-  qof_instance_init(&addr->inst, GNC_ID_ADDRESS, book);
+  addr = g_object_new (GNC_TYPE_ADDRESS, NULL);
+  qof_instance_init_data(&addr->inst, GNC_ID_ADDRESS, book);
   addr->book = book;
   addr->dirty = FALSE;
   addr->parent = prnt;
@@ -95,13 +120,13 @@ qofAddressCreate (QofBook *book)
 }
 
 static void
-qofAddressSetOwner(GncAddress *addr, QofEntity *ent)
+qofAddressSetOwner(GncAddress *addr, QofInstance *ent)
 {
 	if(!addr || !ent) { return; }
 	if(addr->parent == NULL) { addr->parent = ent; }
 }
 
-static QofEntity*
+static QofInstance*
 qofAddressGetOwner(GncAddress *addr)
 {
 
@@ -110,13 +135,14 @@ qofAddressGetOwner(GncAddress *addr)
 }
 
 GncAddress * 
-gncCloneAddress (GncAddress *from, QofEntity *new_parent, QofBook *book)
+gncCloneAddress (GncAddress *from, QofInstance *new_parent, QofBook *book)
 {
   GncAddress *addr;
 
   if (!book) return NULL;
 
-  addr = g_new0 (GncAddress, 1);
+  addr = g_object_new (GNC_TYPE_ADDRESS, NULL);
+  qof_instance_init_data(&addr->inst, GNC_ID_ADDRESS, book);
   addr->book = book;
   addr->dirty = TRUE;
   addr->parent = new_parent;
@@ -137,6 +163,16 @@ void
 gncAddressDestroy (GncAddress *addr)
 {
   if (!addr) return;
+  qof_instance_set_destroying(addr, TRUE);
+  gncAddressCommitEdit (addr);
+}
+
+static void
+gncAddressFree (GncAddress *addr)
+{
+  if (!addr) return;
+
+  qof_event_gen (&addr->inst, QOF_EVENT_DESTROY, NULL);
 
   CACHE_REMOVE (addr->name);
   CACHE_REMOVE (addr->addr1);
@@ -147,16 +183,19 @@ gncAddressDestroy (GncAddress *addr)
   CACHE_REMOVE (addr->fax);
   CACHE_REMOVE (addr->email);
 
-  g_free (addr);
+  /* qof_instance_release (&addr->inst); */
+  g_object_unref (addr);
 }
 
+
 /* Set functions */
 
-#define SET_STR(member, str) { \
+#define SET_STR(obj, member, str) { \
 	char * tmp; \
 	\
 	if (member == str) return; \
 	if (!safe_strcmp (member, str)) return; \
+	gncAddressBeginEdit (obj); \
 	tmp = CACHE_INSERT (str); \
 	CACHE_REMOVE (member); \
 	member = tmp; \
@@ -166,66 +205,100 @@ void gncAddressSetName (GncAddress *addr, const char *name)
 {
   if (!addr) return;
   if (!name) return;
-  SET_STR(addr->name, name);
+  SET_STR(addr, addr->name, name);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetAddr1 (GncAddress *addr, const char *addr1)
 {
   if (!addr) return;
   if (!addr1) return;
-  SET_STR(addr->addr1, addr1);
+  SET_STR(addr, addr->addr1, addr1);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetAddr2 (GncAddress *addr, const char *addr2)
 {
   if (!addr) return;
   if (!addr2) return;
-  SET_STR(addr->addr2, addr2);
+  SET_STR(addr, addr->addr2, addr2);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetAddr3 (GncAddress *addr, const char *addr3)
 {
   if (!addr) return;
   if (!addr3) return;
-  SET_STR(addr->addr3, addr3);
+  SET_STR(addr, addr->addr3, addr3);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetAddr4 (GncAddress *addr, const char *addr4)
 {
   if (!addr) return;
   if (!addr4) return;
-  SET_STR(addr->addr4, addr4);
+  SET_STR(addr, addr->addr4, addr4);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetPhone (GncAddress *addr, const char *phone)
 {
   if (!addr) return;
   if (!phone) return;
-  SET_STR(addr->phone, phone);
+  SET_STR(addr, addr->phone, phone);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetFax (GncAddress *addr, const char *fax)
 {
   if (!addr) return;
   if (!fax) return;
-  SET_STR(addr->fax, fax);
+  SET_STR(addr, addr->fax, fax);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
 void gncAddressSetEmail (GncAddress *addr, const char *email)
 {
   if (!addr) return;
   if (!email) return;
-  SET_STR(addr->email, email);
+  SET_STR(addr, addr->email, email);
   mark_address (addr);
+  gncAddressCommitEdit (addr);
 }
 
+void gncAddressBeginEdit (GncAddress *addr)
+{
+  qof_begin_edit (&addr->inst);
+}
+
+static void gncAddressOnError (QofInstance *inst, QofBackendError errcode)
+{
+  PERR("Address QofBackend Failure: %d", errcode);
+}
+  
+static void gncAddressOnDone (QofInstance *addr) { }
+
+static void address_free (QofInstance *inst)
+{
+  GncAddress *addr = (GncAddress *) inst;
+  gncAddressFree (addr);
+}
+
+void gncAddressCommitEdit (GncAddress *addr)
+{
+  if (!qof_commit_edit (QOF_INSTANCE(addr))) return;
+  qof_commit_edit_part2 (&addr->inst, gncAddressOnError,
+                         gncAddressOnDone, address_free);
+}
+             
+
 /* Get Functions */
 
 const char * gncAddressGetName (const GncAddress *addr)
