@@ -24,6 +24,7 @@
  *
  *********************************************************************/
 
+#include "config.h"
 #include <glib.h>
 #include "qof.h"
 #include "cashobjects.h"
@@ -207,18 +208,13 @@ test_bool_fcn (QofBook *book, const char *message,
 int
 main (int argc, char **argv)
 {
-  guid_init ();
-  qof_query_init ();
-  qof_object_initialize ();
-  qof_book_register ();
+  qof_init();
   do_test (cashobjects_register(), "Cannot register cash objects");
   do_test (gncInvoiceRegister(), "Cannot register GncInvoice");
   do_test (gncJobRegister (),  "Cannot register GncJob");
   do_test (gncCustomerRegister(), "Cannot register GncCustomer");
   test_customer();
   print_test_results();
-  qof_query_shutdown();
-  guid_shutdown();
-  qof_object_shutdown ();
+  qof_close ();
   return 0;
 }
