@@ -24,6 +24,7 @@
  *
  *********************************************************************/
 
+#include "config.h"
 #include <glib.h>
 #include "qof.h"
 #include "gncEmployeeP.h"
@@ -216,19 +217,14 @@ test_gint_fcn (QofBook *book, const char *message,
 
 int
 main (int argc, char **argv)
-{
-  guid_init ();
-  qof_query_init ();
-  qof_object_initialize ();
-  qof_book_register ();
+{ 
+  qof_init();
   do_test (gncInvoiceRegister(), "Cannot register GncInvoice");
   do_test (gncJobRegister (),  "Cannot register GncJob");
   do_test (gncCustomerRegister(), "Cannot register GncCustomer");
   do_test (gncEmployeeRegister(), "Cannot register GncEmployee");
   test_employee();
   print_test_results();
-  qof_query_shutdown();
-  guid_shutdown();
-  qof_object_shutdown ();
+  qof_close();
   return 0;
 }
