@@ -77,7 +77,7 @@
  * emits a warning that the guid null pointer test is always true.
  */
 #if (__GNUC__ >= 4 && __GNUC_MINOR__ >= 2)
-#    pragma GCC diagnostic ignored "-Waddress"
+#    pragma GCC diagnostic warning "-Waddress"
 #endif
 
 #define DIALOG_NEW_INVOICE_CM_CLASS "dialog-new-invoice"
@@ -581,7 +581,7 @@ gnc_invoice_window_printCB (GtkWidget *widget, gpointer data)
 
   arg = scm_apply (func, args, SCM_EOL);
   g_return_if_fail (SCM_EXACTP (arg));
-  report_id = scm_num2int (arg, SCM_ARG1, __FUNCTION__);
+  report_id = scm_num2int (arg, SCM_ARG1, G_STRFUNC);
 
   /* scm_gc_unprotect_object(func); */
   if (report_id >= 0)
@@ -650,7 +650,7 @@ gnc_invoice_window_postCB (GtkWidget *widget, gpointer data)
   accumulate = gnc_gconf_get_bool(GCONF_SECTION_INVOICE, "accumulate_splits", NULL);
 
   if (!gnc_dialog_dates_acct_question_parented (iw_get_window(iw), message, ddue_label,
-				       post_label, acct_label, question_label, TRUE,
+				       post_label, acct_label, question_label, TRUE, TRUE,
 				       acct_types, iw->book, iw->terms,
 				       &ddue, &postdate, &memo, &acc, &accumulate))
     return;
@@ -768,7 +768,7 @@ void gnc_business_call_owner_report (GncOwner *owner, Account *acc)
   /* Apply the function to the args */
   arg = scm_apply (func, args, SCM_EOL);
   g_return_if_fail (SCM_EXACTP (arg));
-  id = scm_num2int (arg, SCM_ARG1, __FUNCTION__);
+  id = scm_num2int (arg, SCM_ARG1, G_STRFUNC);
 
   if (id >= 0)
     reportWindow (id);
