@@ -26,10 +26,16 @@
 
 #include <glib.h>
 
-void gnc_main_set_namespace_regexp(const char *str);
-const char *gnc_main_get_namespace_regexp(void);
+void gnc_main_set_namespace_regexp(const gchar *str);
+const gchar *gnc_main_get_namespace_regexp(void);
 
-int gnc_is_debugging(void);
-void gnc_set_debugging(int d);
+gboolean gnc_is_debugging(void);
+void gnc_set_debugging(gboolean d);
+
+gboolean gnc_is_extra_enabled(void);
+void gnc_set_extra(gboolean enabled);
+
+void gnc_set_gconf_path(const gchar *prefix);
+const gchar *gnc_get_gconf_path(void);
 
 #endif /* GNC_MAIN_H */
