@@ -45,8 +45,6 @@
 
 #include "Account.h"
 #include "AccountP.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "Scrub.h"
 #include "ScrubP.h"
 #include "Transaction.h"
@@ -57,35 +55,18 @@ static QofLogModule log_module = GNC_MOD_SCRUB;
 
 /* ================================================================ */
 
-void
-xaccGroupScrubOrphans (AccountGroup *grp)
-{
-  GList *list;
-  GList *node;
-
-  if (!grp) return;
-
-  list = xaccGroupGetAccountList (grp);
-
-  for (node = list; node; node = node->next)
-  {
-    Account *account = node->data;
-
-    xaccAccountTreeScrubOrphans (account);
-  }
-}
-
 void
 xaccAccountTreeScrubOrphans (Account *acc)
 {
   if (!acc) return;
 
-  xaccGroupScrubOrphans (xaccAccountGetChildren(acc));
   xaccAccountScrubOrphans (acc);
+  gnc_account_foreach_descendant(acc,
+                                 (AccountCb)xaccAccountScrubOrphans, NULL);
 }
 
 static void
-TransScrubOrphansFast (Transaction *trans, AccountGroup *root)
+TransScrubOrphansFast (Transaction *trans, Account *root)
 {
   GList *node;
 
@@ -125,7 +106,7 @@ xaccAccountScrubOrphans (Account *acc)
     Split *split = node->data;
 
     TransScrubOrphansFast (xaccSplitGetParent (split),
-                           xaccAccountGetRoot (acc));
+                           gnc_account_get_root (acc));
   }
 }
 
@@ -135,14 +116,14 @@ xaccTransScrubOrphans (Transaction *trans)
 {
   SplitList *node;
   QofBook *book = NULL;
-  AccountGroup *root = NULL;
+  Account *root = NULL;
   for (node = trans->splits; node; node = node->next)
   {
     Split *split = node->data;
 
     if (split->acc)
     {
-      TransScrubOrphansFast (trans, xaccAccountGetRoot(split->acc));
+      TransScrubOrphansFast (trans, gnc_account_get_root(split->acc));
       return;
     }
   }
@@ -154,35 +135,20 @@ xaccTransScrubOrphans (Transaction *trans)
    */
   PINFO ("Free Floating Transaction!");
   book = xaccTransGetBook (trans);
-  root = xaccGetAccountGroup (book);
+  root = gnc_book_get_root_account (book);
   TransScrubOrphansFast (trans, root);
 }
 
 /* ================================================================ */
 
-void
-xaccGroupScrubSplits (AccountGroup *group)
-{
-  GList *list;
-  GList *node;
-
-  if (!group) return;
-
-  list = xaccGroupGetAccountList (group);
-
-  for (node = list; node; node = node->next)
-  {
-    Account *account = node->data;
-
-    xaccAccountTreeScrubSplits (account);
-  }
-}
-
 void
 xaccAccountTreeScrubSplits (Account *account)
 {
-  xaccGroupScrubSplits (xaccAccountGetChildren(account));
+  if (!account) return;
+
   xaccAccountScrubSplits (account);
+  gnc_account_foreach_descendant(account,
+                                 (AccountCb)xaccAccountScrubSplits, NULL);
 }
 
 void
@@ -200,14 +166,17 @@ xaccSplitScrub (Split *split)
   Account *account;
   Transaction *trans;
   gnc_numeric value, amount;
-  gnc_commodity *currency;
+  gnc_commodity *currency, *acc_commodity;
   int scu;
 
   if (!split) return;
   ENTER ("(split=%p)", split);
 
   trans = xaccSplitGetParent (split);
-  if (!trans) return;
+  if (!trans) {
+    LEAVE("no trans");
+    return;
+  }
 
   account = xaccSplitGetAccount (split);
 
@@ -227,6 +196,7 @@ xaccSplitScrub (Split *split)
   if (!account) 
   {
     PINFO ("Free Floating Transaction!");
+    LEAVE ("no account");
     return;  
   }
 
@@ -250,12 +220,12 @@ xaccSplitScrub (Split *split)
   /* If the account doesn't have a commodity, 
    * we should attempt to fix that first. 
   */
-  if (!account->commodity)
+  acc_commodity = xaccAccountGetCommodity(account);
+  if (!acc_commodity)
   {
     xaccAccountScrubCommodity (account);
   }
-  if (!account->commodity || 
-      !gnc_commodity_equiv (account->commodity, currency))
+  if (!acc_commodity || !gnc_commodity_equiv(acc_commodity, currency))
   {
     LEAVE ("(split=%p) inequiv currency", split);
     return;
@@ -266,6 +236,7 @@ xaccSplitScrub (Split *split)
 
   if (gnc_numeric_same (amount, value, scu, GNC_HOW_RND_ROUND))
   {
+    LEAVE("(split=%p) different values", split);
     return;
   }
 
@@ -288,29 +259,12 @@ xaccSplitScrub (Split *split)
 
 /* ================================================================ */
 
-void
-xaccGroupScrubImbalance (AccountGroup *grp)
-{
-  GList *list;
-  GList *node;
-
-  if (!grp) return;
-
-  list = xaccGroupGetAccountList (grp);
-
-  for (node = list; node; node = node->next)
-  {
-    Account *account = node->data;
-
-    xaccAccountTreeScrubImbalance (account);
-  }
-}
-
 void
 xaccAccountTreeScrubImbalance (Account *acc)
 {
-  xaccGroupScrubImbalance (xaccAccountGetChildren(acc));
   xaccAccountScrubImbalance (acc);
+  gnc_account_foreach_descendant(acc,
+                                 (AccountCb)xaccAccountScrubImbalance, NULL);
 }
 
 void
@@ -332,7 +286,7 @@ xaccAccountScrubImbalance (Account *acc)
 
     xaccTransScrubCurrencyFromSplits(trans);
     
-    xaccTransScrubImbalance (trans, xaccAccountGetRoot (acc), NULL);
+    xaccTransScrubImbalance (trans, gnc_account_get_root (acc), NULL);
   }
 }
 
@@ -397,7 +351,7 @@ xaccTransScrubCurrencyFromSplits(Transaction *trans)
 }
 
 void
-xaccTransScrubImbalance (Transaction *trans, AccountGroup *root,
+xaccTransScrubImbalance (Transaction *trans, Account *root,
                          Account *account)
 {
   Split *balance_split = NULL;
@@ -412,17 +366,21 @@ xaccTransScrubImbalance (Transaction *trans, AccountGroup *root,
 
   /* If the transaction is balanced, nothing more to do */
   imbalance = xaccTransGetImbalance (trans);
-  if (gnc_numeric_zero_p (imbalance)) return;
+  if (gnc_numeric_zero_p (imbalance)) {
+    LEAVE("zero imbalance");
+    return;
+  }
 
   if (!account)
   {
     if (!root) 
     {
-       root = xaccGetAccountGroup (xaccTransGetBook (trans));
+       root = gnc_book_get_root_account (xaccTransGetBook (trans));
        if (NULL == root)
        {
           /* This can't occur, things should be in books */
           PERR ("Bad data corruption, no root account in book");
+          LEAVE("");
           return;
        }
     }
@@ -430,6 +388,7 @@ xaccTransScrubImbalance (Transaction *trans, AccountGroup *root,
         trans->common_currency, _("Imbalance"));
     if (!account) {
         PERR ("Can't get balancing account");
+        LEAVE("");
         return;
     }
   }
@@ -439,7 +398,7 @@ xaccTransScrubImbalance (Transaction *trans, AccountGroup *root,
   /* Put split into account before setting split value */
   if (!balance_split)
   {
-    balance_split = xaccMallocSplit (trans->inst.book);
+    balance_split = xaccMallocSplit (qof_instance_get_book(trans));
 
     xaccTransBeginEdit (trans);
     xaccSplitSetParent(balance_split, trans);
@@ -616,7 +575,7 @@ xaccTransScrubCurrency (Transaction *trans)
   currency = xaccTransGetCurrency (trans);
   if (currency) return;
   
-  currency = xaccTransFindOldCommonCurrency (trans, trans->inst.book);
+  currency = xaccTransFindOldCommonCurrency (trans, qof_instance_get_book(trans));
   if (currency)
   {
     xaccTransBeginEdit (trans);
@@ -647,7 +606,8 @@ xaccTransScrubCurrency (Transaction *trans)
         else
         {
           PWARN (" split=\"%s\" account=\"%s\" commodity=\"%s\"", 
-              split->memo, split->acc->accountName, gnc_commodity_get_mnemonic (split->acc->commodity));
+                 split->memo, xaccAccountGetName(split->acc),
+                 gnc_commodity_get_mnemonic(xaccAccountGetCommodity(split->acc)));
         }
       }
     }
@@ -660,7 +620,9 @@ xaccTransScrubCurrency (Transaction *trans)
     if (!gnc_numeric_equal(xaccSplitGetAmount (sp), 
         xaccSplitGetValue (sp))) 
     {
-      gnc_commodity *acc_currency = xaccAccountGetCommodity (sp->acc);
+      gnc_commodity *acc_currency;
+
+      acc_currency = sp->acc ? xaccAccountGetCommodity(sp->acc) : NULL;
       if (acc_currency == currency) 
       {
         /* This Split needs fixing: The transaction-currency equals
@@ -711,6 +673,7 @@ xaccAccountScrubCommodity (Account *account)
   gnc_commodity *commodity;
 
   if (!account) return;
+  if (xaccAccountGetType(account) == ACCT_TYPE_ROOT) return;
 
   commodity = xaccAccountGetCommodity (account);
   if (commodity) return;
@@ -731,7 +694,8 @@ xaccAccountScrubCommodity (Account *account)
     return;
   }
 
-  PERR ("Account \"%s\" does not have a commodity!", account->accountName);
+  PERR ("Account \"%s\" does not have a commodity!",
+        xaccAccountGetName(account));
 }
 
 /* ================================================================ */
@@ -754,27 +718,22 @@ scrub_trans_currency_helper (Transaction *t, gpointer data)
   return 0;
 }
 
-static gpointer
+static void
 scrub_account_commodity_helper (Account *account, gpointer data)
 {
   xaccAccountScrubCommodity (account);
   xaccAccountDeleteOldData (account);
-  return NULL;
 }
 
 void
-xaccGroupScrubCommodities (AccountGroup *group)
+xaccAccountTreeScrubCommodities (Account *acc)
 {
-  if (!group) return;
+  if (!acc) return;
 
-  xaccAccountGroupBeginEdit (group);
+  xaccAccountTreeForEachTransaction (acc, scrub_trans_currency_helper, NULL);
 
-  xaccGroupForEachTransaction (group, scrub_trans_currency_helper, NULL);
-
-  xaccGroupForEachAccount (group, scrub_account_commodity_helper,
-                           NULL, TRUE);
-
-  xaccAccountGroupCommitEdit (group);
+  scrub_account_commodity_helper (acc, NULL);
+  gnc_account_foreach_descendant (acc, scrub_account_commodity_helper, NULL);
 }
 
 /* ================================================================ */
@@ -788,7 +747,7 @@ check_quote_source (gnc_commodity *com, gpointer data)
   return TRUE;
 }
 
-static gpointer
+static void
 move_quote_source (Account *account, gpointer data)
 {
   gnc_commodity *com;
@@ -798,12 +757,12 @@ move_quote_source (Account *account, gpointer data)
 
   com = xaccAccountGetCommodity(account);
   if (!com)
-    return NULL;
+    return;
 
   if (!new_style) {
     source = dxaccAccountGetPriceSrc(account);
     if (!source || !*source)
-      return NULL;
+      return;
     tz = dxaccAccountGetQuoteTZ(account);
 
     PINFO("to %8s from %s", gnc_commodity_get_mnemonic(com),
@@ -818,27 +777,26 @@ move_quote_source (Account *account, gpointer data)
 
   dxaccAccountSetPriceSrc(account, NULL);
   dxaccAccountSetQuoteTZ(account, NULL);
-  return NULL;
+  return;
 }
 
 
 void
-xaccGroupScrubQuoteSources (AccountGroup *group, gnc_commodity_table *table)
+xaccAccountTreeScrubQuoteSources (Account *root, gnc_commodity_table *table)
 {
   gboolean new_style = FALSE;
   ENTER(" ");
 
-  if (!group || !table) {
+  if (!root || !table) {
     LEAVE("Oops");
     return;
   }
 
   gnc_commodity_table_foreach_commodity (table, check_quote_source, &new_style);
 
-  xaccAccountGroupBeginEdit (group);
-  xaccGroupForEachAccount (group, move_quote_source,
-                           GINT_TO_POINTER(new_style), TRUE);
-  xaccAccountGroupCommitEdit (group);
+  move_quote_source(root, GINT_TO_POINTER(new_style));
+  gnc_account_foreach_descendant (root, move_quote_source,
+                           GINT_TO_POINTER(new_style));
   LEAVE("Migration done");
 }
 
@@ -874,7 +832,7 @@ xaccAccountScrubKvp (Account *account)
 /* ================================================================ */
 
 Account *
-xaccScrubUtilityGetOrMakeAccount (AccountGroup *root, gnc_commodity * currency,
+xaccScrubUtilityGetOrMakeAccount (Account *root, gnc_commodity * currency,
                   const char *name_root)
 {
   char * accname;
@@ -893,19 +851,19 @@ xaccScrubUtilityGetOrMakeAccount (AccountGroup *root, gnc_commodity * currency,
                          gnc_commodity_get_mnemonic (currency), NULL);
 
   /* See if we've got one of these going already ... */
-  acc = xaccGetAccountFromName (root, accname);
+  acc = gnc_account_lookup_by_name(root, accname);
 
   if (acc == NULL)
   {
     /* Guess not. We'll have to build one. */
-    acc = xaccMallocAccount (root->book);
+    acc = xaccMallocAccount(gnc_account_get_book (root));
     xaccAccountBeginEdit (acc);
     xaccAccountSetName (acc, accname);
     xaccAccountSetCommodity (acc, currency);
-    xaccAccountSetType (acc, BANK);
+    xaccAccountSetType (acc, ACCT_TYPE_BANK);
 
     /* Hang the account off the root. */
-    xaccGroupInsertAccount (root, acc);
+    gnc_account_append_child (root, acc);
     xaccAccountCommitEdit (acc);
   }
 
