@@ -1,6 +1,7 @@
 /********************************************************************\
- * gnc-helpers.c -- gnucash g-wrap helper functions                 *
+ * gnc-helpers.c -- gnucash glib helper functions                   *
  * Copyright (C) 2000 Linas Vepstas                                 *
+ * Copyright (C) 2006 Chris Shoemaker <c.shoemaker@cox.net>         *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -27,39 +28,37 @@
 #include <glib.h>
 #include <libguile.h>
 #include "guile-mappings.h"
-
-#include <g-wrap-wct.h>
-
+#include "swig-runtime.h"
 #include "glib-helpers.h"
 
 
-/* These will eventually go into (g-wrapped glib). */
-
 static SCM
-glist_to_scm_list_helper(GList *glist, SCM wct)
+glist_to_scm_list_helper(GList *glist, swig_type_info *wct)
 {
   SCM list = SCM_EOL;
   GList *node;
 
   for (node = glist; node; node = node->next)
-    list = scm_cons (gw_wcp_assimilate_ptr(node->data, wct), list);
+      list = scm_cons(SWIG_NewPointerObj(node->data, wct, 0), list);
 
   return scm_reverse (list);
 }
 
 SCM
-gnc_glist_to_scm_list(GList *glist, SCM wct)
+gnc_glist_to_scm_list(GList *glist, gchar *wct)
 {
-  SCM_ASSERT(gw_wct_p(wct), wct, SCM_ARG1, "gnc_glist_to_scm_list");
-  return(glist_to_scm_list_helper(glist, wct));
+    swig_type_info *stype = SWIG_TypeQuery(wct);
+    g_return_val_if_fail(stype, SCM_UNDEFINED);
+    return glist_to_scm_list_helper(glist, stype);
 }
 
-GList*
+GList *
 gnc_scm_list_to_glist(SCM rest)
 {
   GList *result = NULL;
   SCM scm_item;
-  
+
+  SWIG_GetModule(NULL); /* Work-around for SWIG bug. */
   SCM_ASSERT(SCM_LISTP(rest), rest, SCM_ARG1, "gnc_scm_list_to_glist");
 
   while(!SCM_NULLP(rest))
@@ -69,18 +68,17 @@ gnc_scm_list_to_glist(SCM rest)
     scm_item = SCM_CAR(rest);
     rest = SCM_CDR(rest);
 
-    /* fixes a bug in g-wrap */
     if (scm_item == SCM_BOOL_F)
     {
       result = g_list_prepend(result, NULL);
     }
     else
     {
-      if (!gw_wcp_p(scm_item))
+      if (!SWIG_IsPointer(scm_item))
         scm_misc_error("gnc_scm_list_to_glist",
-                       "Item in list not a gw:wcp.", scm_item);
+                       "Item in list not a wcp.", scm_item);
       
-      item = gw_wcp_get_ptr(scm_item);
+      item = (void *)SWIG_PointerAddress(scm_item);
       result = g_list_prepend(result, item);
     }
   }
@@ -88,38 +86,6 @@ gnc_scm_list_to_glist(SCM rest)
   return g_list_reverse(result);
 }
 
-static SCM
-glist_map_helper(GList *glist, SCM wct, SCM thunk)
-{
-  SCM list = SCM_EOL;
-  GList *node;
-
-  for (node = glist; node; node = node->next)
-    list = scm_cons (scm_call_1(thunk, gw_wcp_assimilate_ptr(node->data, wct)),
-		     list);
-
-  return scm_reverse (list);
-}
-
-SCM
-gnc_glist_scm_map(SCM wct, SCM thunk, GList* glist)
-{
-  SCM_ASSERT(gw_wct_p(wct), wct, SCM_ARG1, "gnc_glist_map");
-  SCM_ASSERT(SCM_PROCEDUREP(thunk), thunk, SCM_ARG2, "gnc_glist_scm_map");  
-  return(glist_map_helper(glist, wct, thunk));
-}
-
-void
-gnc_glist_scm_for_each(SCM wct, SCM thunk, GList *glist)
-{
-  GList *lp;
-  SCM_ASSERT(gw_wct_p(wct), wct, SCM_ARG1, "gnc_glist_map");
-  SCM_ASSERT(SCM_PROCEDUREP(thunk), thunk, SCM_ARG2, "gnc_glist_scm_for_each");  
-  for(lp = glist; lp; lp = lp->next) {
-    scm_call_1(thunk, gw_wcp_assimilate_ptr(lp->data, wct));
-  }
-}
-
 /********************************************************************
  * gnc_glist_string_to_scm
  * i.e. (glist-of (<gw:mchars> calee-owned) callee-owned)
@@ -143,9 +109,9 @@ gnc_glist_string_to_scm(GList *glist)
 
 /********************************************************************
  * gnc_scm_to_glist_string
- * i.e. (glist-of (<gw:mchars> calee-owned) callee-owned)
+ * i.e. (glist-of (<gw:mchars> callee-owned) callee-owned)
  * or equivalently
- * i.e. (glist-of (<gw:gchars> calee-owned) callee-owned)
+ * i.e. (glist-of (<gw:gchars> callee-owned) callee-owned)
  ********************************************************************/
 
 GList *
@@ -164,6 +130,22 @@ gnc_scm_to_glist_string(SCM list)
   return g_list_reverse (glist);
 }
 
+GSList *
+gnc_scm_to_gslist_string(SCM list)
+{
+  GSList *gslist = NULL;
+
+  while (!SCM_NULLP (list))
+  {
+    const gchar * str = SCM_STRING_CHARS (SCM_CAR(list));
+    if (str)
+      gslist = g_slist_prepend (gslist, g_strdup (str));
+    list = SCM_CDR (list);
+  }
+
+  return g_slist_reverse (gslist);
+}
+
 /********************************************************************
  * gnc_glist_string_p
  ********************************************************************/
