@@ -28,7 +28,6 @@
 
 #include "config.h"
 
-#include "AccountP.h"
 #include "gnc-associate-account.h"
 #include "gnc-engine.h"
 #include "qof.h"
@@ -150,7 +149,8 @@ make_kvpd_on_list(GList *account_list)
 
     current_account = iter->data;
     type = xaccAccountGetType(current_account);
-    g_return_val_if_fail(type == INCOME || type == EXPENSE, NULL);
+    g_return_val_if_fail(type == ACCT_TYPE_INCOME || type == ACCT_TYPE_EXPENSE,
+			 NULL);
 
     acc_id = xaccAccountGetGUID(current_account);
     guid_kvp = kvp_value_new_guid(acc_id);
@@ -296,7 +296,8 @@ gnc_tracking_find_expense_accounts(Account *stock_account,
   kvpd_on_account_list = kvp_frame_get_slot(account_frame,
 					    expense_to_key[category]);
 
-  return de_kvp_account_list(kvpd_on_account_list, stock_account->inst.book);
+  return de_kvp_account_list(kvpd_on_account_list,
+			     gnc_account_get_book(stock_account));
 }
 
 /*********************************************************************\
@@ -328,7 +329,8 @@ gnc_tracking_find_income_accounts(Account *stock_account,
   kvpd_on_account_list = kvp_frame_get_slot(income_acc_frame,
 					    income_to_key[category]);
   
-  return de_kvp_account_list(kvpd_on_account_list, stock_account->inst.book);
+  return de_kvp_account_list(kvpd_on_account_list,
+			     gnc_account_get_book(stock_account));
 }
 
 /*********************************************************************\
@@ -423,7 +425,7 @@ gnc_tracking_dissociate_account(Account *inc_or_expense_account)
 
   type = xaccAccountGetType(inc_or_expense_account);
   
-  g_return_if_fail(type == INCOME || type == EXPENSE);
+  g_return_if_fail(type == ACCT_TYPE_INCOME || type == ACCT_TYPE_EXPENSE);
   
   current_account_kvpframe = xaccAccountGetSlots(inc_or_expense_account);
 
@@ -439,7 +441,7 @@ gnc_tracking_dissociate_account(Account *inc_or_expense_account)
 
   inc_or_expense_account_guid = xaccAccountGetGUID(inc_or_expense_account);
   stock_account = xaccAccountLookup
-    (stock_account_guid, inc_or_expense_account->inst.book);
+    (stock_account_guid, gnc_account_get_book(inc_or_expense_account));
 
   stock_account_kvpframe = xaccAccountGetSlots(stock_account);
 
