@@ -22,14 +22,16 @@
  *                                                                  *
 \********************************************************************/
 
+#include "config.h"
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <glib/gi18n.h>
 #include <time.h>
 #include "qof.h"
 
+#include "glib-compat.h"
+
 #include "Account.h"
-#include "Group.h"
 
 #include "gnc-budget.h"
 #include "gnc-commodity.h"
@@ -46,6 +48,29 @@ struct gnc_budget_private{
     guint  num_periods;
 };
 
+struct _GncBudgetClass
+{
+  QofInstanceClass parent_class;
+};
+
+/* GObject Initialization */
+QOF_GOBJECT_IMPL(gnc_budget, GncBudget, QOF_TYPE_INSTANCE);
+
+static void
+gnc_budget_init(GncBudget* budget)
+{
+}
+
+static void
+gnc_budget_dispose_real (GObject *budgetp)
+{
+}
+
+static void
+gnc_budget_finalize_real(GObject* budgetp)
+{
+}
+
 static void commit_err (QofInstance *inst, QofBackendError errcode)
 {
   PERR ("Failed to commit: %d", errcode);
@@ -63,24 +88,24 @@ gnc_budget_free(QofInstance *inst)
     /* We first send the message that this object is about to be
      * destroyed so that any GUI elements can remove it before it is
      * actually gone. */
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_DESTROY, NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_DESTROY, NULL);
 
     CACHE_REMOVE(budget->name);
     CACHE_REMOVE(budget->description);
 
-    qof_instance_release (&budget->inst);
-    g_free(budget);
+    /* qof_instance_release (&budget->inst); */
+    g_object_unref(budget);
 }
 
 static void noop (QofInstance *inst) {}
 
-static void
+void
 gnc_budget_begin_edit(GncBudget *bgt)
 {
     qof_begin_edit(QOF_INSTANCE(bgt));
 }
 
-static void
+void
 gnc_budget_commit_edit(GncBudget *bgt)
 {
     if (!qof_commit_edit(QOF_INSTANCE(bgt))) return;
@@ -96,18 +121,20 @@ gnc_budget_new(QofBook *book)
     g_return_val_if_fail(book, NULL);
 
     ENTER(" ");
-    budget = g_new0(GncBudget, 1);
-    qof_instance_init (&budget->inst, GNC_ID_BUDGET, book);
+    budget = g_object_new(GNC_TYPE_BUDGET, NULL);
+    qof_instance_init_data (&budget->inst, GNC_ID_BUDGET, book);
 
-    g_date_set_time(&date, time(NULL));
+    g_date_set_time_t(&date, time(NULL));
     g_date_subtract_days(&date, g_date_get_day(&date)-1);
     recurrenceSet(&budget->recurrence, 1, PERIOD_MONTH, &date);
 
+	gnc_budget_begin_edit(budget);
     gnc_budget_set_name(budget, _("Unnamed Budget"));
     gnc_budget_set_description(budget, "");
     gnc_budget_set_num_periods(budget, 12);
+	gnc_budget_commit_edit(budget);
 
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_CREATE , NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_CREATE , NULL);
 
     LEAVE(" ");
     return budget;
@@ -119,7 +146,7 @@ gnc_budget_destroy(GncBudget *budget)
     g_return_if_fail(GNC_IS_BUDGET(budget));
     gnc_budget_begin_edit(budget);
     qof_instance_set_dirty(&budget->inst);
-    budget->inst.do_free = TRUE;
+    qof_instance_set_destroying(budget, TRUE);
     gnc_budget_commit_edit(budget);
 }
 
@@ -133,7 +160,7 @@ gnc_budget_set_name(GncBudget* budget, const gchar* name)
     qof_instance_set_dirty(&budget->inst);
     gnc_budget_commit_edit(budget);
 
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 const gchar*
@@ -154,7 +181,7 @@ gnc_budget_set_description(GncBudget* budget, const gchar* description)
     qof_instance_set_dirty(&budget->inst);
     gnc_budget_commit_edit(budget);
 
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 const gchar*
@@ -173,7 +200,7 @@ gnc_budget_set_recurrence(GncBudget *budget, const Recurrence *r)
     qof_instance_set_dirty(&budget->inst);
     gnc_budget_commit_edit(budget);
 
-    qof_event_gen(&budget->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen(&budget->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 const Recurrence *
@@ -188,7 +215,7 @@ gnc_budget_get_guid(GncBudget* budget)
 {
     g_return_val_if_fail(budget, NULL);
     g_return_val_if_fail(GNC_IS_BUDGET(budget), NULL);
-    return qof_entity_get_guid(QOF_ENTITY(budget));
+    return qof_instance_get_guid(QOF_INSTANCE(budget));
 }
 
 void
@@ -201,7 +228,7 @@ gnc_budget_set_num_periods(GncBudget* budget, guint num_periods)
     qof_instance_set_dirty(&budget->inst);
     gnc_budget_commit_edit(budget);
 
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 guint
@@ -214,6 +241,31 @@ gnc_budget_get_num_periods(GncBudget* budget)
 #define BUF_SIZE (10 + GUID_ENCODING_LENGTH + \
    GNC_BUDGET_MAX_NUM_PERIODS_DIGITS)
 
+/* period_num is zero-based */
+/* What happens when account is deleted, after we have an entry for it? */
+void
+gnc_budget_unset_account_period_value(GncBudget *budget, Account *account,
+                                    guint period_num)
+{
+    const GUID *guid;
+    KvpFrame *frame;
+    gchar path[BUF_SIZE];
+    gchar *bufend;
+
+    gnc_budget_begin_edit(budget);
+    frame = qof_instance_get_slots(QOF_INSTANCE(budget));
+    guid = xaccAccountGetGUID(account);
+    bufend = guid_to_string_buff(guid, path);
+    g_sprintf(bufend, "/%d", period_num);
+
+    kvp_frame_set_value(frame, path, NULL);
+    qof_instance_set_dirty(&budget->inst);
+    gnc_budget_commit_edit(budget);
+
+    qof_event_gen( &budget->inst, QOF_EVENT_MODIFY, NULL);
+
+}
+
 /* period_num is zero-based */
 /* What happens when account is deleted, after we have an entry for it? */
 void
@@ -231,11 +283,14 @@ gnc_budget_set_account_period_value(GncBudget *budget, Account *account,
     bufend = guid_to_string_buff(guid, path);
     g_sprintf(bufend, "/%d", period_num);
 
-    kvp_frame_set_numeric(frame, path, val);
+    if (gnc_numeric_check(val))
+        kvp_frame_set_value(frame, path, NULL);
+    else
+        kvp_frame_set_numeric(frame, path, val);
     qof_instance_set_dirty(&budget->inst);
     gnc_budget_commit_edit(budget);
 
-    qof_event_gen( &budget->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen( &budget->inst, QOF_EVENT_MODIFY, NULL);
 
 }
 
@@ -259,20 +314,34 @@ is_same_commodity(Account *a, gpointer data)
 static gboolean
 xaccAccountChildrenHaveSameCommodity(Account *account)
 {
-    AccountGroup *grp;
     gpointer different;
     gnc_commodity *comm;
 
     comm = xaccAccountGetCommodity(account);
-    grp = xaccAccountGetChildren(account);
-    different = xaccGroupForEachAccount(
-        grp, is_same_commodity, comm, TRUE);
+    different =
+      gnc_account_foreach_descendant_until(account, is_same_commodity, comm);
     return (different == NULL);
 }
 #endif
 
 
-/* Does not distinguish between unset and zero - returns zero either way. */
+gboolean
+gnc_budget_is_account_period_value_set(GncBudget *budget, Account *account,
+                                       guint period_num)
+{
+    gchar path[BUF_SIZE];
+    gchar *bufend;
+    KvpFrame *frame;
+
+    g_return_val_if_fail(GNC_IS_BUDGET(budget), FALSE);
+    g_return_val_if_fail(account, FALSE);
+
+    frame = qof_instance_get_slots(QOF_INSTANCE(budget));
+    bufend = guid_to_string_buff(xaccAccountGetGUID(account), path);
+    g_sprintf(bufend, "/%d", period_num);
+    return (kvp_frame_get_value(frame, path) != NULL);
+}
+
 gnc_numeric
 gnc_budget_get_account_period_value(GncBudget *budget, Account *account,
                                     guint period_num)
@@ -289,7 +358,9 @@ gnc_budget_get_account_period_value(GncBudget *budget, Account *account,
     frame = qof_instance_get_slots(QOF_INSTANCE(budget));
     bufend = guid_to_string_buff(xaccAccountGetGUID(account), path);
     g_sprintf(bufend, "/%d", period_num);
-    numeric = kvp_frame_get_numeric(frame, path); /* Zero if unset */
+
+    numeric = kvp_frame_get_numeric(frame, path);
+    /* This still returns zero if unset, but callers can check for that. */
     return numeric;
 }
 
@@ -331,7 +402,7 @@ gnc_budget_lookup (const GUID *guid, QofBook *book)
     return GNC_BUDGET(qof_collection_lookup_entity (col, guid));
 }
 
-static void just_get_one(QofEntity *ent, gpointer data)
+static void just_get_one(QofInstance *ent, gpointer data)
 {
     GncBudget **bgt = (GncBudget**)data;
     if (bgt && !*bgt) *bgt = GNC_BUDGET(ent);
