@@ -97,7 +97,10 @@ struct gnc_new_iso_code
   {"RUR", "RUB"}, /* Russian Ruble: RUR through 1997-12, RUB from 1998-01 onwards; see bug #393185 */
   {"PLZ", "PLN"}, /* Polish Zloty */
   {"UAG", "UAH"}, /* Ukraine Hryvnia */
-  {"ILS", "NIS"}, /* New Israeli Shekel */
+  {"NIS", "ILS"}, /* New Israeli Shekel: The informal abbreviation may be "NIS", but
+		     its iso-4217 is clearly ILS and only this! Incorrectly changed
+		     due to bug#152755 (Nov 2004) and changed back again by bug#492417
+		     (Oct 2008). */
   {"MXP", "MXN"}, /* Mexican (Nuevo) Peso */
   {"TRL", "TRY"}, /* New Turkish Lira: changed 2005 */
 
@@ -1191,10 +1194,12 @@ gnc_commodity_table_lookup(const gnc_commodity_table * table,
      * Backward compatability support for currencies that have
      * recently changed.
      */
-    for (i = 0; i < GNC_NEW_ISO_CODES; i++) {
-      if (strcmp(mnemonic, gnc_new_iso_codes[i].old_code) == 0) {
-	mnemonic = gnc_new_iso_codes[i].new_code;
-	break;
+    if (nsp->iso4217) {
+      for (i = 0; i < GNC_NEW_ISO_CODES; i++) {
+	if (strcmp(mnemonic, gnc_new_iso_codes[i].old_code) == 0) {
+	  mnemonic = gnc_new_iso_codes[i].new_code;
+	  break;
+	}
       }
     }
     return g_hash_table_lookup(nsp->cm_table, (gpointer)mnemonic);
