@@ -193,6 +193,7 @@ static void
 gnc_price_set_dirty (GNCPrice *p)
 {
   qof_instance_set_dirty(&p->inst);
+  qof_event_gen(&p->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 void
@@ -985,7 +986,7 @@ check_one_price_date (GNCPrice *price, gpointer user_data)
 	user_data);
   if (!data->delete_user) {
     source = gnc_price_get_source (price);
-    if (strcmp(source, "Finance::Quote") != 0) {
+    if (safe_strcmp(source, "Finance::Quote") != 0) {
       LEAVE("Not an automatic quote");
       return TRUE;
     }
@@ -1578,7 +1579,10 @@ gnc_pricedb_lookup_nearest_in_time(GNCPriceDB *db,
       Timespec abs_current = timespec_abs(&diff_current);
       Timespec abs_next = timespec_abs(&diff_next);
 
-      if (timespec_cmp(&abs_current, &abs_next) <= 0) {
+      /* Choose the price that is closest to the given time. In case of
+       * a tie, prefer the older price since it actually existed at the
+       * time. (This also fixes bug #541970.) */
+      if (timespec_cmp(&abs_current, &abs_next) < 0) {
         result = current_price;
       } else {
         result = next_price;
@@ -1843,6 +1847,18 @@ gnc_pricedb_convert_balance_latest_price(GNCPriceDB *pdb,
     return balance;
   }
 
+  /* Look for a price of the new currency in the balance currency and use
+   * the reciprocal if we find it 
+   */
+  price = gnc_pricedb_lookup_latest (pdb, new_currency, balance_currency);
+  if (price) {
+    balance = gnc_numeric_div (balance, gnc_price_get_value (price),
+                               gnc_commodity_get_fraction (new_currency),
+                               GNC_HOW_RND_ROUND);
+    gnc_price_unref (price);
+    return balance;
+  }
+
   /*
    * no direct price found, try if we find a price in another currency
    * and convert in two stages
@@ -1880,11 +1896,11 @@ gnc_pricedb_convert_balance_latest_price(GNCPriceDB *pdb,
 
     list_helper = list_helper->next;
   } while((list_helper != NULL) &&
-          (!gnc_numeric_zero_p(currency_price_value)));
+          (gnc_numeric_zero_p(currency_price_value)));
 
   balance = gnc_numeric_mul (balance, currency_price_value,
-                             gnc_commodity_get_fraction (new_currency),
-                             GNC_HOW_RND_ROUND);
+                             GNC_DENOM_AUTO,
+                             GNC_HOW_DENOM_EXACT | GNC_HOW_RND_NEVER);
   balance = gnc_numeric_mul (balance, gnc_price_get_value (price),
                              gnc_commodity_get_fraction (new_currency),
                              GNC_HOW_RND_ROUND);
@@ -1919,6 +1935,18 @@ gnc_pricedb_convert_balance_nearest_price(GNCPriceDB *pdb,
     return balance;
   }
 
+  /* Look for a price of the new currency in the balance currency and use
+   * the reciprocal if we find it 
+   */
+  price = gnc_pricedb_lookup_nearest_in_time (pdb, new_currency, balance_currency, t);
+  if (price) {
+    balance = gnc_numeric_div (balance, gnc_price_get_value (price),
+                               gnc_commodity_get_fraction (new_currency),
+                               GNC_HOW_RND_ROUND);
+    gnc_price_unref (price);
+    return balance;
+  }
+
   /*
    * no direct price found, try if we find a price in another currency
    * and convert in two stages
@@ -1956,7 +1984,7 @@ gnc_pricedb_convert_balance_nearest_price(GNCPriceDB *pdb,
 
     list_helper = list_helper->next;
   } while((list_helper != NULL) &&
-          (!gnc_numeric_zero_p(currency_price_value)));
+	  (gnc_numeric_zero_p(currency_price_value)));
 
   balance = gnc_numeric_mul (balance, currency_price_value,
                              gnc_commodity_get_fraction (new_currency),
@@ -1998,6 +2026,18 @@ gnc_pricedb_convert_balance_latest_before(GNCPriceDB *pdb,
     return balance;
   }
 
+  /* Look for a price of the new currency in the balance currency and use
+   * the reciprocal if we find it.
+   */
+  price = gnc_pricedb_lookup_latest_before (pdb, new_currency, balance_currency, t);
+  if (price) {
+    balance = gnc_numeric_div (balance, gnc_price_get_value (price),
+                               gnc_commodity_get_fraction (new_currency),
+                               GNC_HOW_RND_ROUND);
+    gnc_price_unref (price);
+    return balance;
+  }
+  
   /*
    * no direct price found, try if we find a price in another currency
    * and convert in two stages
@@ -2035,7 +2075,7 @@ gnc_pricedb_convert_balance_latest_before(GNCPriceDB *pdb,
 
     list_helper = list_helper->next;
   } while((list_helper != NULL) &&
-          (!gnc_numeric_zero_p(currency_price_value)));
+          (gnc_numeric_zero_p(currency_price_value)));
 
   balance = gnc_numeric_mul (balance, currency_price_value,
                              gnc_commodity_get_fraction (new_currency),
