@@ -21,6 +21,7 @@
  *  02110-1301, USA.
  */
  
+#include "config.h"
 #include <glib.h>
 #include <stdio.h>
 #include "qof.h"
@@ -91,13 +92,13 @@ static void test_querynew (void)
 int
 main (int argc, char **argv)
 {
-	qof_init();
-	if(cashobjects_register()) {
-  test_query_core();
-  test_class();
-  test_querynew();
-	}
-	qof_close();
-  print_test_results();
-  return 0;
+     qof_init();
+     if(cashobjects_register()) {
+          test_query_core();
+          test_class();
+          test_querynew();
+     }
+     qof_close();
+     print_test_results();
+     return get_rv();
 }
