@@ -22,6 +22,7 @@
  *  02110-1301, USA.
  */
 
+#include "config.h"
 #include <glib.h>
 #include "qof.h"
 #include "cashobjects.h"
@@ -70,5 +71,5 @@ main (int argc, char **argv)
         print_test_results();
     }
     qof_close();
-    return 0;
+    return get_rv();
 }
