@@ -1,7 +1,7 @@
 /*********************************************************************
  * gncmod-gnome-search
  * GNC Module initialization for the Gnome Search UI
- * 
+ *
  * Copyright (c) 2002 Derek Atkins <warlord@MIT.EDU>
  *
  * This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <stdio.h>
+#include <gmodule.h>
 #include <libguile.h>
 
 #include "gnc-module.h"
@@ -35,35 +35,31 @@
 
 #include "search-core-type.h"
 
+GNC_MODULE_API_DECL(libgncmod_gnome_search)
+
 /* version of the gnc module system interface we require */
-int libgncmod_gnome_search_LTX_gnc_module_system_interface = 0;
+int libgncmod_gnome_search_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_gnome_search_LTX_gnc_module_current  = 0;
-int libgncmod_gnome_search_LTX_gnc_module_revision = 0;
-int libgncmod_gnome_search_LTX_gnc_module_age      = 0;
-
-/* forward references */
-char *libgncmod_gnome_search_LTX_gnc_module_path(void);
-char *libgncmod_gnome_search_LTX_gnc_module_description(void);
-int libgncmod_gnome_search_LTX_gnc_module_init(int refcount);
-int libgncmod_gnome_search_LTX_gnc_module_end(int refcount);
+int libgncmod_gnome_search_gnc_module_current  = 0;
+int libgncmod_gnome_search_gnc_module_revision = 0;
+int libgncmod_gnome_search_gnc_module_age      = 0;
 
 
 char *
-libgncmod_gnome_search_LTX_gnc_module_path(void) 
+libgncmod_gnome_search_gnc_module_path(void)
 {
   return g_strdup("gnucash/gnome-search");
 }
 
-char * 
-libgncmod_gnome_search_LTX_gnc_module_description(void) 
+char *
+libgncmod_gnome_search_gnc_module_description(void)
 {
   return g_strdup("The GnuCash Gnome Search UI");
 }
 
 int
-libgncmod_gnome_search_LTX_gnc_module_init(int refcount) 
+libgncmod_gnome_search_gnc_module_init(int refcount)
 {
   /* load the engine (we depend on it) */
   if(!gnc_module_load("gnucash/engine", 0)) {
@@ -74,17 +70,17 @@ libgncmod_gnome_search_LTX_gnc_module_init(int refcount)
     return FALSE;
   }
 
-  if(refcount == 0) 
+  if(refcount == 0)
   {
     /* initialize known types */
     gnc_search_core_initialize ();
   }
-  
+
   return TRUE;
 }
 
 int
-libgncmod_gnome_search_LTX_gnc_module_end(int refcount) {
+libgncmod_gnome_search_gnc_module_end(int refcount) {
   /* XXX Unload the other modules */
 
   if (refcount == 0) {
