@@ -53,7 +53,7 @@
 #include "gnc-date-format.h"
 #include "misc-gnome-utils.h"
 
-#define FUNC_NAME __FUNCTION__
+#define FUNC_NAME G_STRFUNC
 /* TODO: clean up "register-stocks" junk
  */
 
@@ -2384,7 +2384,7 @@ gnc_option_set_ui_value_account_sel (GNCOption *option, gboolean use_default,
     acc = SWIG_MustGetPtr(value, SWIG_TypeQuery("_p_Account"), 4, 0);
   }
 	
-  gnc_account_sel_set_account (GNC_ACCOUNT_SEL(widget), acc);
+  gnc_account_sel_set_account (GNC_ACCOUNT_SEL(widget), acc, FALSE);
 
   return FALSE;
 }
@@ -2435,7 +2435,7 @@ gnc_option_set_ui_value_number_range (GNCOption *option, gboolean use_default,
 
   if (SCM_NUMBERP(value))
   {
-    d_value = scm_num2dbl(value, __FUNCTION__);
+    d_value = scm_num2dbl(value, G_STRFUNC);
     gtk_spin_button_set_value(spinner, d_value);
     return FALSE;
   }
