@@ -257,7 +257,10 @@ gnc_xfer_dialog_set_price_auto (XferDialog *xferData,
 
   if (!gnc_is_euro_currency (from_currency) ||
       !gnc_is_euro_currency (to_currency))
-    return gnc_xfer_dialog_update_price (xferData);
+  {
+    gnc_xfer_dialog_update_price (xferData);
+    return;
+  }
 
   from_rate = gnc_euro_currency_get_rate (from_currency);
   to_rate = gnc_euro_currency_get_rate (to_currency);
@@ -825,47 +828,41 @@ gnc_xfer_amount_update_cb(GtkWidget *widget, GdkEventFocus *event,
 static void
 gnc_xfer_update_to_amount (XferDialog *xferData)
 {
-  gnc_numeric amount, price, to_amount;
+  GNCAmountEdit *amount_edit, *price_edit, *to_amount_edit;
+  gnc_numeric price, to_amount;
   Account *account;
+  int scu = 0;
 
-  account = gnc_transfer_dialog_get_selected_account (xferData, XFER_DIALOG_TO);
+  g_return_if_fail(xferData);
+
+  /* Get the amount editing controls of the dialog. */
+  amount_edit     = GNC_AMOUNT_EDIT(xferData->amount_edit);
+  price_edit      = GNC_AMOUNT_EDIT(xferData->price_edit);
+  to_amount_edit  = GNC_AMOUNT_EDIT(xferData->to_amount_edit);
+
+  /* Determine the SCU (smallest commodity unit) of the "to" amount. */
+  account = gnc_transfer_dialog_get_selected_account(xferData, XFER_DIALOG_TO);
   if (account == NULL)
-    account = gnc_transfer_dialog_get_selected_account (xferData, XFER_DIALOG_FROM);
+    account = gnc_transfer_dialog_get_selected_account(xferData,
+                                                       XFER_DIALOG_FROM);
+  if (account != NULL)
+    scu = xaccAccountGetCommoditySCU(account);
+  else if (xferData->to_commodity != NULL)
+    scu = gnc_commodity_get_fraction(xferData->to_commodity);
 
-  if (account == NULL)
-  {
-    GtkEntry *entry;
-
-    gnc_amount_edit_set_amount(GNC_AMOUNT_EDIT(xferData->to_amount_edit),
-                               gnc_numeric_zero ());
-    entry = GTK_ENTRY(gnc_amount_edit_gtk_entry
-                      (GNC_AMOUNT_EDIT(xferData->to_amount_edit)));
-    gtk_entry_set_text(entry, "");
-  }
-
-  gnc_amount_edit_evaluate (GNC_AMOUNT_EDIT (xferData->price_edit));
-
-  amount = gnc_amount_edit_get_amount(GNC_AMOUNT_EDIT(xferData->amount_edit));
-  price = gnc_amount_edit_get_amount(GNC_AMOUNT_EDIT(xferData->price_edit));
-
-  if (gnc_numeric_zero_p (price))
-    to_amount = gnc_numeric_zero ();
+  /* Determine the amount to transfer. */
+  if (!gnc_amount_edit_evaluate(price_edit) ||
+      gnc_numeric_zero_p(price = gnc_amount_edit_get_amount(price_edit)))
+    to_amount = gnc_numeric_zero();
   else
-    to_amount = gnc_numeric_mul (amount, price,
-                                 xaccAccountGetCommoditySCU (account),
-                                 GNC_RND_ROUND);
+    to_amount = gnc_numeric_mul(gnc_amount_edit_get_amount(amount_edit),
+                                price, scu, GNC_RND_ROUND);
 
-  gnc_amount_edit_set_amount(GNC_AMOUNT_EDIT(xferData->to_amount_edit),
-                             to_amount);
-
-  if (gnc_numeric_zero_p (to_amount))
-  {
-    GtkEntry *entry;
-
-    entry = GTK_ENTRY(gnc_amount_edit_gtk_entry
-                      (GNC_AMOUNT_EDIT(xferData->to_amount_edit)));
-    gtk_entry_set_text(entry, "");
-  }
+  /* Update the dialog. */
+  gnc_amount_edit_set_amount(to_amount_edit, to_amount);
+  if (gnc_numeric_zero_p(to_amount))
+    gtk_entry_set_text(GTK_ENTRY(gnc_amount_edit_gtk_entry(to_amount_edit)),
+                       "");
 
   gnc_xfer_dialog_update_conv_info(xferData);
 }
@@ -1084,7 +1081,10 @@ gnc_xfer_dialog_is_exchange_dialog (XferDialog *xferData,
 {
   GNCAmountEdit *gae;
 
-  if (!xferData) return;
+  g_return_if_fail(xferData);
+  ENTER("xferData=%p, exch_rate=%p (%s)", xferData, exch_rate,
+        exch_rate == NULL ? "NULL" : xaccPrintAmount(*exch_rate,
+                                       gnc_default_print_info(FALSE)));
 
   gtk_widget_set_sensitive (xferData->amount_edit, FALSE);
   gtk_widget_set_sensitive (xferData->date_entry, FALSE);
@@ -1097,6 +1097,8 @@ gnc_xfer_dialog_is_exchange_dialog (XferDialog *xferData,
   gtk_widget_grab_focus (gnc_amount_edit_gtk_entry (gae));
 
   xferData->exch_rate = exch_rate;
+
+  LEAVE(" ");
 }
 
 /********************************************************************\
@@ -1683,7 +1685,6 @@ gnc_xfer_dialog_create(GtkWidget *parent, XferDialog *xferData)
     edit = gnc_amount_edit_new();
     gnc_amount_edit_set_print_info(GNC_AMOUNT_EDIT(edit),
                                    gnc_default_print_info (FALSE));
-    gnc_amount_edit_set_fraction(GNC_AMOUNT_EDIT(edit), PRECISION);
     hbox = glade_xml_get_widget (xml, "price_hbox");
     gtk_box_pack_start(GTK_BOX(hbox), edit, TRUE, TRUE, 0);
     xferData->price_edit = edit;
