@@ -94,7 +94,7 @@ GType gnc_tree_model_account_types_get_type (void);
 
 /*************** Method 1 functions ***************/
 
-/* Returns a GtkTreeModelFilter that wraps the model. Deprecated
+/* Returns a GtkTreeModelFilter that wraps the model. Deprecated and root
    account types will be filtered. Caller is responsible for
    ref/unref. */
 GtkTreeModel * gnc_tree_model_account_types_valid (void);
@@ -128,8 +128,8 @@ guint32 gnc_tree_model_account_types_get_selection(GtkTreeSelection *sel);
 
 /* Gets the selected account type.  Use the function if your view
    allows the selection of only one account type. If no types are
-   selected, returns NO_TYPE.  If more than one type is selected,
-   arbitrarily returns one of the selected types. */
+   selected, returns ACCT_TYPE_NONE.  If more than one type is
+   selected, arbitrarily returns one of the selected types. */
 GNCAccountType
 gnc_tree_model_account_types_get_selection_single(GtkTreeSelection *sel);
 
