@@ -1,16 +1,18 @@
 #include <stdlib.h>
-#include <guile/gh.h>
+#include <libguile.h>
 #include <gnc-module.h>
 
 static void
-guile_main(int argc, char ** argv) {
+guile_main(void *closure, int argc, char ** argv)
+{
   gnc_module_system_init();
 /*  gnc_module_load("gnucash/gnome-utils", 0); */
   exit(0);
 }
 
 int
-main(int argc, char ** argv) {
-  gh_enter(argc, argv, guile_main);
+main(int argc, char ** argv)
+{
+  scm_boot_guile(argc, argv, guile_main, NULL);
   return 0;
 }
