@@ -29,7 +29,6 @@
 #include <glib/gi18n.h>
 
 #include "Account.h"
-#include "Group.h"
 #include "gnc-accounting-period.h"
 #include "gnc-component-manager.h"
 #include "gnc-euro.h"
@@ -120,14 +119,13 @@ gnc_ui_get_currency_accumulator(GList **list, gnc_commodity * currency, gint tot
  * @fixme Move this non-GUI code into the engine.
  **/
 static void
-gnc_ui_accounts_recurse (AccountGroup *group, GList **currency_list,
+gnc_ui_accounts_recurse (Account *parent, GList **currency_list,
                          GNCSummarybarOptions options)
 {
   gnc_numeric start_amount;
   gnc_numeric start_amount_default_currency;
   gnc_numeric end_amount;
   gnc_numeric end_amount_default_currency;
-  AccountGroup *children;
   GNCAccountType account_type;  
   gnc_commodity * account_currency;
   gnc_commodity * euro_commodity;
@@ -135,21 +133,20 @@ gnc_ui_accounts_recurse (AccountGroup *group, GList **currency_list,
   GNCCurrencyAcc *euro_accum = NULL;
   GNCCurrencyAcc *grand_total_accum = NULL;
   GNCCurrencyAcc *non_curr_accum = NULL;
-  GList *list;
-  GList *node;
+  GList *children, *node;
   gboolean non_currency = FALSE;
   Timespec end_timespec;
   Timespec start_timespec;
 
+  if (parent == NULL) return;
 
-  list = xaccGroupGetAccountList (group);
-  for (node = list; node; node = node->next)
+  children = gnc_account_get_children(parent);
+  for (node = children; node; node = g_list_next(node))
   {
     Account *account = node->data;
 
     account_type = xaccAccountGetType(account);
     account_currency = xaccAccountGetCommodity(account);
-    children = xaccAccountGetChildren(account);
 
     if(options.grand_total)
       grand_total_accum = gnc_ui_get_currency_accumulator(currency_list,
@@ -181,15 +178,15 @@ gnc_ui_accounts_recurse (AccountGroup *group, GList **currency_list,
 
     switch (account_type)
     {
-      case BANK:
-      case CASH:
-      case ASSET:
-      case STOCK:
-      case MUTUAL:
-      case CREDIT:
-      case LIABILITY:
-      case PAYABLE:
-      case RECEIVABLE:
+      case ACCT_TYPE_BANK:
+      case ACCT_TYPE_CASH:
+      case ACCT_TYPE_ASSET:
+      case ACCT_TYPE_STOCK:
+      case ACCT_TYPE_MUTUAL:
+      case ACCT_TYPE_CREDIT:
+      case ACCT_TYPE_LIABILITY:
+      case ACCT_TYPE_PAYABLE:
+      case ACCT_TYPE_RECEIVABLE:
 	end_amount = xaccAccountGetBalanceAsOfDate(account, options.end_date);
         timespecFromTime_t(&end_timespec, options.end_date);
 	end_amount_default_currency = 
@@ -226,11 +223,10 @@ gnc_ui_accounts_recurse (AccountGroup *group, GList **currency_list,
                              GNC_RND_ROUND);
 	}
 
-	if (children != NULL)
-	  gnc_ui_accounts_recurse(children, currency_list, options);
+	gnc_ui_accounts_recurse(account, currency_list, options);
 	break;
-      case INCOME:
-      case EXPENSE:
+      case ACCT_TYPE_INCOME:
+      case ACCT_TYPE_EXPENSE:
 	start_amount = xaccAccountGetBalanceAsOfDate(account, options.start_date);
         timespecFromTime_t(&start_timespec, options.start_date);
 	start_amount_default_currency = 
@@ -292,17 +288,17 @@ gnc_ui_accounts_recurse (AccountGroup *group, GList **currency_list,
                              GNC_RND_ROUND);
 	}
 
-	if (children != NULL)
-	  gnc_ui_accounts_recurse(children, currency_list, options);
+	gnc_ui_accounts_recurse(account, currency_list, options);
 	break;
-      case EQUITY:
+      case ACCT_TYPE_EQUITY:
         /* no-op, see comments at top about summing assets */
 	break;
-      case CURRENCY:
+      case ACCT_TYPE_CURRENCY:
       default:
 	break;
     }
   }
+  g_list_free(children);
 }
 
 static char*
@@ -313,13 +309,13 @@ get_total_mode_label(const char *mnemonic, int total_mode)
   switch(total_mode)
   {
   case TOTAL_CURR_TOTAL:
-    label_str = g_strdup_printf( _("%s, total:"), mnemonic );
+    label_str = g_strdup_printf( _("%s, Total:"), mnemonic );
     break;
   case TOTAL_NON_CURR_TOTAL:
-    label_str = g_strdup_printf( _("%s, non currency commodities total:"), mnemonic );
+    label_str = g_strdup_printf( _("%s, Non Currency Commodities Total:"), mnemonic );
     break;
   case TOTAL_GRAND_TOTAL:
-    label_str = g_strdup_printf( _("%s, grand total:"), mnemonic );
+    label_str = g_strdup_printf( _("%s, Grand Total:"), mnemonic );
     break;
   case TOTAL_SINGLE:
   default:
@@ -358,7 +354,7 @@ enum {
 static void
 gnc_main_window_summary_refresh (GNCMainSummary * summary)
 {
-  AccountGroup *group;
+  Account *root;
   char asset_string[256];
   char profit_string[256];
   GNCCurrencyAcc *currency_accum;
@@ -387,8 +383,8 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
   gnc_ui_get_currency_accumulator (&currency_list, options.default_currency,
 				   TOTAL_SINGLE);
 
-  group = gnc_get_current_group ();
-  gnc_ui_accounts_recurse(group, &currency_list, options);
+  root = gnc_get_current_root_account ();
+  gnc_ui_accounts_recurse(root, &currency_list, options);
 
   {
     GtkTreeIter iter;
@@ -402,6 +398,7 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
     gtk_list_store_clear(summary->datamodel);
     for (current = g_list_first(currency_list); current; current = g_list_next(current)) {
       const char *mnemonic;
+      gchar *total_mode_label;
 
       currency_accum = current->data;
 
@@ -424,13 +421,15 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
                        gnc_commodity_print_info(currency_accum->currency, TRUE));
 
       gtk_list_store_append(summary->datamodel, &iter);
+      total_mode_label = get_total_mode_label(mnemonic, currency_accum->total_mode);
       gtk_list_store_set(summary->datamodel, &iter,
-                         COLUMN_MNEMONIC_TYPE, get_total_mode_label(mnemonic, currency_accum->total_mode),
+                         COLUMN_MNEMONIC_TYPE, total_mode_label,
                          COLUMN_ASSETS,        _("Assets:"),
                          COLUMN_ASSETS_VALUE,  asset_amount_string,
                          COLUMN_PROFITS,       _("Profits:"),
                          COLUMN_PROFITS_VALUE, profit_amount_string,
                          -1);
+      g_free(total_mode_label);
     }
     gtk_combo_box_set_model(GTK_COMBO_BOX(summary->totals_combo),
 			    GTK_TREE_MODEL(summary->datamodel));
@@ -438,6 +437,14 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
 
     gtk_combo_box_set_active(GTK_COMBO_BOX(summary->totals_combo), 0);
   }
+
+  /* Free the list we created for this */
+  for (current = g_list_first(currency_list);
+       current;
+       current = g_list_next(current)) {
+    g_free(current->data);
+  }
+  g_list_free(currency_list);
 }
 
 static void
