@@ -17,8 +17,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #include "config.h"
@@ -52,42 +52,37 @@ gnc_get_username_password (GtkWidget *parent,
   dialog = glade_xml_get_widget (xml, "Username Password Dialog");
 
   if (parent)
-    gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (parent));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
 
   heading_label  = glade_xml_get_widget (xml, "heading_label");
   username_entry = glade_xml_get_widget (xml, "username_entry");
   password_entry = glade_xml_get_widget (xml, "password_entry");
 
-  gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
-
-  gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
-                                GTK_EDITABLE (username_entry));
-  gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
-                                GTK_EDITABLE (password_entry));
-
   if (heading)
     gtk_label_set_text (GTK_LABEL (heading_label), heading);
 
   if (initial_username)
     gtk_entry_set_text (GTK_ENTRY (username_entry), initial_username);
+  gtk_editable_select_region (GTK_EDITABLE (username_entry), 0, -1);
 
   if (initial_password)
     gtk_entry_set_text (GTK_ENTRY (password_entry), initial_password);
 
-  gtk_widget_grab_focus (username_entry);
+  result = gtk_dialog_run(GTK_DIALOG (dialog));
+  gtk_widget_hide(dialog);
 
-  result = gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
-
-  if (result == 0)
+  if (result == GTK_RESPONSE_OK)
   {
     *username = gtk_editable_get_chars (GTK_EDITABLE (username_entry), 0, -1);
     *password = gtk_editable_get_chars (GTK_EDITABLE (password_entry), 0, -1);
 
+    gtk_widget_destroy(dialog);
     return TRUE;
   }
 
   *username = NULL;
   *password = NULL;
 
+  gtk_widget_destroy(dialog);
   return FALSE;
 }
