@@ -25,11 +25,11 @@
 
 #include <gnome.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "Group.h"
 #include "gnc-account-merge.h"
 #include "dialog-new-user.h"
 #include "dialog-utils.h"
@@ -43,7 +43,7 @@
 #include "gnc-gconf-utils.h"
 #include "gnc-hooks.h"
 #include "gnc-component-manager.h"
-#include "../gnome-utils/gnc-dir.h"
+#include "gnc-path.h"
 #include "gnc-gui-query.h"
 #include "gnc-tree-view-account.h"
 #include "gnc-ui-util.h"
@@ -88,7 +88,7 @@ typedef struct {
   /** Map<Account*,gnc_numeric*> **/
   GHashTable *balance_hash;
 
-  AccountGroup *our_final_group;
+  Account *our_account_tree;
   QofBook *temporary;
 
   gboolean account_list_added;
@@ -185,29 +185,35 @@ gnc_get_ea_locale_dir(const char *top_dir)
 #ifdef HAVE_LC_MESSAGES
     locale = g_strdup(setlocale(LC_MESSAGES, NULL));
 #else
+# ifdef G_OS_WIN32
+    /* On win32, setlocale() doesn't say anything useful. Use
+       glib's function instead. */
+    locale = g_win32_getlocale();
+# else
     /*
      * Mac OS X 10.1 and earlier, not only doesn't have LC_MESSAGES
      * setlocale can sometimes return NULL instead of "C"
      */
     locale = g_strdup(setlocale(LC_ALL, NULL) ? 
 		      setlocale(LC_ALL, NULL) : "C");
+# endif
 #endif
 
     i = strlen(locale);
-    ret = g_strdup_printf("%s/%s", top_dir, locale);
+    ret = g_build_filename(top_dir, locale, (char *)NULL);
 
-    while (stat(ret, &buf) != 0)
+    while (g_stat(ret, &buf) != 0)
     { 
 	i--;
 	if (i<1) 
 	{
 	    g_free(ret);
-	    ret = g_strdup_printf("%s/%s", top_dir, default_locale);
+	    ret = g_build_filename(top_dir, default_locale, (char *)NULL);
 	    break;
 	}
 	locale[i] = '\0';
 	g_free(ret);
-	ret = g_strdup_printf("%s/%s", top_dir, locale);
+	ret = g_build_filename(top_dir, locale, (char *)NULL);
     }
     
     g_free(locale);
@@ -358,6 +364,7 @@ static void
 account_categories_tree_view_prepare (hierarchy_data  *data)
 {
 	GSList *list;
+	gchar *gnc_accounts_dir;
 	gchar *locale_dir;
 	GtkTreeView *tree_view;
 	GtkListStore *model;
@@ -366,9 +373,10 @@ account_categories_tree_view_prepare (hierarchy_data  *data)
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
 
-	locale_dir = gnc_get_ea_locale_dir (GNC_ACCOUNTS_DIR);
- 	list = gnc_load_example_account_list (data->temporary,
-					      locale_dir);
+	gnc_accounts_dir = gnc_path_get_accountsdir ();
+	locale_dir = gnc_get_ea_locale_dir (gnc_accounts_dir);
+ 	list = gnc_load_example_account_list (locale_dir);
+	g_free (gnc_accounts_dir);
 	g_free (locale_dir);
 
 	/* Prepare the account_categories GtkTreeView with a model and with some columns */
@@ -447,7 +455,6 @@ on_choose_account_categories_prepare (GnomeDruidPage  *gnomedruidpage,
 
     /* Build the categories tree if necessary */
     gnc_suspend_gui_refresh ();
-    data->temporary = qof_book_new();
     account_categories_tree_view_prepare (data);
     gnc_resume_gui_refresh ();
   }
@@ -473,14 +480,18 @@ categories_tree_selection_changed (GtkTreeSelection *selection,
 
 	/* Add a new one if something selected */
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gchar *text2;
 		gtk_tree_model_get (model, &iter, COL_ACCOUNT, &gea, -1);
-		text = g_strdup_printf(_("<b>Accounts in '%s'</b>"), gea->title);
+		/* Translators: '%s' is the name of the selected account hierarchy template. */
+		text2 = g_strdup_printf(_("Accounts in '%s'"), gea->title);
+		text = g_strdup_printf("<b>%s</b>", text2);
 		gtk_label_set_markup(data->category_accounts_label, text);
+		g_free(text2);
 		g_free(text);
 		buffer = gtk_text_view_get_buffer(data->category_description);
 		gtk_text_buffer_set_text(buffer, gea->long_description, -1);
 
-		tree_view = gnc_tree_view_account_new_with_group (gea->group, FALSE);
+		tree_view = gnc_tree_view_account_new_with_root (gea->root, FALSE);
 		/* Override the normal fixed (user settable) sizing */
 		column = gtk_tree_view_get_column(GTK_TREE_VIEW(tree_view), 0);
 		gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
@@ -490,8 +501,10 @@ categories_tree_selection_changed (GtkTreeSelection *selection,
 		gtk_container_add(GTK_CONTAINER(data->category_accounts_container), GTK_WIDGET(tree_view));
 		gtk_widget_show(GTK_WIDGET(tree_view));
 	} else {
-		gtk_label_set_markup(data->category_accounts_label,
-				     _("<b>Accounts in Category</b>"));
+		gchar *text;
+		text = g_strdup_printf ("<b>%s</b>", _("Accounts in Category"));
+		gtk_label_set_markup(data->category_accounts_label, text);
+		g_free (text);
 		buffer = gtk_text_view_get_buffer(data->category_description);
 		gtk_text_buffer_set_text(buffer, "", -1);
 	}
@@ -540,13 +553,13 @@ clear_all_clicked (GtkButton       *button,
  ************************************************************/
 
 static void
-delete_our_final_group (hierarchy_data *data)
+delete_our_account_tree (hierarchy_data *data)
 {
-  if (data->our_final_group != NULL)
+  if (data->our_account_tree != NULL)
   {
-    xaccAccountGroupBeginEdit (data->our_final_group);
-    xaccAccountGroupDestroy (data->our_final_group);
-    data->our_final_group = NULL;
+    xaccAccountBeginEdit (data->our_account_tree);
+    xaccAccountDestroy (data->our_account_tree);
+    data->our_account_tree = NULL;
   }
 }
 
@@ -564,27 +577,27 @@ clone_account (const Account* from, gnc_commodity *com)
 
 struct add_group_data_struct
 {
-  AccountGroup *to;
+  Account *to;
   Account *parent;
   gnc_commodity *com;
 };
 
-static gpointer
+static void
 add_groups_for_each (Account *toadd, gpointer data)
 {
   struct add_group_data_struct *dadata = data;
   Account *foundact;
     
-  foundact = xaccGetAccountFromName (dadata->to, xaccAccountGetName(toadd));
+  foundact = gnc_account_lookup_by_name(dadata->to, xaccAccountGetName(toadd));
 
   if (!foundact)
   {
     foundact = clone_account (toadd, dadata->com);
 
     if (dadata->to)
-      xaccGroupInsertAccount (dadata->to, foundact);
+      gnc_account_append_child (dadata->to, foundact);
     else if (dadata->parent)
-      xaccAccountInsertSubAccount (dadata->parent, foundact);
+      gnc_account_append_child (dadata->parent, foundact);
     else
     {
       g_warning ("add_groups_for_each: no valid parent");
@@ -592,47 +605,42 @@ add_groups_for_each (Account *toadd, gpointer data)
   }
 
   {
-    AccountGroup *addgrp = xaccAccountGetChildren (toadd);
-
-    if (xaccGroupGetNumAccounts(addgrp) > 0)
+    if (gnc_account_n_children(toadd) > 0)
     {
       struct add_group_data_struct downdata;
 
-      downdata.to = xaccAccountGetChildren(foundact);
+      downdata.to = foundact;
       downdata.parent = foundact;
       downdata.com = dadata->com;
 
-      xaccGroupForEachAccount (addgrp, add_groups_for_each,
-                               &downdata, FALSE);
+      gnc_account_foreach_child (toadd, add_groups_for_each, &downdata);
     }
   }
-
-  return NULL;
 }
 
 static void
-add_groups_to_with_random_guids (AccountGroup *into, AccountGroup *from,
-                                 gnc_commodity *com)
+add_new_accounts_with_random_guids (Account *into, Account *from,
+                                    gnc_commodity *com)
 {
   struct add_group_data_struct data;
   data.to = into;
   data.parent = NULL;
   data.com = com;
     
-  xaccGroupForEachAccount (from, add_groups_for_each, &data, FALSE);
+  gnc_account_foreach_child (from, add_groups_for_each, &data);
 }
 
-static AccountGroup *
-hierarchy_merge_groups (GSList *dalist, gnc_commodity *com)
+static Account *
+hierarchy_merge_accounts (GSList *dalist, gnc_commodity *com)
 {
   GSList *mark;
-  AccountGroup *ret = xaccMallocAccountGroup (gnc_get_current_book ());
+  Account *ret = xaccMallocAccount (gnc_get_current_book ());
 
   for (mark = dalist; mark; mark = mark->next)
   {
     GncExampleAccount *xea = mark->data;
 
-    add_groups_to_with_random_guids (ret, xea->group, com);
+    add_new_accounts_with_random_guids (ret, xea->root, com);
   }
 
   return ret;
@@ -698,12 +706,12 @@ balance_cell_data_func (GtkTreeViewColumn *tree_column,
 		string = xaccPrintAmount (balance, print_info);
 	}
 
- 	if (xaccAccountGetType(account) == EQUITY) {
+ 	if (xaccAccountGetType(account) == ACCT_TYPE_EQUITY) {
 	  allow_value = FALSE;
 	  string=_("zero");
 	} else {
           GncAccountMergeDisposition disp;
-          disp = determine_merge_disposition(gnc_book_get_group(gnc_get_current_book()), account);
+          disp = determine_merge_disposition(gnc_book_get_root_account(gnc_get_current_book()), account);
           if (disp == GNC_ACCOUNT_MERGE_DISPOSITION_CREATE_NEW)
           {
                   allow_value = !xaccAccountGetPlaceholder(account);
@@ -736,8 +744,8 @@ balance_cell_edited (GtkCellRendererText *cell,
 
 	account = gnc_tree_view_account_get_selected_account(data->final_account_tree);
 	if (account == NULL) {
-	  printf("Account is null\n");
-	  return;
+      g_critical("account is null");
+      return;
 	}
 
 	error_loc = NULL;
@@ -745,8 +753,17 @@ balance_cell_edited (GtkCellRendererText *cell,
 	  amount = gnc_numeric_zero();
 	  g_object_set (G_OBJECT(cell), "text", "", NULL);
 	}
+    /* Bug#348364: Emulating price-cell, we need to ensure the denominator of
+     * the amount is in the SCU of the account's commodity (so
+     * gnc-ui-util.c:is_decimal_fraction() on the remainder denom for
+     * fractional values will be a "decimal").
+     */
+    {
+        int account_cmdty_fraction = xaccAccountGetCommoditySCU(account);
+        amount = gnc_numeric_convert(amount, account_cmdty_fraction, GNC_RND_ROUND);
+    }
 	set_final_balance (data->balance_hash, account, amount);
-	qof_event_gen ((QofEntity*)account, QOF_EVENT_MODIFY, NULL);
+	qof_event_gen (QOF_INSTANCE(account), QOF_EVENT_MODIFY, NULL);
 }
 
 static void
@@ -756,22 +773,22 @@ placeholder_cell_data_func (GtkTreeViewColumn *tree_column,
                             GtkTreeIter *iter,
                             gpointer user_data)
 {
-	Account *account;
+	Account *account, *root;
 	gboolean willbe_placeholder = FALSE;
         GncAccountMergeDisposition disp;
 
 	g_return_if_fail (GTK_TREE_MODEL (model));
 	account = gnc_tree_view_account_get_account_from_iter (model, iter);
-        disp = determine_merge_disposition(gnc_book_get_group(gnc_get_current_book()), account);
+        root = gnc_book_get_root_account(gnc_get_current_book());
+        disp = determine_merge_disposition(root, account);
         switch (disp)
         {
         case GNC_ACCOUNT_MERGE_DISPOSITION_USE_EXISTING: {
                 /* find the existing account, do whatever it is. */
                 gchar *full_name;
                 Account *existing_acct;
-                AccountGroup *root_group = gnc_book_get_group(gnc_get_current_book());
                 full_name = xaccAccountGetFullName(account);
-                existing_acct = xaccGetAccountFromFullName(root_group, full_name);
+                existing_acct = gnc_account_lookup_by_full_name(root, full_name);
                 willbe_placeholder = xaccAccountGetPlaceholder(existing_acct);
                 g_free(full_name);
         } break;
@@ -792,7 +809,7 @@ use_existing_account_data_func(GtkTreeViewColumn *tree_column,
                                gpointer user_data)
 {
   Account *new_acct;
-  AccountGroup *real_root;
+  Account *real_root;
   GncAccountMergeDisposition disposition;
   char *to_user = "(error; unknown condition)";
 
@@ -804,15 +821,15 @@ use_existing_account_data_func(GtkTreeViewColumn *tree_column,
     return;
   }
 
-  real_root = gnc_book_get_group(gnc_get_current_book());
+  real_root = gnc_book_get_root_account(gnc_get_current_book());
   disposition = determine_merge_disposition(real_root, new_acct);
   switch (disposition)
   {
   case GNC_ACCOUNT_MERGE_DISPOSITION_USE_EXISTING:
-    to_user = "yes";
+    to_user = _("Yes");
     break;
   case GNC_ACCOUNT_MERGE_DISPOSITION_CREATE_NEW:
-    to_user = "no";
+    to_user = _("No");
     break;
   }
   
@@ -843,18 +860,18 @@ on_final_account_prepare (GnomeDruidPage  *gnomedruidpage,
     gtk_widget_destroy(GTK_WIDGET(data->final_account_tree));
     data->final_account_tree = NULL;
   }
-  delete_our_final_group (data);
+  delete_our_account_tree (data);
 
 
   /* Build a new account list */
   actlist = get_selected_account_list (data->categories_tree);
   com = gnc_currency_edit_get_currency (GNC_CURRENCY_EDIT(data->currency_selector));
-  data->our_final_group = hierarchy_merge_groups (actlist, com);
+  data->our_account_tree = hierarchy_merge_accounts (actlist, com);
 
 
   /* Now build a new account tree */
   data->final_account_tree
-    = GNC_TREE_VIEW_ACCOUNT(gnc_tree_view_account_new_with_group (data->our_final_group, FALSE));
+    = GNC_TREE_VIEW_ACCOUNT(gnc_tree_view_account_new_with_root (data->our_account_tree, FALSE));
   tree_view = GTK_TREE_VIEW(data->final_account_tree);
   gnc_tree_view_account_set_name_edited(data->final_account_tree,
                                         gnc_tree_view_account_name_edited_cb);
@@ -912,7 +929,7 @@ on_final_account_prepare (GnomeDruidPage  *gnomedruidpage,
   }
 
   // only in the case where there *are* existing accounts...
-  if (xaccGroupGetNumSubAccounts(gnc_book_get_group(gnc_get_current_book())) > 0)
+  if (gnc_account_n_descendants(gnc_book_get_root_account(gnc_get_current_book())) > 0)
   {
     GList *renderers;
     column = gnc_tree_view_add_text_column(GNC_TREE_VIEW(tree_view),
@@ -945,13 +962,13 @@ on_cancel (GnomeDruid      *gnomedruid,
 {
   gnc_suspend_gui_refresh ();
   delete_hierarchy_dialog (data);
-  delete_our_final_group (data);
+  delete_our_account_tree (data);
   gncp_new_user_finish ();
   g_free(data);
   gnc_resume_gui_refresh ();
 }
 
-static gpointer
+static void
 starting_balance_helper (Account *account, hierarchy_data *data)
 {
   gnc_numeric balance;
@@ -962,8 +979,6 @@ starting_balance_helper (Account *account, hierarchy_data *data)
   if (!gnc_numeric_zero_p (balance))
     gnc_account_create_opening_balance (account, balance, time (NULL),
                                         gnc_get_current_book ());
-
-  return NULL;
 }
 
 void
@@ -974,11 +989,11 @@ on_finish (GnomeDruidPage  *gnomedruidpage,
         GncHierarchyDruidFinishedCallback when_completed;
 	ENTER (" ");
 
-	if (data->our_final_group)
+	if (data->our_account_tree)
         {
-	  xaccGroupForEachAccount (data->our_final_group,
-                                   (AccountCallback)starting_balance_helper,
-				   data, TRUE);
+	  gnc_account_foreach_descendant (data->our_account_tree,
+					  (AccountCb)starting_balance_helper,
+					  data);
         }
 
         // delete before we suspend GUI events, and then muck with the model,
@@ -989,10 +1004,9 @@ on_finish (GnomeDruidPage  *gnomedruidpage,
 
 	gnc_suspend_gui_refresh ();
 
-        account_group_merge(gnc_get_current_group(), data->our_final_group);
+        account_trees_merge(gnc_get_current_root_account(), data->our_account_tree);
 
-        delete_our_final_group (data);
-        qof_book_destroy(data->temporary);
+        delete_our_account_tree (data);
 
         when_completed = data->when_completed;
 	g_free(data);
