@@ -1864,7 +1864,7 @@ report_helper (GNCLedgerDisplay *ledger, Split *split, Query *query)
   arg = scm_apply (func, args, SCM_EOL);
   g_return_val_if_fail (SCM_EXACTP (arg), -1);
 
-  return scm_num2int (arg, SCM_ARG1, __FUNCTION__);
+  return scm_num2int (arg, SCM_ARG1, G_STRFUNC);
 }
 
 /************************************************************/
@@ -2470,6 +2470,7 @@ gnc_plugin_page_register_cmd_blank_transaction (GtkAction *action,
     gnc_split_register_redraw (reg);
 
   gnc_split_reg_jump_to_blank (priv->gsr);
+  LEAVE(" ");
 }
 
 static void
