@@ -33,7 +33,7 @@
 #include "dialog-account.h"
 #include "dialog-commodity.h"
 #include "dialog-options.h"
-#include "dialog-scheduledxaction.h"
+#include "dialog-sx-editor.h"
 #include "dialog-transfer.h"
 #include "dialog-totd.h"
 #include "druid-hierarchy.h"
@@ -44,6 +44,7 @@
 #include "gnc-file.h"
 #include "gnc-filepath-utils.h"
 #include "gnc-hooks.h"
+#include "gfec.h"
 #include "gnc-main-window.h"
 #include "gnc-menu-extensions.h"
 #include "gnc-plugin-menu-additions.h" /* FIXME Remove this line*/
@@ -68,7 +69,6 @@
 #include "window-report.h"
 #include "gnc-window.h"
 #include "gnc-gkeyfile-utils.h"
-#include <g-wrap-wct.h>
 
 
 /** GLOBALS *********************************************************/
@@ -83,7 +83,7 @@ static QofLogModule log_module = GNC_MOD_GUI;
   {                                                                         \
     GUID guid;                                                              \
     QofCollection *col;                                                     \
-    QofEntity *entity;                                                      \
+    QofInstance *entity;                                                      \
     if (!string_to_guid (location + strlen(URL_TYPE_STR), &guid))           \
     {                                                                       \
       result->error_message = g_strdup_printf (_("Bad URL: %s"), location); \
@@ -93,7 +93,8 @@ static QofLogModule log_module = GNC_MOD_GUI;
     entity = qof_collection_lookup_entity (col, &guid);                     \
     if (NULL == entity)                                                     \
     {                                                                       \
-      result->error_message = g_strdup_printf (_("Entity Not Found: %s"), location); \
+      result->error_message = g_strdup_printf (_("Entity Not Found: %s"),   \
+                                               location);                   \
       return FALSE;                                                         \
     }                                                                       \
 
@@ -118,8 +119,8 @@ gnc_html_register_url_cb (const char *location, const char *label,
   /* href="gnc-register:account=My Bank Account" */
   if (strncmp("account=", location, 8) == 0)
   {
-    account = xaccGetAccountFromFullName (gnc_get_current_group (),
-                                          location + 8);
+    account = gnc_account_lookup_by_full_name (gnc_get_current_root_account (),
+					       location + 8);
   }
 
   /* href="gnc-register:guid=12345678901234567890123456789012" */
@@ -201,11 +202,6 @@ gnc_html_price_url_cb (const char *location, const char *label,
  *  iterates through this state information, calling a helper function
  *  to recreate each open window.
  *
- *  If the "new" state file cannot be found, this function will open
- *  an account tree window and then attempt to invoke the old gnucash
- *  1.x state routines.  This provides a fluid transition for users
- *  from the old to the new state systems.
- *
  *  @note The name of the state file is based on the name of the data
  *  file, not the path name of the data file.  If there are multiple
  *  data files with the same name, the state files will be suffixed
@@ -226,7 +222,7 @@ gnc_restore_all_state (gpointer session, gpointer unused)
     GError *error = NULL;
     
     url = qof_session_get_url(session);
-    ENTER("session %p (%s)", session, url);
+    ENTER("session %p (%s)", session, url ? url : "(null)");
     if (!url) {
         LEAVE("no url, nothing to do");
         return;
@@ -234,7 +230,7 @@ gnc_restore_all_state (gpointer session, gpointer unused)
     
     /* Get the book GUID */
     book = qof_session_get_book(session);
-    guid = qof_entity_get_guid(QOF_ENTITY(book));
+    guid = qof_entity_get_guid(QOF_INSTANCE(book));
     guid_string = guid_to_string(guid);
     
     keyfile = gnc_find_state_file(url, guid_string, &filename);
@@ -243,19 +239,7 @@ gnc_restore_all_state (gpointer session, gpointer unused)
 
     if (!keyfile) {
         gnc_main_window_restore_default_state();
-        
-#if (GNUCASH_MAJOR_VERSION < 2) || ((GNUCASH_MAJOR_VERSION == 2) && (GNUCASH_MINOR_VERSION == 0))
-        /* See if there's an old style state file to be found */
-        scm_call_1(scm_c_eval_string("gnc:main-window-book-open-handler"),
-                   (session ?
-                    gw_wcp_assimilate_ptr (session, scm_c_eval_string("<gnc:Session*>")) :
-                    SCM_BOOL_F));
-        /* At this point the reports have only been loaded into
-           memory.  Now we create their ui component. */
-        gnc_reports_show_all(session);
-#endif
-        
-        LEAVE("old");
+        LEAVE("no state file");
         return;
     }
     
@@ -271,7 +255,7 @@ gnc_restore_all_state (gpointer session, gpointer unused)
 #endif
     
     /* validate top level info */
-    file_guid = gnc_key_file_get_string(keyfile, STATE_FILE_TOP, 
+    file_guid = g_key_file_get_string(keyfile, STATE_FILE_TOP, 
                                       STATE_FILE_BOOK_GUID, &error);
     if (error) {
         g_warning("error reading group %s key %s: %s",
@@ -325,7 +309,7 @@ gnc_save_all_state (gpointer session, gpointer unused)
     
     
     url = qof_session_get_url(session);
-    ENTER("session %p (%s)", session, url);
+    ENTER("session %p (%s)", session, url ? url : "(null)");
     if (!url) {
         LEAVE("no url, nothing to do");
         return;
@@ -333,7 +317,7 @@ gnc_save_all_state (gpointer session, gpointer unused)
 
     /* Get the book GUID */
     book = qof_session_get_book(session);
-    guid = qof_entity_get_guid(QOF_ENTITY(book));
+    guid = qof_entity_get_guid(QOF_INSTANCE(book));
     guid_string = guid_to_string(guid);
 
     /* Find the filename to use.  This returns the data from the
