@@ -16,15 +16,16 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #ifndef GNC_HBCI_GETTRANS_H
 #define GNC_HBCI_GETTRANS_H
 
-#include <gnome.h>
 #include <aqbanking/jobgettransactions.h>
+
+#include "import-main-matcher.h"
 #include "Account.h"
 
 /** Start a GetTrans job. */
@@ -39,5 +40,25 @@ gnc_hbci_gettrans_final(GtkWidget *parent,
 			const AB_JOB *trans_job,
 			gboolean run_until_done);
 
+/** Finalize the final importing part of a GetTrans job.  Returns true
+ * if everything has been finished succesfully. */
+gboolean
+gnc_hbci_import_final(GtkWidget *parent, 
+		      Account *gnc_acc,
+		      AB_TRANSACTION_LIST2 *trans_list, 
+		      gboolean run_until_done);
+
+/** user_data struct for the gnc_hbci_trans_list_cb() structure */
+struct trans_list_data 
+{
+  Account *gnc_acc;
+  GNCImportMainMatcher *importer_generic;
+};
+
+/** AB_TRANSACTION_LIST2_foreach callback. The Conversion from HBCI to
+   GNC transaction is done here, once for each AB_TRANSACTION.  */
+AB_TRANSACTION *gnc_hbci_trans_list_cb(AB_TRANSACTION *imported_trans, 
+				       void *user_data);
+
 
 #endif /* GNC_HBCI_GETTRANS_H */
