@@ -29,6 +29,10 @@
 #define KEY_CLOSE_ON_FINISH "close_on_finish"
 #define KEY_REMEMBER_PIN    "remember_pin"
 #define KEY_VERBOSE_DEBUG   "verbose_debug"
+#define KEY_FORMAT_DTAUS    "format_dtaus"
+#define KEY_FORMAT_CSV      "format_csv"
+#define KEY_FORMAT_SWIFT940 "format_swift_mt940"
+#define KEY_FORMAT_SWIFT942 "format_swift_mt942"
 
 typedef struct _inter_data GNCInteractor;
 
@@ -44,7 +48,8 @@ void GNCInteractor_erasePIN(GNCInteractor *i);
 void GNCInteractor_reparent (GNCInteractor *i, GtkWidget *new_parent);
 gboolean GNCInteractor_get_cache_valid(const GNCInteractor *i);
 void GNCInteractor_set_cache_valid(GNCInteractor *i, gboolean value);
-GtkWidget *GNCInteractor_parent(GNCInteractor *i);
+GtkWidget *GNCInteractor_parent(const GNCInteractor *i);
+GtkWidget *GNCInteractor_dialog(const GNCInteractor *i);
 void GNCInteractor_add_log_text (GNCInteractor *i, const char *msg);
 /** Returns true if aqbanking requested to show a msgBox of type
     error. (Note: This happens very seldomly.) */
