@@ -560,8 +560,6 @@ int ofx_proc_account_cb(struct OfxAccountData data, void * account_user_data)
   gchar * account_type_name = NULL;
 
   if(data.account_id_valid==true){
-    //printf("ofx_proc_account() Now calling gnc_import_select_account()\n");
-    printf("WRITEME:  ofx_proc_account() Fill in the account type, default name, currency, etc.  \n"); 
     commodity_table = gnc_get_current_commodities ();
     if( data.currency_valid == true)
       {
