@@ -25,43 +25,41 @@
  */
 #include "config.h"
 
-#include <gtk/gtk.h>
+#include <gmodule.h>
 
 #include "gnc-ofx-import.h"
 #include "gnc-module.h"
 #include "gnc-module-api.h"
 #include "gnc-plugin-ofx.h"
 
+GNC_MODULE_API_DECL(libgncmod_ofx)
+
 /* version of the gnc module system interface we require */
-int libgncmod_ofx_LTX_gnc_module_system_interface = 0;
+int libgncmod_ofx_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_ofx_LTX_gnc_module_current  = 0;
-int libgncmod_ofx_LTX_gnc_module_revision = 0;
-int libgncmod_ofx_LTX_gnc_module_age      = 0;
+int libgncmod_ofx_gnc_module_current  = 0;
+int libgncmod_ofx_gnc_module_revision = 0;
+int libgncmod_ofx_gnc_module_age      = 0;
 
 //static GNCModule bus_core;
 //static GNCModule file;
 
-/* forward references */
-char *libgncmod_ofx_LTX_gnc_module_path(void);
-char *libgncmod_ofx_LTX_gnc_module_description(void);
-int libgncmod_ofx_LTX_gnc_module_init(int refcount);
-int libgncmod_ofx_LTX_gnc_module_end(int refcount);
-
 
 char *
-libgncmod_ofx_LTX_gnc_module_path(void)
+libgncmod_ofx_gnc_module_path(void)
 {
   return g_strdup("gnucash/import-export/ofx");
 }
+
 char *
-libgncmod_ofx_LTX_gnc_module_description(void)
+libgncmod_ofx_gnc_module_description(void)
 {
   return g_strdup("Gnome GUI and C code for OFX importer using libofx");
 }
+
 int
-libgncmod_ofx_LTX_gnc_module_init(int refcount)
+libgncmod_ofx_gnc_module_init(int refcount)
 {
   if(!gnc_module_load("gnucash/engine", 0))
   {
@@ -82,12 +80,12 @@ libgncmod_ofx_LTX_gnc_module_init(int refcount)
 
   /* Add menu items with C callbacks */
   gnc_plugin_ofx_create_plugin();
-  
+
   return TRUE;
 }
 
 int
-libgncmod_ofx_LTX_gnc_module_end(int refcount)
+libgncmod_ofx_gnc_module_end(int refcount)
 {
   return TRUE;
 }
