@@ -26,7 +26,6 @@
 #include <time.h>
 
 #include "Account.h"
-#include "Group.h"
 #include "Query.h"
 #include "QueryCore.h"
 #include "QueryNew.h"
@@ -196,12 +195,12 @@ static SplitRegisterStyle
 gnc_get_default_register_style (GNCAccountType type)
 {
   SplitRegisterStyle new_style = REG_STYLE_LEDGER;
-  char *style_string;
+  gchar *style_string;
 
   switch (type) {
 #if 0
-  case PAYABLE:
-  case RECEIVABLE:
+  case ACCT_TYPE_PAYABLE:
+  case ACCT_TYPE_RECEIVABLE:
     new_style = REG_STYLE_LEDGER;
     break;
 #endif
@@ -215,9 +214,9 @@ gnc_get_default_register_style (GNCAccountType type)
       new_style = REG_STYLE_AUTO_LEDGER;
     else
       new_style = REG_STYLE_LEDGER;
-    
+
     if (style_string != NULL)
-      free(style_string);
+      g_free(style_string);
 
     break;
   }
@@ -246,41 +245,41 @@ gnc_get_reg_type (Account *leader, GNCLedgerDisplayType ld_type)
   {
     switch (account_type)
     {
-      case BANK:
+      case ACCT_TYPE_BANK:
         return BANK_REGISTER;
 
-      case CASH:
+      case ACCT_TYPE_CASH:
         return CASH_REGISTER;
 
-      case ASSET:
+      case ACCT_TYPE_ASSET:
         return ASSET_REGISTER;
 
-      case CREDIT:
+      case ACCT_TYPE_CREDIT:
         return CREDIT_REGISTER;
 
-      case LIABILITY:
+      case ACCT_TYPE_LIABILITY:
         return LIABILITY_REGISTER;
 
-      case PAYABLE:
+      case ACCT_TYPE_PAYABLE:
         return PAYABLE_REGISTER;
 
-      case RECEIVABLE:
+      case ACCT_TYPE_RECEIVABLE:
         return RECEIVABLE_REGISTER;
 
-      case STOCK:
-      case MUTUAL:
+      case ACCT_TYPE_STOCK:
+      case ACCT_TYPE_MUTUAL:
         return STOCK_REGISTER;
 
-      case INCOME:
+      case ACCT_TYPE_INCOME:
         return INCOME_REGISTER;
 
-      case EXPENSE:
+      case ACCT_TYPE_EXPENSE:
         return EXPENSE_REGISTER;
 
-      case EQUITY:
+      case ACCT_TYPE_EQUITY:
         return EQUITY_REGISTER;
 
-      case CURRENCY:
+      case ACCT_TYPE_CURRENCY:
         return CURRENCY_REGISTER;
 
       default:
@@ -297,39 +296,37 @@ gnc_get_reg_type (Account *leader, GNCLedgerDisplayType ld_type)
 
   switch (account_type)
   {
-    case BANK:
-    case CASH:
-    case ASSET:
-    case CREDIT:
-    case LIABILITY:
-    case RECEIVABLE:
-    case PAYABLE:
+    case ACCT_TYPE_BANK:
+    case ACCT_TYPE_CASH:
+    case ACCT_TYPE_ASSET:
+    case ACCT_TYPE_CREDIT:
+    case ACCT_TYPE_LIABILITY:
+    case ACCT_TYPE_RECEIVABLE:
+    case ACCT_TYPE_PAYABLE:
     {
-      /* If any of the sub-accounts have STOCK or MUTUAL types,
-       * then we must use the PORTFOLIO_LEDGER ledger. Otherwise,
-       * a plain old GENERAL_LEDGER will do. */
+      /* If any of the sub-accounts have ACCT_TYPE_STOCK or
+       * ACCT_TYPE_MUTUAL types, then we must use the PORTFOLIO_LEDGER
+       * ledger. Otherwise, a plain old GENERAL_LEDGER will do. */
       gpointer ret;
       reg_type = GENERAL_LEDGER;
 
-      ret = xaccGroupForEachAccount (xaccAccountGetChildren (leader),
-                                    look_for_portfolio_cb,
-                                    NULL, TRUE);
+      ret = gnc_account_foreach_descendant_until(leader, look_for_portfolio_cb, NULL);
       if (ret) reg_type = PORTFOLIO_LEDGER;
       break;
     }
 
-    case STOCK:
-    case MUTUAL:
-    case CURRENCY:
+    case ACCT_TYPE_STOCK:
+    case ACCT_TYPE_MUTUAL:
+    case ACCT_TYPE_CURRENCY:
       reg_type = PORTFOLIO_LEDGER;
       break;
 
-    case INCOME:
-    case EXPENSE:
+    case ACCT_TYPE_INCOME:
+    case ACCT_TYPE_EXPENSE:
       reg_type = INCOME_LEDGER;
       break;
 
-    case EQUITY:
+    case ACCT_TYPE_EQUITY:
       reg_type = GENERAL_LEDGER;
       break;
 
@@ -360,8 +357,8 @@ gnc_ledger_display_simple (Account *account)
   gboolean use_double_line;
 
   switch (acc_type) {
-  case PAYABLE:
-  case RECEIVABLE:
+  case ACCT_TYPE_PAYABLE:
+  case ACCT_TYPE_RECEIVABLE:
     use_double_line = TRUE;
     break;
   default:
@@ -404,20 +401,20 @@ gnc_ledger_display_gl (void)
 
   /* In lieu of not "mis-using" some portion of the infrastructure by writing
    * a bunch of new code, we just filter out the accounts of the template
-   * transactions.  While these are in a seperate AccountGroup just for this
-   * reason, the query engine makes no distinction between AccountGroups.
+   * transactions.  While these are in a seperate Account trees just for this
+   * reason, the query engine makes no distinction between Account trees.
    * See Gnome Bug 86302.
    *         -- jsled */
   {
-    AccountGroup *tAG;
-    AccountList *al;
+    Account *tRoot;
+    GList *al;
     
-    tAG = gnc_book_get_template_group( gnc_get_current_book() );
-    al = xaccGroupGetSubAccounts( tAG );
+    tRoot = gnc_book_get_template_root( gnc_get_current_book() );
+    al = gnc_account_get_descendants( tRoot );
     xaccQueryAddAccountMatch( query, al, GUID_MATCH_NONE, QUERY_AND );
     g_list_free (al);
     al = NULL;
-    tAG = NULL;
+    tRoot = NULL;
   }
 
   gnc_tm_get_today_start(&tm);
@@ -448,8 +445,7 @@ gnc_ledger_display_template_gl (char *id)
   Query *q;
   GNCLedgerDisplay *ld;
   SplitRegister *sr;
-  AccountGroup *ag;
-  Account *acct;
+  Account *root, *acct;
   gboolean isTemplateModeTrue;
 
   acct = NULL;
@@ -461,8 +457,8 @@ gnc_ledger_display_template_gl (char *id)
   xaccQuerySetBook (q, book);
 
   if ( id != NULL ) {
-    ag = gnc_book_get_template_group (book);
-    acct = xaccGetAccountFromName (ag, id);
+    root = gnc_book_get_template_root (book);
+    acct = gnc_account_lookup_by_name(root, id);
     g_assert( acct );
     xaccQueryAddSingleAccountMatch (q, acct, QUERY_AND);
   }
@@ -630,7 +626,7 @@ gnc_ledger_display_make_query (GNCLedgerDisplay *ld,
   leader = gnc_ledger_display_leader (ld);
 
   if (ld->ld_type == LD_SUBACCOUNT)
-    accounts = xaccGroupGetSubAccounts (xaccAccountGetChildren (leader));
+    accounts = gnc_account_get_descendants (leader);
   else
     accounts = NULL;
 
