@@ -1,5 +1,6 @@
 /********************************************************************\
  * split-register-layout.c -- split register layout object          *
+ * Copyright (C) 1998 Linas Vepstas <linas@linas.org>               *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -15,22 +16,22 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
 
 #include "config.h"
 
 #include <glib.h>
+#include <glib/gi18n.h>
 
-#include "gnc-engine-util.h"
-#include "messages.h"
+#include "gnc-engine.h"
 #include "split-register-layout.h"
 
 
 /* This static indicates the debugging module that this .o belongs to.  */
-static short module = MOD_REGISTER;
+static QofLogModule log_module = GNC_MOD_REGISTER;
 
 
 static void
@@ -111,7 +112,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
           gnc_table_layout_set_cell (layout, curs, CRED_CELL,  0, 6);
         }
         gnc_table_layout_set_cell (layout, curs, BALN_CELL,  0, 7);
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
 
         curs_last = curs;
         curs = gnc_table_layout_get_cursor (layout,
@@ -121,6 +122,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -131,7 +133,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TDEBT_CELL, 0, 5);
         gnc_table_layout_set_cell (layout, curs, TCRED_CELL, 0, 6);
         gnc_table_layout_set_cell (layout, curs, TBALN_CELL, 0, 7);
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
 
         curs_last = curs;
         curs = gnc_table_layout_get_cursor (layout,
@@ -140,6 +142,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         copy_cursor_row (layout, curs, curs_last, 0);
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -158,7 +161,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
           gnc_table_layout_set_cell (layout, curs, DEBT_CELL, 0, 5);
           gnc_table_layout_set_cell (layout, curs, CRED_CELL, 0, 6);
         }
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 8);
 
         break;
       }
@@ -171,13 +174,13 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
                                             CURSOR_SINGLE_LEDGER);
 
         gnc_table_layout_set_cell (layout, curs, DATE_CELL,  0, 0);
-	gnc_table_layout_set_cell (layout, curs, TYPE_CELL,  0, 1);
-	gnc_table_layout_set_cell (layout, curs, DDUE_CELL,  0, 2);
+        gnc_table_layout_set_cell (layout, curs, TYPE_CELL,  0, 1);
+        gnc_table_layout_set_cell (layout, curs, DDUE_CELL,  0, 2);
         gnc_table_layout_set_cell (layout, curs, NUM_CELL,   0, 3);
         gnc_table_layout_set_cell (layout, curs, DESC_CELL,  0, 4);
         gnc_table_layout_set_cell (layout, curs, MXFRM_CELL, 0, 5);
-	gnc_table_layout_set_cell (layout, curs, DEBT_CELL,  0, 6);
-	gnc_table_layout_set_cell (layout, curs, CRED_CELL,  0, 7);
+        gnc_table_layout_set_cell (layout, curs, DEBT_CELL,  0, 6);
+        gnc_table_layout_set_cell (layout, curs, CRED_CELL,  0, 7);
         gnc_table_layout_set_cell (layout, curs, BALN_CELL,  0, 8);
 
         curs_last = curs;
@@ -193,8 +196,8 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
                                             CURSOR_SINGLE_JOURNAL);
 
         gnc_table_layout_set_cell (layout, curs, DATE_CELL,  0, 0);
-	gnc_table_layout_set_cell (layout, curs, TYPE_CELL,  0, 1);
-	gnc_table_layout_set_cell (layout, curs, DDUE_CELL,  0, 2);
+        gnc_table_layout_set_cell (layout, curs, TYPE_CELL,  0, 1);
+        gnc_table_layout_set_cell (layout, curs, DDUE_CELL,  0, 2);
         gnc_table_layout_set_cell (layout, curs, NUM_CELL,   0, 3);
         gnc_table_layout_set_cell (layout, curs, DESC_CELL,  0, 4);
 
@@ -216,8 +219,8 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL, 0, 3);
         gnc_table_layout_set_cell (layout, curs, MEMO_CELL, 0, 4);
         gnc_table_layout_set_cell (layout, curs, XFRM_CELL, 0, 5);
-	gnc_table_layout_set_cell (layout, curs, DEBT_CELL, 0, 6);
-	gnc_table_layout_set_cell (layout, curs, CRED_CELL, 0, 7);
+        gnc_table_layout_set_cell (layout, curs, DEBT_CELL, 0, 6);
+        gnc_table_layout_set_cell (layout, curs, CRED_CELL, 0, 7);
 
         break;
       }
@@ -245,7 +248,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
           gnc_table_layout_set_cell (layout, curs, DEBT_CELL,  0, 5);
           gnc_table_layout_set_cell (layout, curs, CRED_CELL,  0, 6);
         }
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
 
         curs_last = curs;
         curs = gnc_table_layout_get_cursor (layout,
@@ -255,6 +258,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -264,7 +268,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, DESC_CELL,  0, 2);
         gnc_table_layout_set_cell (layout, curs, TDEBT_CELL, 0, 5);
         gnc_table_layout_set_cell (layout, curs, TCRED_CELL, 0, 6);
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
 
         curs_last = curs;
         curs = gnc_table_layout_get_cursor (layout,
@@ -273,6 +277,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         copy_cursor_row (layout, curs, curs_last, 0);
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -291,7 +296,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
           gnc_table_layout_set_cell (layout, curs, DEBT_CELL,  0, 5);
           gnc_table_layout_set_cell (layout, curs, CRED_CELL,  0, 6);
         }
-	gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
+        gnc_table_layout_set_cell (layout, curs, RATE_CELL, 0, 7);
 
         break;
       }
@@ -322,6 +327,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -341,6 +347,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         copy_cursor_row (layout, curs, curs_last, 0);
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -381,6 +388,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -399,6 +407,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         copy_cursor_row (layout, curs, curs_last, 0);
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
+        gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -514,11 +523,11 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
   gnc_register_add_cell (layout,
                          NUM_CELL,
                          NUM_CELL_TYPE_NAME,
-			 /* Translators: The 'sample:' items are
-			    strings which are not displayed, but only
-			    used to estimate widths. Please only
-			    translate the portion after the ':' and
-			    leave the rest ("sample:") as is. */
+                         /* Translators: The 'sample:' items are
+                            strings which are not displayed, but only
+                            used to estimate widths. Please only
+                            translate the portion after the ':' and
+                            leave the rest ("sample:") as is. */
                          N_("sample:99999") + 7,
                          CELL_ALIGN_LEFT,
                          FALSE,
@@ -670,6 +679,14 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
                          FALSE,
                          TRUE);
 
+  gnc_register_add_cell (layout,
+                         VNOTES_CELL,
+                         BASIC_CELL_TYPE_NAME,
+                         N_("sample:No Particular Reason") + 7,
+                         CELL_ALIGN_RIGHT,
+                         FALSE,
+                         TRUE);
+
   gnc_register_add_cell (layout,
                          FCRED_CELL,
                          FORMULA_CELL_TYPE_NAME,
