@@ -15,8 +15,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
 
@@ -27,7 +27,7 @@
 #include "Scrub.h"
 #include "SchedXaction.h"
 #include "datecell.h"
-#include "gnc-engine-util.h"
+#include "gnc-engine.h"
 #include "numcell.h"
 #include "pricecell.h"
 #include "recncell.h"
@@ -46,7 +46,7 @@ struct sr_save_data
 };
 
 /* This static indicates the debugging module that this .o belongs to. */
-static short module = MOD_LEDGER;
+static QofLogModule log_module = GNC_MOD_LEDGER;
 
 
 static void
@@ -419,7 +419,7 @@ gnc_split_register_save_amount_values (SRSaveData *sd, SplitRegister *reg)
      * Otherwise, we _can_ use the rate_cell!
      */
     if (sd->reg_expanded && ! gnc_commodity_equal (reg_com, xfer_com))
-      amtconv = gnc_split_register_get_conv_rate (sd->trans, acc);
+      amtconv = xaccTransGetAccountConvRate(sd->trans, acc);
     else
       amtconv = convrate;
 
@@ -506,7 +506,7 @@ gnc_split_register_save_cells (gpointer save_data,
     Account *acc;
     gboolean split_needs_amount;
 
-    split_needs_amount = gnc_split_register_split_needs_amount (reg, sd->split);
+    split_needs_amount = gnc_split_register_split_needs_amount(reg, sd->split);
 
     /* We are changing the rate on the current split, but it was not
      * handled in the debcred handler, so we need to do it here.
@@ -514,8 +514,8 @@ gnc_split_register_save_cells (gpointer save_data,
     if (!sd->handled_dc && split_needs_amount && !gnc_numeric_zero_p (rate))
     {
       gnc_numeric amount = xaccSplitGetAmount (sd->split);
-      value = gnc_numeric_div (amount, rate, gnc_commodity_get_fraction (txn_cur),
-			       GNC_RND_ROUND);
+      value = gnc_numeric_div(
+          amount, rate, gnc_commodity_get_fraction(txn_cur), GNC_RND_ROUND);
       xaccSplitSetValue (sd->split, value);
 
       /* XXX: do we need to set the amount on the other split? */
@@ -534,8 +534,8 @@ gnc_split_register_save_cells (gpointer save_data,
        * _both_ accounts -- so grab the other exchange rate.
        */
       if (gnc_numeric_zero_p (rate) || split_needs_amount)
-	rate = gnc_split_register_get_conv_rate (xaccSplitGetParent (other_split),
-						 acc);
+          rate = xaccTransGetAccountConvRate(xaccSplitGetParent (other_split),
+                                             acc);
 
       amount = gnc_numeric_mul (value, rate, xaccAccountGetCommoditySCU (acc),
 				GNC_RND_ROUND);
@@ -596,8 +596,6 @@ gnc_template_register_save_xfrm_cell (BasicCell * cell,
 
   g_return_if_fail (gnc_basic_cell_has_name (cell, XFRM_CELL));
 
-  kvpf = xaccSplitGetSlots (sd->split);
-
   /* save the account GUID into the kvp_data. */
   acct = gnc_split_register_get_account (reg, XFRM_CELL);
   if (!acct)
@@ -607,12 +605,10 @@ gnc_template_register_save_xfrm_cell (BasicCell * cell,
   }
 
   acctGUID = xaccAccountGetGUID (acct);
-
+  kvpf = xaccSplitGetSlots (sd->split);
   kvp_frame_set_slot_path (kvpf, kvp_value_new_guid(acctGUID),
                            GNC_SX_ID, GNC_SX_ACCOUNT, NULL);
 
-  kvpf = xaccSplitGetSlots (sd->split);
-
   template_acc = xaccAccountLookup (&info->template_account,
                                     gnc_get_current_book ());
 
