@@ -91,6 +91,9 @@ struct sr_info
    * split */
   gboolean change_confirmed;
 
+  /* true if the exchange rate has been reset on the current split */
+  gboolean rate_reset;
+
   /* User data for users of SplitRegisters */
   gpointer user_data;
 
@@ -158,6 +161,8 @@ Account * gnc_split_register_get_account (SplitRegister *reg,
 
 gboolean gnc_split_register_recn_cell_confirm (char old_flag, gpointer data);
 
+void gnc_split_register_check_cell (SplitRegister *reg, const char *cell_name);
+
 CursorClass gnc_split_register_cursor_name_to_class (const char *cursor_name);
 
 gnc_numeric gnc_split_register_debcred_cell_value (SplitRegister *reg);
