@@ -1356,6 +1356,10 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
 
    DEBUG ("save split is %p \n", split);
 
+   /* Act on any changes to the current cell before the save. */
+   gnc_split_register_check_cell (reg,
+                                  gnc_table_get_current_cell_name (reg->table));
+
    if (!gnc_split_register_auto_calc (reg, split))
      return FALSE;
 
@@ -2368,9 +2372,11 @@ gnc_split_register_cleanup (SplitRegister *reg)
 {
    SRInfo *info = gnc_split_register_get_info (reg);
    Transaction *pending_trans;
-   Transaction *trans;
+   Transaction *blank_trans = NULL;
    Split *blank_split;
 
+   ENTER("reg=%p", reg);
+
    blank_split = xaccSplitLookup (&info->blank_split_guid,
                                   gnc_get_current_book ());
 
@@ -2384,16 +2390,19 @@ gnc_split_register_cleanup (SplitRegister *reg)
    {
       /* split destroy will automatically remove it
        * from its parent account */
-      trans = xaccSplitGetParent (blank_split);
+      blank_trans = xaccSplitGetParent (blank_split);
+
+      DEBUG("blank_split=%p, blank_trans=%p, pending_trans=%p",
+            blank_split, blank_trans, pending_trans);
 
       /* Make sure we don't commit this below */
-      if (trans == pending_trans)
+      if (blank_trans == pending_trans)
       {
         info->pending_trans_guid = *guid_null ();
         pending_trans = NULL;
       }
 
-      xaccTransDestroy (trans);
+      xaccTransDestroy (blank_trans);
 
       info->blank_split_guid = *guid_null ();
       blank_split = NULL;
@@ -2402,6 +2411,8 @@ gnc_split_register_cleanup (SplitRegister *reg)
    /* be sure to take care of any open transactions */
    if (pending_trans != NULL)
    {
+      g_critical("BUG DETECTED: pending_trans=%p, blank_split=%p, blank_trans=%p",
+                 pending_trans, blank_split, blank_trans);
       g_assert_not_reached();
       info->pending_trans_guid = *guid_null ();
       /* CAS: It's not clear to me that we'd really want to commit
@@ -2417,13 +2428,16 @@ gnc_split_register_cleanup (SplitRegister *reg)
    gnc_split_register_destroy_info (reg);
 
    gnc_resume_gui_refresh ();
+
+   LEAVE(" ");
 }
 
 void
 gnc_split_register_destroy (SplitRegister *reg)
 {
-  if (!reg)
-    return;
+  g_return_if_fail(reg);
+
+  ENTER("reg=%p", reg);
 
   gnc_gconf_general_remove_cb(KEY_ACCOUNTING_LABELS,
 			      split_register_gconf_changed,
@@ -2438,6 +2452,7 @@ gnc_split_register_destroy (SplitRegister *reg)
 
   /* free the memory itself */
   g_free (reg);
+  LEAVE(" ");
 }
 
 void 
