@@ -2426,8 +2426,9 @@ gnucash_sheet_new (Table *table)
         sheet->grid = item;
 
         /* some register data */
-        sheet->dimensions_hash_table = g_hash_table_new (g_int_hash,
-                                                         g_int_equal);
+        sheet->dimensions_hash_table = g_hash_table_new_full (g_int_hash,
+							      g_int_equal,
+							      g_free, NULL);
 
         /* The cursor */
         sheet->cursor = gnucash_cursor_new (sheet_group);
