@@ -48,6 +48,15 @@ style_get_key (SheetBlockStyle *style)
         return &key;
 }
 
+static gpointer
+style_create_key (SheetBlockStyle *style)
+{
+        static gint key;
+
+        key = style->cursor->num_rows;
+
+        return g_memdup(&key, sizeof(key));
+}
 
 static void
 cell_dimensions_construct (gpointer _cd, gpointer user_data)
@@ -103,7 +112,7 @@ gnucash_style_dimensions_init (GnucashSheet *sheet, SheetBlockStyle *style)
         if (!dimensions) {
                 dimensions = style_dimensions_new (style);
                 g_hash_table_insert (sheet->dimensions_hash_table,
-                                     style_get_key (style), dimensions);
+                                     style_create_key (style), dimensions);
         }
 
         dimensions->refcount++;
