@@ -137,6 +137,9 @@
           (list->vector
            (list '2nd-est (N_ "2nd Est Tax Quarter") (N_ "Apr 1 - May 31")))
           (list->vector
+	   ;; Translators: The US tax quarters are different from
+	   ;; actual year's quarters! See the definition of
+	   ;; tax-qtr-real-qtr-year variable above.
            (list '3rd-est (N_ "3rd Est Tax Quarter") (N_ "Jun 1 - Aug 31")))
           (list->vector
            (list '4th-est (N_ "4th Est Tax Quarter") (N_ "Sep 1 - Dec 31")))
@@ -197,7 +200,7 @@
 
 (define (gnc:account-get-txf-code account)
   (let ((code (xaccAccountGetTaxUSCode account)))
-    (string->symbol (if code code "N000"))))
+    (string->symbol (if (string-null? code) "N000" code))))
 
 (define (gnc:get-txf-format code income?)
   (gnc:txf-get-format (if income?
@@ -207,7 +210,7 @@
 
 (define (gnc:account-get-txf-payer-source account)
   (let ((pns (xaccAccountGetTaxUSPayerNameSource account)))
-    (string->symbol (if pns pns "keine"))))
+    (string->symbol (if (string-null? pns) "keine" pns))))
 
 ;; check for duplicate txf codes
 (define (txf-check-dups account) 
@@ -283,7 +286,7 @@
       '()
       (cons (gnc:make-html-table-header-cell/markup
              "number-header"
-             (_ "Sub-")
+             "Sub-"
              (number->string (- max-level 1)))
             (make-sub-headers (- max-level 1)))))
 
@@ -318,7 +321,7 @@
 					(gnc-account-get-parent account)
 					account))
 				    (name (xaccAccountGetName named-acct)))
-			       (if name
+			       (if (not (string-null? name))
 				   name
 				   (begin
 				     (display
