@@ -143,7 +143,7 @@ update_display_lists(gnc_column_view_edit * view)
     for(i = 0; !SCM_NULLP(names); names = SCM_CDR(names), i++) {
       if (SCM_EQUALP (SCM_CAR(names), selection))
         row = i;
-      name = SCM_STRING_CHARS(scm_call_1(template_menu_name, SCM_CAR(names)));
+      name = _(SCM_STRING_CHARS(scm_call_1(template_menu_name, SCM_CAR(names))));
       gtk_list_store_append(store, &iter);
       gtk_list_store_set(store, &iter,
 			 AVAILABLE_COL_NAME, name,
@@ -180,19 +180,19 @@ update_display_lists(gnc_column_view_edit * view)
       if (SCM_EQUALP (SCM_CAR(contents), selection))
         row = i;
 
-      id = scm_num2int(SCM_CAAR(contents), SCM_ARG1, __FUNCTION__);
+      id = scm_num2int(SCM_CAAR(contents), SCM_ARG1, G_STRFUNC);
       this_report = gnc_report_find(id);
+      name = _(SCM_STRING_CHARS(scm_call_1(report_menu_name, this_report)));
 
       gtk_list_store_append(store, &iter);
       gtk_list_store_set
 	(store, &iter,
-	 CONTENTS_COL_NAME, SCM_STRING_CHARS(scm_call_1(report_menu_name,
-							this_report)),
+	 CONTENTS_COL_NAME, name,
 	 CONTENTS_COL_ROW, i,
 	 CONTENTS_COL_REPORT_COLS, scm_num2int(SCM_CADR(SCM_CAR(contents)),
-					       SCM_ARG1, __FUNCTION__),
+					       SCM_ARG1, G_STRFUNC),
 	 CONTENTS_COL_REPORT_ROWS, scm_num2int(SCM_CADDR(SCM_CAR(contents)),
-					       SCM_ARG1, __FUNCTION__),
+					       SCM_ARG1, G_STRFUNC),
 	 -1);
     }
   }
@@ -364,15 +364,15 @@ gnc_column_view_edit_options(SCM options, SCM view)
     gtk_tree_view_append_column(r->contents, column);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Cols"), renderer,
-						      "text", CONTENTS_COL_REPORT_COLS,
+    column = gtk_tree_view_column_new_with_attributes(_("Rows"), renderer,
+						      "text", CONTENTS_COL_REPORT_ROWS,
 						      NULL);
     gtk_tree_view_append_column(r->contents, column);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Rows"), renderer,
-						      "text", CONTENTS_COL_REPORT_ROWS,
-						      NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Cols"), renderer,
+                  "text", CONTENTS_COL_REPORT_COLS,
+                  NULL);
     gtk_tree_view_append_column(r->contents, column);
 
     selection = gtk_tree_view_get_selection(r->contents);
@@ -409,7 +409,7 @@ gnc_column_view_edit_add_cb(GtkButton * button, gpointer user_data)
     template_name = scm_list_ref(r->available_list, 
                                 scm_int2num(r->available_selected));
     new_report = scm_call_1(make_report, template_name);
-    id = scm_num2int(new_report, SCM_ARG1, __FUNCTION__);
+    id = scm_num2int(new_report, SCM_ARG1, G_STRFUNC);
     scm_call_2(mark_report, gnc_report_find(id), SCM_BOOL_T);
     oldlength = scm_ilength(r->contents_list);
     
@@ -585,10 +585,10 @@ gnc_column_view_edit_size_cb(GtkButton * button, gpointer user_data)
                           scm_int2num(r->contents_selected));
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(colspin),
                               (float)scm_num2int(SCM_CADR(current),
-						 SCM_ARG1, __FUNCTION__));
+						 SCM_ARG1, G_STRFUNC));
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(rowspin),
                               (float)scm_num2int(SCM_CADDR(current),
-						 SCM_ARG1, __FUNCTION__));
+						 SCM_ARG1, G_STRFUNC));
   
     dlg_ret = gtk_dialog_run(GTK_DIALOG(dlg));
     gtk_widget_hide(dlg);
