@@ -1,16 +1,16 @@
 /*********************************************************************
  * gncmod-report-gnome.c
- * module definition/initialization for the gnome report infrastructure 
- * 
- * Copyright (c) 2001 Linux Developers Group, Inc. 
+ * module definition/initialization for the gnome report infrastructure
+ *
+ * Copyright (c) 2001 Linux Developers Group, Inc.
  *********************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <gmodule.h>
 #include <gtk/gtk.h>
-#include <stdio.h>
 #include <libguile.h>
 
 #include "gnc-module.h"
@@ -18,29 +18,25 @@
 
 #include "window-report.h"
 
+GNC_MODULE_API_DECL(libgncmod_report_gnome)
+
 /* version of the gnc module system interface we require */
-int libgncmod_report_gnome_LTX_gnc_module_system_interface = 0;
+int libgncmod_report_gnome_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_report_gnome_LTX_gnc_module_current  = 0;
-int libgncmod_report_gnome_LTX_gnc_module_revision = 0;
-int libgncmod_report_gnome_LTX_gnc_module_age      = 0;
-
-/* forward references */
-char *libgncmod_report_gnome_LTX_gnc_module_path(void);
-char *libgncmod_report_gnome_LTX_gnc_module_description(void);
-int libgncmod_report_gnome_LTX_gnc_module_init(int refcount);
-int libgncmod_report_gnome_LTX_gnc_module_end(int refcount);
+int libgncmod_report_gnome_gnc_module_current  = 0;
+int libgncmod_report_gnome_gnc_module_revision = 0;
+int libgncmod_report_gnome_gnc_module_age      = 0;
 
 
 char *
-libgncmod_report_gnome_LTX_gnc_module_path(void)
+libgncmod_report_gnome_gnc_module_path(void)
 {
   return g_strdup("gnucash/report/report-gnome");
 }
 
-char * 
-libgncmod_report_gnome_LTX_gnc_module_description(void)
+char *
+libgncmod_report_gnome_gnc_module_description(void)
 {
   return g_strdup("Gnome component of GnuCash report generation system");
 }
@@ -52,9 +48,10 @@ lmod(char * mn)
   scm_c_eval_string(form);
   g_free(form);
 }
+extern SCM scm_init_sw_report_gnome_module(void);
 
 int
-libgncmod_report_gnome_LTX_gnc_module_init(int refcount)
+libgncmod_report_gnome_gnc_module_init(int refcount)
 {
   if(!gnc_module_load("gnucash/app-utils", 0)) {
     return FALSE;
@@ -67,8 +64,9 @@ libgncmod_report_gnome_LTX_gnc_module_init(int refcount)
   if(!gnc_module_load("gnucash/report/report-system", 0)) {
     return FALSE;
   }
+  scm_init_sw_report_gnome_module();
 
-  lmod ("(g-wrapped gw-report-gnome)");
+  lmod ("(sw_report_gnome)");
   lmod ("(gnucash report report-gnome)");
 
   if (refcount == 0)
@@ -78,7 +76,7 @@ libgncmod_report_gnome_LTX_gnc_module_init(int refcount)
 }
 
 int
-libgncmod_report_gnome_LTX_gnc_module_end(int refcount)
+libgncmod_report_gnome_gnc_module_end(int refcount)
 {
   return TRUE;
 }
