@@ -266,14 +266,14 @@
 (define (gnc:html-barchart-render barchart doc)
   (define (ensure-numeric elt)
     (cond ((number? elt)
-           elt)
+           (exact->inexact elt))
           ((string? elt)
            (with-input-from-string elt
              (lambda ()
                (let ((n (read)))
                  (if (number? n) n 0.0)))))
           ((gnc:gnc-numeric? elt)
-           (gnc:numeric-to-double elt))
+           (gnc-numeric-to-double elt))
           (#t 
            0.0)))
   
