@@ -22,7 +22,7 @@
 ;;    sheet to no more than daily resolution.
 ;;    
 ;;    The Company Name field does not currently default to the name
-;;    in (gnc:get-current-book).
+;;    in (gnc-get-current-book).
 ;;    
 ;;    Line & column alignments still do not conform with
 ;;    textbook accounting practice (they're close though!).
@@ -139,6 +139,9 @@
   (N_ "Display any foreign currency amount in an account"))
 (define optname-show-rates (N_ "Show Exchange Rates"))
 (define opthelp-show-rates (N_ "Show the exchange rates used"))
+(define optname-unrealized-gains (N_ "Compute unrealized gains and losses"))
+(define opthelp-unrealized-gains
+  (N_ "Include unrealized gains and losses in the computation.  Will produce incorrect results if the current file uses commodity trading accounts"))
 
 
 ;; options generator
@@ -156,7 +159,7 @@
       (gnc:make-string-option
       gnc:pagename-general optname-party-name
       "b" opthelp-party-name ""))
-    ;; this should default to company name in (gnc:get-current-book)
+    ;; this should default to company name in (gnc-get-current-book)
     ;; does anyone know the function to get the company name??
     ;; (GnuCash is *so* well documented... sigh)
     
@@ -168,6 +171,11 @@
      (gnc:make-simple-boolean-option
       gnc:pagename-general optname-report-form
       "d" opthelp-report-form #t))
+
+    (add-option
+     (gnc:make-simple-boolean-option
+      gnc:pagename-general optname-unrealized-gains
+      "e" opthelp-unrealized-gains #t))
     
     ;; accounts to work on
     (add-option
@@ -177,9 +185,12 @@
       opthelp-accounts
       (lambda ()
 	(gnc:filter-accountlist-type 
-	 '(bank cash credit asset liability stock mutual-fund currency
-		payable receivable equity income expense)
-	 (gnc:group-get-subaccounts (gnc:get-current-group))))
+         (list ACCT-TYPE-BANK ACCT-TYPE-CASH ACCT-TYPE-CREDIT
+               ACCT-TYPE-ASSET ACCT-TYPE-LIABILITY
+               ACCT-TYPE-STOCK ACCT-TYPE-MUTUAL ACCT-TYPE-CURRENCY
+               ACCT-TYPE-PAYABLE ACCT-TYPE-RECEIVABLE
+               ACCT-TYPE-EQUITY ACCT-TYPE-INCOME ACCT-TYPE-EXPENSE)
+	 (gnc-account-get-descendants-sorted (gnc-get-current-root-account))))
       #f #t))
     (gnc:options-add-account-levels!
      options gnc:pagename-accounts optname-depth-limit
@@ -196,7 +207,7 @@
     
     (gnc:options-add-price-source! 
      options pagename-commodities
-     optname-price-source "b" 'weighted-average)
+     optname-price-source "b" 'average-cost)
     
     (add-option 
      (gnc:make-simple-boolean-option
@@ -290,6 +301,8 @@
                                    optname-date))))
          (report-form? (get-option gnc:pagename-general
                                optname-report-form))
+         (compute-unrealized-gains? (get-option gnc:pagename-general
+                                                optname-unrealized-gains))
          (accounts (get-option gnc:pagename-accounts
                                optname-accounts))	 
 	 (depth-limit (get-option gnc:pagename-accounts 
@@ -337,14 +350,14 @@
          ;; decompose the account list
          (split-up-accounts (gnc:decompose-accountlist accounts))
          (asset-accounts
-	  (assoc-ref split-up-accounts 'asset))
+	  (assoc-ref split-up-accounts ACCT-TYPE-ASSET))
          (liability-accounts
-	  (assoc-ref split-up-accounts 'liability))
-         (equity-accounts
-          (assoc-ref split-up-accounts 'equity))
+	  (assoc-ref split-up-accounts ACCT-TYPE-LIABILITY))
          (income-expense-accounts
-          (append (assoc-ref split-up-accounts 'income)
-                  (assoc-ref split-up-accounts 'expense)))
+          (append (assoc-ref split-up-accounts ACCT-TYPE-INCOME)
+                  (assoc-ref split-up-accounts ACCT-TYPE-EXPENSE)))
+         (equity-accounts
+          (assoc-ref split-up-accounts ACCT-TYPE-EQUITY))
 	 
          (doc (gnc:make-html-document))
 	 ;; this can occasionally put extra (blank) columns in our
@@ -353,7 +366,7 @@
 	 ;; is the only simple way to ensure that all three tables
 	 ;; (asset, liability, equity) have the same width.
          (tree-depth (if (equal? depth-limit 'all)
-                         (gnc:get-current-group-depth) 
+                         (gnc:get-current-account-tree-depth) 
 			 depth-limit))
          ;; exchange rates calculation parameters
 	 (exchange-fn
@@ -366,7 +379,7 @@
       (define allow-same-column-totals #t)
       (let* ((neg? (and signed-balance
 			neg-label
-			(gnc:numeric-negative-p
+			(gnc-numeric-negative-p
 			 (gnc:gnc-monetary-amount
 			  (gnc:sum-collector-commodity
 			   signed-balance report-commodity exchange-fn)))))
@@ -402,11 +415,11 @@
        table
        (+ (* 2 tree-depth)
 	  (if (equal? tabbing 'canonically-tabbed) 1 0))))
-    
+
     ;;(gnc:warn "account names" liability-account-names)
     (gnc:html-document-set-title! 
      doc (string-append company-name " " report-title " "
-			(gnc:print-date date-tp))
+			(gnc-print-date date-tp))
      )
     
     (if (null? accounts)
@@ -420,7 +433,7 @@
          (gnc:html-make-no-account-warning 
 	  reportname (gnc:report-id report-obj)))
 	
-        ;; Get all the balances for each account group.
+        ;; Get all the balances for each of the account types.
         (let* ((asset-balance #f)
                (neg-liability-balance #f) ;; credit balances are < 0
                (liability-balance #f)
@@ -431,7 +444,6 @@
                (unrealized-gain-collector #f)
                (total-equity-balance #f)
                (liability-plus-equity #f)
-	       (book-balance #f) ;; assets - liabilities - equity, norm 0
 	       
                ;; Create the account tables below where their
                ;; percentage time can be tracked.
@@ -447,6 +459,9 @@
 		(lambda (account)
 		  (gnc:account-get-comm-balance-at-date 
 		   account date-tp #f)))
+               (get-total-value-fn
+                (lambda (account)
+                  (gnc:account-get-comm-value-at-date account date-tp #f)))
 	       )
 	  
 	  ;; If you ask me, any outstanding(TM) retained earnings and
@@ -493,38 +508,25 @@
 	  ;; something and its value increases/decreases (prior to
 	  ;; your selling it) and you have to reflect that on your
 	  ;; balance sheet.
-	  ;; 
-	  ;; I *think* a decrease in the value of a liability or
-	  ;; equity constitutes an unrealized loss.  I'm unsure about
-	  ;; that though....
-	  ;; 
-	  (set! book-balance (gnc:make-commodity-collector))
-	  (book-balance 'merge asset-balance #f)
-	  (book-balance 'merge neg-liability-balance #f)
-	  (book-balance 'merge neg-equity-balance #f)
-	  (book-balance 'merge neg-retained-earnings #f)
+	  ;;
+          ;; Don't calculate unrealized gains if we were asked not to.  If we are using
+          ;; commodity trading accounts they will automatically accumulate the gains.
           (set! unrealized-gain-collector (gnc:make-commodity-collector))
-          (let* ((weighted-fn
-                  (gnc:case-exchange-fn 'weighted-average
-                                        report-commodity date-tp))
-		 
-                 (value
-                  (gnc:gnc-monetary-amount
-                   (gnc:sum-collector-commodity book-balance
-                                                report-commodity
-                                                exchange-fn)))
-		 
-                 (cost
-                  (gnc:gnc-monetary-amount
-                   (gnc:sum-collector-commodity book-balance
-                                                report-commodity
-                                                weighted-fn)))
-		 
-                 (unrealized-gain (gnc:numeric-sub-fixed value cost)))
-	    
-            (unrealized-gain-collector 'add report-commodity unrealized-gain)
-	    )
-	  ;; calculate equity and liability+equity totals
+          (if compute-unrealized-gains?
+              (let ((asset-basis 
+                     (gnc:accounts-get-comm-total-assets asset-accounts
+                                                         get-total-value-fn))
+                    (neg-liability-basis 
+                     (gnc:accounts-get-comm-total-assets liability-accounts
+                                                         get-total-value-fn)))
+                ;; Calculate unrealized gains from assets.
+                (unrealized-gain-collector 'merge asset-balance #f)
+                (unrealized-gain-collector 'minusmerge asset-basis #f)
+                ;; Combine with unrealized gains from liabilities
+                (unrealized-gain-collector 'merge neg-liability-balance #f)
+                (unrealized-gain-collector 'minusmerge neg-liability-basis #f)))
+
+          ;; calculate equity and liability+equity totals
 	  (set! total-equity-balance (gnc:make-commodity-collector))
 	  (total-equity-balance 'merge
 				equity-balance
@@ -641,13 +643,13 @@
 	  ;; we omit retianed earnings & unrealized gains
 	  ;; from the balance report, if zero, since they
 	  ;; are not present on normal balance sheets
-	  (and (not (gnc:commodity-collector-allzero?
+	  (and (not (gnc-commodity-collector-allzero?
 		     retained-earnings))
 	       (add-subtotal-line right-table
 				  (_ "Retained Earnings")
 				  (_ "Retained Losses")
 				  retained-earnings))
-	  (and (not (gnc:commodity-collector-allzero?
+	  (and (not (gnc-commodity-collector-allzero?
 		     unrealized-gain-collector))
 	       (add-subtotal-line right-table
 				  (_ "Unrealized Gains")
@@ -715,7 +717,7 @@
   )
 
 (gnc:define-report 
- 'version 2
+ 'version 1
  'name reportname
  'menu-path (list gnc:menuname-asset-liability)
  'options-generator balance-sheet-options-generator
