@@ -116,7 +116,7 @@ developing over time"))
       (lambda ()
         (gnc:filter-accountlist-type 
          account-types
-         (gnc:group-get-subaccounts (gnc:get-current-group))))
+         (gnc-account-get-descendants-sorted (gnc-get-current-root-account))))
       (lambda (accounts)
         (list #t
               (gnc:filter-accountlist-type account-types accounts)))
@@ -146,13 +146,20 @@ developing over time"))
       "c" (N_ "Maximum number of bars in the chart") 8
       2 24 0 1))
 
+    (add-option
+     (gnc:make-simple-boolean-option
+      gnc:pagename-display
+      (N_ "Show table")
+      "d" (N_ "Display a table of the selected data.")
+      #f))
+
     (gnc:options-add-plot-size! 
      options gnc:pagename-display 
-     optname-plot-width optname-plot-height "d" 400 400)
+     optname-plot-width optname-plot-height "e" 400 400)
 
     (gnc:options-add-sort-method! 
      options gnc:pagename-display
-     optname-sort-method "e" 'amount)
+     optname-sort-method "f" 'amount)
 
     (gnc:options-set-default-section options gnc:pagename-general)
 
@@ -209,12 +216,14 @@ developing over time"))
         
 	(work-done 0)
 	(work-to-do 0)
+        (show-table? (get-option gnc:pagename-display (N_ "Show table")))
         (document (gnc:make-html-document))
         (chart (gnc:make-html-barchart))
+        (table (gnc:make-html-table))
         (topl-accounts (gnc:filter-accountlist-type 
                         account-types
-                        (gnc:group-get-account-list 
-                         (gnc:get-current-group)))))
+                        (gnc-account-get-children-sorted
+                         (gnc-get-current-root-account)))))
     
     ;; Returns true if the account a was selected in the account
     ;; selection option.
@@ -228,7 +237,7 @@ developing over time"))
         (let* ((commodity-list #f)
                (exchange-fn #f)
                (tree-depth (if (equal? account-levels 'all)
-                               (gnc:get-current-group-depth)
+                               (gnc:get-current-account-tree-depth)
                                account-levels))
                ;; This is the list of date intervals to calculate.
                (dates-list (if do-intervals?
@@ -244,7 +253,7 @@ developing over time"))
                ;; created.
                (date-string-list
                 (map (lambda (date-list-item)
-                       (gnc:print-date
+                       (gnc-print-date
                         (if do-intervals?
                             (car date-list-item)
                             date-list-item)))
@@ -258,7 +267,7 @@ developing over time"))
           (define (collector->double c date)
             ;; Future improvement: Let the user choose which kind of
             ;; currency combining she want to be done. 
-            (gnc:numeric-to-double 
+            (gnc-numeric-to-double
              (gnc:gnc-monetary-amount
               (gnc:sum-collector-commodity 
                c report-currency 
@@ -298,7 +307,7 @@ developing over time"))
 		  (for-each
 		   (lambda (a)
 		     (set! sum (+ sum (+ 1 (count-accounts (+ 1 current-depth)
-							   (gnc:account-get-immediate-subaccounts a))))))
+							   (gnc-account-get-children a))))))
 		   accts)
 		  sum)
 		(length (filter show-acct? accts))))
@@ -332,7 +341,7 @@ developing over time"))
                        (set! res (append
                                   (traverse-accounts
                                    (+ 1 current-depth)
-                                   (gnc:account-get-immediate-subaccounts a))
+                                   (gnc-account-get-children a))
                                   res))))
                    accts)
                   res)
@@ -371,16 +380,16 @@ developing over time"))
 			  (cond
 			   ((eq? sort-method 'acct-code)
 			    (lambda (a b) 
-			      (string<? (gnc:account-get-code (car a))
-					(gnc:account-get-code (car b)))))
+			      (string<? (xaccAccountGetCode (car a))
+					(xaccAccountGetCode (car b)))))
 			   ((eq? sort-method 'alphabetical)
 			    (lambda (a b) 
 			      (string<? ((if show-fullname?
-					     gnc:account-get-full-name
-					     gnc:account-get-name) (car a))
+					     gnc-account-get-full-name
+					     xaccAccountGetName) (car a))
 					((if show-fullname?
-					     gnc:account-get-full-name
-					     gnc:account-get-name) (car b)))))
+					     gnc-account-get-full-name
+					     xaccAccountGetName) (car b)))))
 			   (else
 			    (lambda (a b)
 			      (> (apply + (cadr a))
@@ -407,8 +416,8 @@ developing over time"))
                              (if do-intervals?
                                  (_ "%s to %s")
                                  (_ "Balances %s to %s"))
-                             (gnc:print-date from-date-tp) 
-                             (gnc:print-date to-date-tp)))
+                             (gnc-print-date from-date-tp)
+                             (gnc-print-date to-date-tp)))
              (gnc:html-barchart-set-width! chart width)
              (gnc:html-barchart-set-height! chart height)
              
@@ -417,7 +426,7 @@ developing over time"))
              ;; FIXME: axis labels are not yet supported by
              ;; libguppitank.
              (gnc:html-barchart-set-y-axis-label!
-              chart (gnc:commodity-get-mnemonic report-currency))
+              chart (gnc-commodity-get-mnemonic report-currency))
              (gnc:html-barchart-set-row-labels-rotated?! chart #t)
              (gnc:html-barchart-set-stacked?! chart stacked?)
              ;; If this is a stacked barchart, then reverse the legend.
@@ -469,8 +478,8 @@ developing over time"))
                            (if (string? (car pair))
                                (car pair)
                                ((if show-fullname?
-                                    gnc:account-get-full-name
-                                    gnc:account-get-name) (car pair)))
+                                    gnc-account-get-full-name
+                                    xaccAccountGetName) (car pair)))
 			   'pre " " (_ "and") " " 'post))
                          all-data))
              (gnc:html-barchart-set-col-colors! 
@@ -488,7 +497,7 @@ developing over time"))
                        other-anchor
                        (let* ((acct (car pair))
                               (subaccts 
-                               (gnc:account-get-immediate-subaccounts acct)))
+                               (gnc-account-get-children acct)))
                          (if (null? subaccts)
                              ;; if leaf-account, make this an anchor
                              ;; to the register.
@@ -508,8 +517,8 @@ developing over time"))
                                (list gnc:pagename-general 
                                      gnc:optname-reportname
                                      ((if show-fullname?
-                                          gnc:account-get-full-name
-                                          gnc:account-get-name) acct))))))))
+                                          gnc-account-get-full-name
+                                          xaccAccountGetName) acct))))))))
                     all-data)))
                (gnc:html-barchart-set-button-1-bar-urls! 
                 chart (append urls urls))
@@ -518,7 +527,79 @@ developing over time"))
                 chart (append urls urls)))
              
 	     (gnc:report-percent-done 98)
-             (gnc:html-document-add-object! document chart))
+             (gnc:html-document-add-object! document chart)
+             (if show-table?
+                 (begin
+                   (gnc:html-table-append-column! table date-string-list)
+
+                   (letrec
+                       ((addcol
+                         (lambda (col)
+                           (if (not (null? col))
+                               (begin
+                                 (gnc:html-table-append-column!
+                                  table (car col))
+                                 (addcol (cdr col))
+                                 )
+                               ))
+                         ))
+                     (addcol (map cadr all-data))
+                     )
+
+                   (gnc:html-table-set-col-headers!
+                    table
+                    (append
+                     (list (_ "Date"))
+                     (map (lambda (pair)
+                            (regexp-substitute/global #f "&"
+                                                      (if (string? (car pair))
+                                                          (car pair)
+                                                          ((if show-fullname?
+                                                               gnc-account-get-full-name
+                                                               xaccAccountGetName) (car pair)))
+                                                      'pre " " (_ "and") " " 'post))
+                          all-data)
+                     (if (> (gnc:html-table-num-columns table) 2)
+                         (list (_ "Grand Total"))
+                         (list nil)
+                         )
+                     ))
+
+                   (if (> (gnc:html-table-num-columns table) 2)
+                       (letrec
+                           ((sumtot
+                             (lambda (row)
+                               (if (null? row)
+                                   '()
+                                   (cons (sumrow (car row)) (sumtot (cdr row)))
+                                   )
+                               )
+                             )
+                            (sumrow
+                             (lambda (row)
+                               (if (not (null? row))
+                                   (+ (car row) (sumrow (cdr row)))
+                                   0
+                                   )
+                               )
+                             ))
+                         (gnc:html-table-append-column!
+                          table
+                          (sumtot (apply zip (map cadr all-data)))
+                          )
+                         )
+                       )
+                       ;; set numeric columns to align right
+                   (for-each
+                    (lambda (col)
+                      (gnc:html-table-set-col-style!
+                       table col "td"
+                       'attribute (list "align" "right")))
+                    '(1 2 3 4 5 6 7 8 9 10 11 12 13 14))
+                   (gnc:html-document-add-object! document table)
+                   ) ;; begin if
+                 )
+             )
 
            ;; else if empty data
            (gnc:html-document-add-object!
@@ -555,12 +636,15 @@ developing over time"))
  (list 
   ;; reportname, account-types, do-intervals?, 
   ;; menu-reportname, menu-tip
-  (list reportname-income '(income) #t menuname-income menutip-income (lambda (x) #t))
-  (list reportname-expense '(expense) #t menuname-expense menutip-expense (lambda (x) #f))
+  (list reportname-income (list ACCT-TYPE-INCOME) #t menuname-income menutip-income (lambda (x) #t))
+  (list reportname-expense (list ACCT-TYPE-EXPENSE) #t menuname-expense menutip-expense (lambda (x) #f))
   (list reportname-assets 
-        '(asset bank cash checking savings money-market receivable
-                stock mutual-fund currency)
+        (list ACCT-TYPE-ASSET ACCT-TYPE-BANK ACCT-TYPE-CASH ACCT-TYPE-CHECKING
+              ACCT-TYPE-SAVINGS ACCT-TYPE-MONEYMRKT
+              ACCT-TYPE-RECEIVABLE ACCT-TYPE-STOCK ACCT-TYPE-MUTUAL
+              ACCT-TYPE-CURRENCY)
         #f menuname-assets menutip-assets (lambda (x) #f))
   (list reportname-liabilities 
-        '(liability payable credit credit-line)
+        (list ACCT-TYPE-LIABILITY ACCT-TYPE-PAYABLE ACCT-TYPE-CREDIT
+              ACCT-TYPE-CREDITLINE)
         #f menuname-liabilities menutip-liabilities (lambda (x) #t))))
